@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/align.c,v 3.22 1998/11/05 22:56:05 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /n/opus/u/guest/william/src/tgif/v3/RCS/align.c,v 3.0 1996/05/06 16:03:27 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -58,6 +57,7 @@ static char RCSid[] =
 #include "obj.e"
 #include "poly.e"
 #include "raster.e"
+#include "rect.e"
 #include "select.e"
 #include "setup.e"
 
@@ -245,7 +245,7 @@ void DistrSelObjs()
       }
       if (horiAlign != ALIGN_N) {
          x = (double)(left_dv->x);
-         h_dist = (right_dv->x-x)/(num_pts-1);
+         h_dist = ((double)(right_dv->x-x))/((double)(num_pts-1));
          for (ptr=left_dv; ptr->next!=right_dv; ptr=ptr->next) {
             obj_ptr = ptr->next->obj;
             vsel_ptr = ptr->next->vsel;
@@ -267,7 +267,7 @@ void DistrSelObjs()
       }
       if (vertAlign != ALIGN_N) {
          y = (double)(top_dv->y);
-         v_dist = (bottom_dv->y-y)/(num_pts-1);
+         v_dist = ((double)(bottom_dv->y-y))/((double)(num_pts-1));
          for (ptr=top_dv; ptr->next!=bottom_dv; ptr=ptr->next) {
             obj_ptr = ptr->next->obj;
             vsel_ptr = ptr->next->vsel;
@@ -490,42 +490,42 @@ void DistrSelObjs()
       case ALIGN_N:
       case ALIGN_L:
          x = (double)(left_sel->obj->obbox.ltx);
-         h_dist = (right_sel->obj->obbox.ltx-x)/(count-1);
+         h_dist = ((double)(right_sel->obj->obbox.ltx-x))/((double)(count-1));
          break;
       case ALIGN_C:
          x = (double)(left_sel->obj->obbox.rbx+left_sel->obj->obbox.ltx);
-         h_dist = (right_sel->obj->obbox.rbx+right_sel->obj->obbox.ltx-x) /
-               (count-1);
+         h_dist = ((double)(right_sel->obj->obbox.rbx +
+               right_sel->obj->obbox.ltx - x)) / ((double)(count-1));
          break;
       case ALIGN_R:
          x = (double)(left_sel->obj->obbox.rbx);
-         h_dist = (right_sel->obj->obbox.rbx-x)/(count-1);
+         h_dist = ((double)(right_sel->obj->obbox.rbx-x))/((double)(count-1));
          break;
       case ALIGN_S:
          x = (double)(left_sel->obj->obbox.rbx);
-         h_dist = (right_sel->obj->obbox.rbx-left_sel->obj->obbox.ltx-w) /
-               (count-1);
+         h_dist = ((double)(right_sel->obj->obbox.rbx -
+               left_sel->obj->obbox.ltx - w)) / ((double)(count-1));
          break;
       }
       switch (vertAlign) {
       case ALIGN_N:
       case ALIGN_T:
          y = (double)(top_sel->obj->obbox.lty);
-         v_dist = (bottom_sel->obj->obbox.lty-y)/(count-1);
+         v_dist = ((double)(bottom_sel->obj->obbox.lty-y))/((double)(count-1));
          break;
       case ALIGN_M:
          y = (double)(top_sel->obj->obbox.rby+top_sel->obj->obbox.lty);
-         v_dist = (bottom_sel->obj->obbox.rby +
-               bottom_sel->obj->obbox.lty-y) / (count-1);
+         v_dist = ((double)(bottom_sel->obj->obbox.rby +
+               bottom_sel->obj->obbox.lty - y)) / ((double)(count-1));
          break;
       case ALIGN_B:
          y = (double)(top_sel->obj->obbox.rby);
-         v_dist = (bottom_sel->obj->obbox.rby-y)/(count-1);
+         v_dist = ((double)(bottom_sel->obj->obbox.rby-y))/((double)(count-1));
          break;
       case ALIGN_S:
          y = (double)(top_sel->obj->obbox.rby);
-         v_dist = (bottom_sel->obj->obbox.rby-top_sel->obj->obbox.lty-h) /
-               (count-1);
+         v_dist = ((double)(bottom_sel->obj->obbox.rby -
+               top_sel->obj->obbox.lty - h)) / ((double)(count-1));
          break;
       }
       for (sel_ptr=left_sel; sel_ptr->next!=right_sel; sel_ptr=next_sel) {
@@ -536,7 +536,7 @@ void DistrSelObjs()
             break;
          case ALIGN_C:
             dx = round((x + h_dist - sel_ptr->next->obj->obbox.rbx -
-                  sel_ptr->next->obj->obbox.ltx) / 2.0);
+                  sel_ptr->next->obj->obbox.ltx) / ((double)2.0));
             break;
          case ALIGN_R:
             dx = round(x+h_dist-sel_ptr->next->obj->obbox.rbx);
@@ -555,10 +555,9 @@ void DistrSelObjs()
             MoveObj(sel_ptr->next->obj, dx, 0);
          }
 
+         x += h_dist;
          if (horiAlign == ALIGN_S) {
-            x = sel_ptr->next->obj->obbox.rbx;
-         } else {
-            x += h_dist;
+            x += sel_ptr->next->obj->obbox.rbx - sel_ptr->next->obj->obbox.ltx;
          }
          next_sel = sel_ptr->next;
          free(sel_ptr);
@@ -574,7 +573,7 @@ void DistrSelObjs()
             break;
          case ALIGN_M:
             dy = round((y + v_dist - sel_ptr->next->obj->obbox.rby -
-                  sel_ptr->next->obj->obbox.lty) / 2.0);
+                  sel_ptr->next->obj->obbox.lty) / ((double)2.0));
             break;
          case ALIGN_B:
             dy = round(y+v_dist-sel_ptr->next->obj->obbox.rby);
@@ -593,10 +592,9 @@ void DistrSelObjs()
             MoveObj(sel_ptr->next->obj, 0, dy);
          }
 
+         y += v_dist;
          if (vertAlign == ALIGN_S) {
-            y = sel_ptr->next->obj->obbox.rby;
-         } else {
-            y += v_dist;
+            y += sel_ptr->next->obj->obbox.rby - sel_ptr->next->obj->obbox.lty;
          }
          next_sel = sel_ptr->next;
          free(sel_ptr);
@@ -617,7 +615,7 @@ void DistrSelObjs()
          break;
       case ALIGN_C:
          sprintf(gszMsgBox, "Center of objects are %1d pixels apart.",
-               round(h_dist/2.0));
+               round(h_dist/((double)2.0)));
          Msg(gszMsgBox);
          break;
       case ALIGN_R:
@@ -639,7 +637,7 @@ void DistrSelObjs()
          break;
       case ALIGN_M:
          sprintf(gszMsgBox, "Middle of objects are %1d pixels apart.",
-               round(v_dist/2.0));
+               round(v_dist/((double)2.0)));
          Msg(gszMsgBox);
          break;
       case ALIGN_B:
@@ -673,6 +671,7 @@ int AutoJustifiable(obj_ptr)
    int auto_justifiable=TRUE, rotate, just;
 
    if (obj_ptr->type!=OBJ_TEXT || obj_ptr->detail.t->lines!=1) return FALSE;
+   if (obj_ptr->ctm != NULL) return FALSE;
 
    text_ptr=obj_ptr->detail.t;
    rotate=text_ptr->rotate;
@@ -1414,7 +1413,7 @@ void CenterAnEndPoint()
 {
    struct ObjRec *other_obj, *poly_obj;
    IntPoint *v;
-   int cx, cy, x1, y1, xn, yn, d1, dn, num_pts, index;
+   int cx, cy, x1, y1, xn, yn, d1, dn, num_pts, index, x, y, tmp_x, tmp_y;
 
    if (curChoice != NOTHING) return;
    if (topSel == NULL) return;
@@ -1441,20 +1440,46 @@ void CenterAnEndPoint()
    cy = (other_obj->obbox.lty+other_obj->obbox.rby)>>1;
    num_pts = poly_obj->detail.p->n;
    v = poly_obj->detail.p->vlist;
-   x1 = v[0].x;
-   y1 = v[0].y;
-   xn = v[num_pts-1].x;
-   yn = v[num_pts-1].y;
+   if (poly_obj->ctm == NULL) {
+      x1 = v[0].x;
+      y1 = v[0].y;
+      xn = v[num_pts-1].x;
+      yn = v[num_pts-1].y;
+   } else {
+      TransformPointThroughCTM(v[0].x-poly_obj->x, v[0].y-poly_obj->y,
+            poly_obj->ctm, &tmp_x, &tmp_y);
+      x1 = tmp_x+poly_obj->x;
+      y1 = tmp_y+poly_obj->y;
+      TransformPointThroughCTM(v[num_pts-1].x-poly_obj->x,
+            v[num_pts-1].y-poly_obj->y, poly_obj->ctm, &tmp_x, &tmp_y);
+      xn = tmp_x+poly_obj->x;
+      yn = tmp_y+poly_obj->y;
+   }
    d1 = (x1-cx)*(x1-cx)+(y1-cy)*(y1-cy);
    dn = (xn-cx)*(xn-cx)+(yn-cy)*(yn-cy);
-   index = (d1 <= dn) ? 0 : num_pts-1;
-   if (cx != v[index].x || cy != v[index].y) {
+   if (d1 <= dn) {
+      index = 0;
+      x = x1;
+      y = y1;
+   } else {
+      index = num_pts-1;
+      x = xn;
+      y = yn;
+   }
+   if (cx != x || cy != y) {
       int ltx=0, lty=0, rbx=0, rby=0;
 
       HighLightReverse();
       PrepareToReplaceAnObj(poly_obj);
-      v[index].x = cx;
-      v[index].y = cy;
+      if (poly_obj->ctm == NULL) {
+         v[index].x = cx;
+         v[index].y = cy;
+      } else {
+         ReverseTransformPointThroughCTM(cx-poly_obj->x, cy-poly_obj->y,
+               poly_obj->ctm, &tmp_x, &tmp_y);
+         v[index].x = tmp_x+poly_obj->x;
+         v[index].y = tmp_y+poly_obj->y;
+      }
       AdjObjSplineVs(poly_obj);
       if (poly_obj->detail.p->curved != LT_INTSPLINE) {
          UpdPolyBBox(poly_obj, num_pts, v);
