@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/arc.c,v 3.45 1998/11/05 22:56:05 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/arc.c,v 3.7 1996/09/14 20:43:03 william Exp $";
-#endif
 
 #include <math.h>
 #include <stdio.h>
@@ -63,6 +62,7 @@ static char RCSid[] =
 #include "poly.e"
 #include "ps.e"
 #include "raster.e"
+#include "rect.e"
 #include "ruler.e"
 #include "select.e"
 #include "setup.e"
@@ -71,6 +71,8 @@ static char RCSid[] =
 #include "util.e"
 #include "xpixmap.e"
 
+extern int atoi ARGS_DECL((char*));
+
 #define EXPAND_BBOX(bbox,x,y) \
    if ((x)<(bbox)->ltx) (bbox)->ltx=(x); if ((y)<(bbox)->lty) (bbox)->lty=(y); \
    if ((x)>(bbox)->rbx) (bbox)->rbx=(x); if ((y)>(bbox)->rby) (bbox)->rby=(y)
@@ -269,7 +271,7 @@ void GetArcArrowInfo(obj_ptr, ptip_vs1, ptail_vs1, vs1, pa_angle1,
     */
 {
    struct ArcRec *arc_ptr=obj_ptr->detail.a;
-   int i, style=arc_ptr->style, a_angle1, a_angle2, angle90, angle360;
+   int style=arc_ptr->style, a_angle1, a_angle2, angle90, angle360;
    int x1, y1, x2, y2, int_dx, int_dy, x, y, angle1, angle2, dir, w, h, aw, ah;
    double dx, dy, angle_in_radian, theta1, theta2;
    IntPoint tip_vs1, tail_vs1, tip_vs2, tail_vs2;
@@ -655,6 +657,9 @@ void DumpArcPath(FP,ObjPtr,xc,yc,xr,yr,dir,angle1,angle2,width,pen,dash)
    int xc, yc, xr, yr, dir, angle1, angle2, width, pen, dash;
 {
    register int i;
+   int w_is_int=TRUE;
+   char *width_spec=ObjPtr->detail.a->width_spec;
+   double dw=GetWidthInDouble(width, width_spec, &w_is_int);
 
    fprintf(FP, "   gsave\n");
    if (!colorDump && useGray && pen > BACKPAT) {
@@ -667,7 +672,11 @@ void DumpArcPath(FP,ObjPtr,xc,yc,xr,yr,dir,angle1,angle2,width,pen,dash)
    if (ObjPtr->ctm != NULL) {
       fprintf(FP, "      tgiforigctm setmatrix\n");
    }
-   if (width != 1) fprintf(FP, "      %1d setlinewidth\n", width);
+   if (w_is_int) {
+      if (width != 1) fprintf(FP, "      %1d setlinewidth\n", width);
+   } else {
+      fprintf(FP, "      %.3f setlinewidth\n", dw);
+   }
    if (dash != 0) {
       fprintf(FP, "      [");
       for (i = 0; i < dashListLength[dash]-1; i++) {
@@ -1043,10 +1052,9 @@ void MakeCachedArc(ObjPtr)
    struct ObjRec *ObjPtr;
 {
    struct ArcRec *arc_ptr=ObjPtr->detail.a;
-   XPoint *sv=NULL;
-   IntPoint *pv, *cntrlv=NULL, tmp_vs[25];
+   IntPoint tmp_vs[25];
    struct BBRec obbox;
-   int i, cx, cy, v_index, cur_index, angle, a_angle1, a_angle2;
+   int i, cx, cy, a_angle1, a_angle2;
    double hw, hh; /* half w and half h */
 
    if (!arcXYMagInitialized) {
@@ -1598,6 +1606,13 @@ void ReadArcObj(FP, Inbuf, ObjPtr)
    int aw=origArrowHeadW[0], ah=origArrowHeadH[0];
    int xc, yc, x1, y1, x2, y2, dir, angle1, angle2;
    int invisible=FALSE, transformed=FALSE;
+#ifdef _TGIF_WB
+ 
+   char                 aux[10000];
+ 
+   strcpy(aux,Inbuf);
+ 
+#endif /* _TGIF_WB */
 
    *ObjPtr = NULL;
 
@@ -1907,7 +1922,20 @@ void ReadArcObj(FP, Inbuf, ObjPtr)
       char inbuf[MAXSTRING+1];
       struct XfrmMtrxRec *ctm;
 
+#ifdef _TGIF_WB
+ 
+      s = FindChar ((int)'[', aux);
+      s++;
+      if (!bufferAsFileForWhiteBoard) {
+         fgets(inbuf, MAXSTRING, FP);
+      }
+ 
+#else /* ~_TGIF_WB */
+ 
       fgets(inbuf, MAXSTRING, FP);
+ 
+#endif /* _TGIF_WB */
+
       scanLineNum++;
       InitScan(inbuf, "\t\n, ");
 
