@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/attr.c,v 3.40 1998/11/05 22:56:06 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/attr.c,v 3.1 1996/05/24 22:37:40 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -208,6 +207,7 @@ void UpdateAttr (TextPtr, AttrPtr)
       DynStrSet (&TextPtr->first->dyn_str, value);
    }
    UpdTextBBox (AttrPtr->obj);
+   AdjObjCache (AttrPtr->obj);
 }
 
 void DrawAttrs (Win, XOff, YOff, AttrPtr)
@@ -406,93 +406,79 @@ void AddAttr (ObjPtr, TextObjPtr)
    ObjPtr->lattr = botAttr;
 }
 
-void AddAttrs ()
+void AddAttrs()
 {
-   struct ObjRec	* owner_ptr = NULL;
-   struct SelRec	* sel_ptr;
-   int			text_count=0, sel_ltx, sel_lty, sel_rbx, sel_rby;
-   int			locked_text_count=0;
+   struct ObjRec *owner_ptr=NULL;
+   struct SelRec *sel_ptr;
+   int text_count=0, sel_ltx, sel_lty, sel_rbx, sel_rby;
+   int locked_text_count=0;
 
-   if (topSel == NULL)
-   {
-      MsgBox ("Must select at least one text object.", TOOL_NAME, INFO_MB);
+   if (topSel == NULL) {
+      MsgBox("Must select at least one text object.", TOOL_NAME, INFO_MB);
       return;
    }
-   for (sel_ptr = topSel; sel_ptr != NULL; sel_ptr = sel_ptr->next)
-      switch (sel_ptr->obj->type)
-      {
-         case OBJ_TEXT: text_count++; break;
+   for (sel_ptr=topSel; sel_ptr != NULL; sel_ptr=sel_ptr->next) {
+      switch (sel_ptr->obj->type) {
+      case OBJ_TEXT: text_count++; break;
 
-         case OBJ_BOX:
-         case OBJ_OVAL:
-         case OBJ_POLYGON:
-         case OBJ_POLY:
-         case OBJ_SYM:
-         case OBJ_GROUP:
-         case OBJ_ICON:
-         case OBJ_ARC:
-         case OBJ_RCBOX:
-         case OBJ_XBM:
-         case OBJ_XPM:
-            if (owner_ptr != NULL)
-            {
-               Msg("Two non-text objects selected.");
-               return;
-            }
-            owner_ptr = sel_ptr->obj;
-            break; 
+      default:
+         if (owner_ptr != NULL) {
+            Msg("Two non-text objects selected.");
+            return;
+         }
+         owner_ptr = sel_ptr->obj;
+         break; 
       }
- 
-   if (text_count == 0)
-   {
-      MsgBox ("No text objects selected to add as attributes.",
+   }
+
+   if (text_count == 0) {
+      MsgBox("No text objects selected to add as attributes.",
             TOOL_NAME, INFO_MB);
       return;
    }
-   if (owner_ptr == NULL)
-   {
-      MsgBox ("No objects (other than TEXT objects) selected.",
+   if (owner_ptr == NULL) {
+      MsgBox("No objects (other than TEXT objects) selected.",
             TOOL_NAME, INFO_MB);
       return;
    }
-   HighLightReverse ();
-   PrepareToRecord (CMD_REPLACE, topSel, botSel, numObjSelected);
+   HighLightReverse();
+   PrepareToRecord(CMD_REPLACE, topSel, botSel, numObjSelected);
    sel_ltx = selLtX; sel_lty = selLtY;
    sel_rbx = selRbX; sel_rby = selRbY;
 
-   for (sel_ptr = botSel;  sel_ptr != NULL; sel_ptr = sel_ptr->prev)
-      if (sel_ptr->obj->type == OBJ_TEXT)
-      {
-         if (sel_ptr->obj->locked)
-         {
+   for (sel_ptr=botSel;  sel_ptr != NULL; sel_ptr=sel_ptr->prev) {
+      if (sel_ptr->obj->type == OBJ_TEXT) {
+         if (sel_ptr->obj->locked) {
             locked_text_count++;
             sel_ptr->obj->locked = FALSE;
          }
          AddAttr(owner_ptr, sel_ptr->obj);
       }
+   }
 
-   RemoveAllSel ();
-   UnlinkObj (owner_ptr);
-   AddObj (NULL, topObj, owner_ptr);
+   RemoveAllSel();
+   UnlinkObj(owner_ptr);
+   AddObj(NULL, topObj, owner_ptr);
    topSel = botSel = (struct SelRec *)malloc(sizeof(struct SelRec));
-   if (topSel == NULL) FailAllocMessage ();
+   if (topSel == NULL) FailAllocMessage();
    topSel->obj = owner_ptr;
    topSel->prev = NULL;
    botSel->next = NULL;
-   AdjObjBBox (owner_ptr);
-   UpdSelBBox ();
-   RecordCmd (CMD_MANY_TO_ONE, NULL, topSel, botSel, 1);
-   RedrawAreas (botObj, sel_ltx-GRID_ABS_SIZE(1), sel_lty-GRID_ABS_SIZE(1),
+   AdjObjBBox(owner_ptr);
+   UpdSelBBox();
+   RecordCmd(CMD_MANY_TO_ONE, NULL, topSel, botSel, 1);
+   RedrawAreas(botObj, sel_ltx-GRID_ABS_SIZE(1), sel_lty-GRID_ABS_SIZE(1),
          sel_rbx+GRID_ABS_SIZE(1), sel_rby+GRID_ABS_SIZE(1),
          selLtX-GRID_ABS_SIZE(1), selLtY-GRID_ABS_SIZE(1),
          selRbX+GRID_ABS_SIZE(1), selRbY+GRID_ABS_SIZE(1));
-   HighLightForward ();
-   SetFileModified (TRUE);
+   HighLightForward();
+   SetFileModified(TRUE);
    justDupped = FALSE;
-   if (locked_text_count==0)
-      Msg ("Text object(s) attached.");
-   else
-      Msg ("Text object(s) unlocked and attached.");
+   if (locked_text_count==0) {
+      Msg("Text object(s) attached.");
+   } else {
+      Msg("Text object(s) unlocked and attached.");
+   }
 }
 
 static
@@ -575,7 +561,7 @@ int ReadAttr (FP, AttrPtr)
    struct AttrRec	* * AttrPtr;
 {
    struct ObjRec	* TextObj;
-   char			* s, * line, * c_ptr;
+   char			* s, * line;
    char			* name, * value;
    int			len, shown, nameshown, inherited;
  
@@ -662,28 +648,52 @@ int ObjMightChangeForShowAndUpdAttrNames (ObjPtr)
 }
 
 static
-void UpdateFirstTextStringWithAttrNameAndValue (ObjPtr, AttrPtr)
-   struct ObjRec	* ObjPtr;
-   struct AttrRec	* AttrPtr;
+void GetFirstTextStringWithAttrNameAndValue(ObjPtr, AttrPtr, pszBuf, cbBuf)
+   struct ObjRec *ObjPtr;
+   struct AttrRec *AttrPtr;
+   char *pszBuf;
+   int cbBuf;
 {
-   int			len1, len2;
-   char			s[MAXSTRING+1], msg[80];
-   struct DynStrRec	* dest_dyn_str=(&ObjPtr->detail.t->first->dyn_str);
-
-   DynStrCpy (dest_dyn_str, &AttrPtr->attr_name);
+   int len1, len2;
+   char s[MAXSTRING+1];
 
    len1 = AttrPtr->attr_name.sz-1;
    len2 = AttrPtr->attr_value.sz-1;
-   if (len1+len2 >= MAXSTRING)
-   {
-      sprintf (msg, "String length exceeds %1d.  %s.",
+   if (len1+len2 >= MAXSTRING) {
+      char saved_ch=AttrPtr->attr_value.s[MAXSTRING-len1];
+
+      AttrPtr->attr_value.s[MAXSTRING-len1] = '\0';
+      AttrPtr->attr_value.sz = MAXSTRING-len1+1;
+      sprintf(s, "%s%s", AttrPtr->attr_name.s, AttrPtr->attr_value.s);
+      AttrPtr->attr_value.s[MAXSTRING-len1] = saved_ch;
+   } else {
+      sprintf(s, "%s%s", AttrPtr->attr_name.s, AttrPtr->attr_value.s);
+   }
+   strncpy(pszBuf, s, cbBuf);
+}
+
+static
+void UpdateFirstTextStringWithAttrNameAndValue(ObjPtr, AttrPtr)
+   struct ObjRec *ObjPtr;
+   struct AttrRec *AttrPtr;
+{
+   int len1=0, len2=0;
+   char buf[MAXSTRING+1];
+   struct DynStrRec *dest_dyn_str=(&ObjPtr->detail.t->first->dyn_str);
+
+   DynStrCpy(dest_dyn_str, &AttrPtr->attr_name);
+
+   len1 = AttrPtr->attr_name.sz-1;
+   len2 = AttrPtr->attr_value.sz-1;
+   if (len1+len2 >= MAXSTRING) {
+      sprintf(gszMsgBox, "String length exceeds %1d.  %s.",
             MAXSTRING, "String truncated");
-      Msg (msg);
+      Msg(gszMsgBox);
       AttrPtr->attr_value.s[MAXSTRING-len1] = '\0';
       AttrPtr->attr_value.sz = MAXSTRING-len1+1;
    }
-   sprintf (s, "%s%s", dest_dyn_str->s, AttrPtr->attr_value.s);
-   DynStrSet (dest_dyn_str, s);
+   sprintf(buf, "%s%s", dest_dyn_str->s, AttrPtr->attr_value.s);
+   DynStrSet(dest_dyn_str, buf);
 }
 
 static
@@ -1034,39 +1044,35 @@ void DetachAllObjAttrs(obj_ptr, TopSelPtr, BotSelPtr)
    obj_ptr->fattr = obj_ptr->lattr = NULL;
 }
 
-void DetachAttrs ()
+void DetachAttrs()
 {
-   struct SelRec	* sel_ptr, * new_sel_ptr;
-   struct ObjRec	* obj_ptr;
-   struct AttrRec	* attr_ptr, * next_attr;
-   int			picture_changed=FALSE, name_changed=FALSE;
+   struct SelRec *sel_ptr, *new_sel_ptr;
+   struct ObjRec *obj_ptr;
+   struct AttrRec *attr_ptr, *next_attr;
+   int picture_changed=FALSE, name_changed=FALSE;
 
-   HighLightReverse ();
-   StartCompositeCmd ();
+   HighLightReverse();
+   StartCompositeCmd();
 
-   for (sel_ptr = topSel; sel_ptr != NULL; sel_ptr = sel_ptr->next)
-   {
+   for (sel_ptr=topSel; sel_ptr != NULL; sel_ptr=sel_ptr->next) {
       obj_ptr = sel_ptr->obj;
       attr_ptr = obj_ptr->fattr;
-      if (attr_ptr != NULL)
-      {
-         int	obj_change = FALSE;
+      if (attr_ptr != NULL) {
+         int obj_change=FALSE;
 
-         for ( ; attr_ptr != NULL; attr_ptr = attr_ptr->next)
-            if (!attr_ptr->inherited)
-            {
+         for ( ; attr_ptr != NULL; attr_ptr=attr_ptr->next) {
+            if (!attr_ptr->inherited) {
                obj_change = TRUE;
                break;
             }
+         }
+         if (obj_change) {
+            struct SelRec *tmp_top_sel, *tmp_bot_sel;
+            struct SelRec *tmp_sel_ptr, *next_sel;
+            int count;
 
-         if (obj_change)
-         {
-            struct SelRec	* tmp_top_sel, * tmp_bot_sel;
-            struct SelRec	* tmp_sel_ptr, * next_sel;
-            int			count;
-
-            PrepareToReplaceAnObj (obj_ptr);
-            if (DoShowAndUpdAttrNames (obj_ptr, FALSE)) name_changed = TRUE;
+            PrepareToReplaceAnObj(obj_ptr);
+            if (DoShowAndUpdAttrNames(obj_ptr, FALSE)) name_changed = TRUE;
 
             tmp_top_sel = tmp_bot_sel = (struct SelRec *)malloc(
                   sizeof(struct SelRec));
@@ -1076,28 +1082,23 @@ void DetachAttrs ()
             count = 1;
 
             topAttr = botAttr = NULL;
-            for (attr_ptr=obj_ptr->fattr; attr_ptr!=NULL; attr_ptr=next_attr)
-            {
+            for (attr_ptr=obj_ptr->fattr; attr_ptr!=NULL; attr_ptr=next_attr) {
                next_attr = attr_ptr->next;
-               if (obj_ptr->type == OBJ_ICON && attr_ptr->inherited)
-               {
-                  LinkInAttr ((struct AttrRec *)NULL, topAttr, attr_ptr);
+               if (obj_ptr->type == OBJ_ICON && attr_ptr->inherited) {
+                  LinkInAttr((struct AttrRec *)NULL, topAttr, attr_ptr);
                   continue;
                }
                picture_changed = TRUE;
 
                tmp_sel_ptr = (struct SelRec *)malloc(sizeof(struct SelRec));
-               if (tmp_sel_ptr == NULL) FailAllocMessage ();
+               if (tmp_sel_ptr == NULL) FailAllocMessage();
                tmp_sel_ptr->next = tmp_bot_sel;
                tmp_sel_ptr->obj = attr_ptr->obj;
-               if (tmp_top_sel == tmp_bot_sel)
-               {
+               if (tmp_top_sel == tmp_bot_sel) {
                   tmp_sel_ptr->prev = NULL;
                   tmp_top_sel->prev = tmp_sel_ptr;
                   tmp_top_sel = tmp_sel_ptr;
-               }
-               else
-               {
+               } else {
                   tmp_sel_ptr->prev = tmp_bot_sel->prev;
                   tmp_bot_sel->prev->next = tmp_sel_ptr;
                   tmp_bot_sel->prev = tmp_sel_ptr;
@@ -1105,17 +1106,17 @@ void DetachAttrs ()
                count++;
 
                attr_ptr->obj->detail.t->attr = NULL;
-               AddObj (obj_ptr->prev, obj_ptr, attr_ptr->obj);
+               AddObj(obj_ptr->prev, obj_ptr, attr_ptr->obj);
                new_sel_ptr = (struct SelRec *)malloc(sizeof(struct SelRec));
-               if (new_sel_ptr == NULL) FailAllocMessage ();
+               if (new_sel_ptr == NULL) FailAllocMessage();
                new_sel_ptr->obj = obj_ptr->prev;
                AddSel(sel_ptr->prev, sel_ptr, new_sel_ptr);
                free(attr_ptr);
             }
             obj_ptr->fattr = topAttr;
             obj_ptr->lattr = botAttr;
-            AdjObjBBox (obj_ptr);
-            RecordCmd (CMD_ONE_TO_MANY, NULL, tmp_top_sel, tmp_bot_sel, count);
+            AdjObjBBox(obj_ptr);
+            RecordCmd(CMD_ONE_TO_MANY, NULL, tmp_top_sel, tmp_bot_sel, count);
 
             for (tmp_sel_ptr=tmp_top_sel; tmp_sel_ptr!=NULL;
                   tmp_sel_ptr=next_sel) {
@@ -1125,26 +1126,26 @@ void DetachAttrs ()
          }
       }
    }
-   EndCompositeCmd ();
-   UpdSelBBox ();
-   if (picture_changed || name_changed)
-   {
-      RedrawAnArea (botObj, selLtX-GRID_ABS_SIZE(1),
+   EndCompositeCmd();
+   UpdSelBBox();
+   if (picture_changed || name_changed) {
+      RedrawAnArea(botObj, selLtX-GRID_ABS_SIZE(1),
             selLtY-GRID_ABS_SIZE(1), selRbX+GRID_ABS_SIZE(1),
             selRbY+GRID_ABS_SIZE(1));
-      SetFileModified (TRUE);
+      SetFileModified(TRUE);
    }
-   HighLightForward ();
+   HighLightForward();
 }
 
-void UpdAttr (AttrPtr)
-   struct AttrRec	* AttrPtr;
+void UpdAttr(AttrPtr)
+   struct AttrRec *AttrPtr;
    /* Update the text object's string value associated with AttrPtr */
 {
-   if (AttrPtr->nameshown)
-      UpdateFirstTextStringWithAttrNameAndValue (AttrPtr->obj, AttrPtr);
-   else
-      DynStrCpy (&AttrPtr->obj->detail.t->first->dyn_str, &AttrPtr->attr_value);
+   if (AttrPtr->nameshown) {
+      UpdateFirstTextStringWithAttrNameAndValue(AttrPtr->obj, AttrPtr);
+   } else {
+      DynStrCpy(&AttrPtr->obj->detail.t->first->dyn_str, &AttrPtr->attr_value);
+   }
    UpdTextBBox(AttrPtr->obj);
 }
 
@@ -1231,6 +1232,7 @@ int MoveOneAttr (ObjPtr, AttrPtr)
       else if (input.type == ButtonPress)
       {
          XUngrabPointer (mainDisplay, CurrentTime);
+         XSync(mainDisplay, False);
          placing = FALSE;
          SelBox (drawWindow, revDefaultGC, ltx+dx, lty+dy, rbx+dx, rby+dy);
          PixelToMeasurementUnit(x_buf, ABS_SIZE(dx));
@@ -1364,6 +1366,7 @@ int ChangeAttrJust (ObjPtr, AttrPtr)
       else if (input.type == ButtonPress)
       {
          XUngrabPointer (mainDisplay, CurrentTime);
+         XSync(mainDisplay, False);
          placing = FALSE;
          SelBox (drawWindow, revDefaultGC, ltx+dx, lty+dy, rbx+dx, rby+dy);
          EndShowMeasureCursor (ltx+dx, lty+dy, NULL, TRUE);
@@ -1400,7 +1403,7 @@ void MoveAttr ()
    int			sel_ltx, sel_lty, sel_rbx, sel_rby;
    int			* fore_colors, * pixel_ptr, * valid, * flag_ptr;
    int			* init_rv;
-   char			* * attrStrs, * s, buf[MAXSTRING];
+   char			* * attrStrs, buf[MAXSTRING];
    unsigned int		button;
 
    if (topSel != botSel || topSel == NULL)
@@ -1424,12 +1427,12 @@ void MoveAttr ()
    attr_ptr1 = attr_ptr;
    for (i = 0; i < num_attrs; i++, attr_ptr1 = attr_ptr1->next)
    {
-      s = (char*)malloc((MAXSTRING+1)*sizeof(char));
-      if (s == NULL) FailAllocMessage();
-      attrStrs[i] = s;
+      char buf[MAXSTRING];
 
-      UpdateFirstTextStringWithAttrNameAndValue (attr_ptr1->obj, attr_ptr1);
-      strcpy (s, attr_ptr1->obj->detail.t->first->dyn_str.s);
+      *buf = '\0';
+      GetFirstTextStringWithAttrNameAndValue(attr_ptr1->obj, attr_ptr1,
+            buf, sizeof(buf));
+      if ((attrStrs[i]=UtilStrDup(buf)) == NULL) FailAllocMessage();
 
       *pixel_ptr++ = colorPixels[attr_ptr1->obj->color];
       *flag_ptr++ = TRUE;
@@ -1482,7 +1485,7 @@ void MoveAttr ()
       }
    }
 
-   for (i = 0; i < num_attrs; i++) free(attrStrs[i]);
+   for (i = 0; i < num_attrs; i++) UtilFree(attrStrs[i]);
    free(attrStrs);
    justDupped = FALSE;
 }
@@ -1699,7 +1702,6 @@ void DetachFileAttrs ()
    justDupped = FALSE;
 }
 
-static XComposeStatus	c_stat;
 static DspList		* fileAttrNameDspPtr=NULL;
 
 static
