@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/choice.c,v 3.58 1998/11/05 22:56:07 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/choice.c,v 3.8 1997/01/30 05:52:48 william Exp $";
-#endif
 
 #include <math.h>
 #include <stdio.h>
@@ -268,69 +267,69 @@ void UpdateAbcBitmap()
    rotatedAbcBBox.rbx = rbx; rotatedAbcBBox.rby = rby;
 }
 
-void ShowWhereToPrint ()
+void ShowWhereToPrint()
 {
-   if (colorDump)
-      XSetForeground (mainDisplay, rasterGC, colorPixels[colorIndex]);
-   XSetStipple (mainDisplay, rasterGC, whereToPrintPixmap[whereToPrint]);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC, PRINT_COL*choiceImageW,
+   if (colorDump) {
+      XSetForeground(mainDisplay, rasterGC, colorPixels[colorIndex]);
+   }
+   XSetStipple(mainDisplay, rasterGC, whereToPrintPixmap[whereToPrint]);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC, PRINT_COL*choiceImageW,
          PRINT_ROW*choiceImageH, choiceImageW, choiceImageH);
-   if (colorDump) XSetForeground (mainDisplay, rasterGC, myFgPixel);
+   if (colorDump) XSetForeground(mainDisplay, rasterGC, myFgPixel);
 }
 
-void ShowMode ()
+void ShowMode()
 {
-   XSetStipple (mainDisplay, rasterGC, choicePixmap[curChoice]);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC, MODE_COL*choiceImageW,
+   XSetStipple(mainDisplay, rasterGC, choicePixmap[curChoice]);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC, MODE_COL*choiceImageW,
          MODE_ROW*choiceImageH, choiceImageW, choiceImageH);
 }
 
-void ShowColor (PropagateWhereToPrint)
+void ShowColor(PropagateWhereToPrint)
    int PropagateWhereToPrint;
 {
    XGCValues values;
 
-   if (colorDisplay)
-   {
+   if (colorDisplay) {
       values.foreground = colorPixels[colorIndex];
       values.function = GXcopy;
       values.fill_style = FillOpaqueStippled;
       values.stipple = patPixmap[1];
-      XChangeGC (mainDisplay, patGC,
+      XChangeGC(mainDisplay, patGC,
             GCForeground | GCFunction | GCFillStyle | GCStipple, &values);
 
-      XFillRectangle (mainDisplay, choiceWindow, patGC,
+      XFillRectangle(mainDisplay, choiceWindow, patGC,
             COLOR_COL*choiceImageW, COLOR_ROW*choiceImageH,
             choiceImageW, choiceImageH);
    }
-   if (PropagateWhereToPrint) ShowWhereToPrint ();
+   if (PropagateWhereToPrint) ShowWhereToPrint();
 }
 
-void ShowHoriAlign ()
+void ShowHoriAlign()
 {
-   XSetStipple (mainDisplay, rasterGC, alignHoriPixmap[horiAlign]);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC,
+   XSetStipple(mainDisplay, rasterGC, alignHoriPixmap[horiAlign]);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC,
          HORI_ALIGN_COL*choiceImageW, HORI_ALIGN_ROW*choiceImageH,
          choiceImageW, choiceImageH);
 }
 
-void ShowVertAlign ()
+void ShowVertAlign()
 {
-   XSetStipple (mainDisplay, rasterGC, alignVertPixmap[vertAlign]);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC,
+   XSetStipple(mainDisplay, rasterGC, alignVertPixmap[vertAlign]);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC,
          VERT_ALIGN_COL*choiceImageW, VERT_ALIGN_ROW*choiceImageH,
          choiceImageW, choiceImageH);
 }
 
-void ShowJust ()
+void ShowJust()
 {
-   XSetStipple (mainDisplay, rasterGC, justPixmap[textJust]);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC,
+   XSetStipple(mainDisplay, rasterGC, justPixmap[textJust]);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC,
          JUST_COL*choiceImageW, JUST_ROW*choiceImageH,
          choiceImageW, choiceImageH);
 }
 
-void ShowCurFont ()
+void ShowCurFont()
 {
    int x, y, w, h;
    XRectangle recs[1];
@@ -341,7 +340,7 @@ void ShowCurFont ()
    recs[0].width = choiceImageW;
    recs[0].height = choiceImageH;
 
-   w = XTextWidth (canvasFontPtr, "W", 1);
+   w = XTextWidth(canvasFontPtr, "W", 1);
    h = canvasFontHeight;
 
    x = (w > choiceImageW) ?
@@ -351,115 +350,114 @@ void ShowCurFont ()
          FONT_ROW*choiceImageH + (canvasFontAsc-(h-choiceImageH)/2) :
          FONT_ROW*choiceImageH + (canvasFontAsc+(choiceImageH-h)/2);
 
-   XClearArea (mainDisplay, choiceWindow, FONT_COL*choiceImageW,
+   XClearArea(mainDisplay, choiceWindow, FONT_COL*choiceImageW,
          FONT_ROW*choiceImageH, choiceImageW, choiceImageH, FALSE);
 
-   XSetFont (mainDisplay, choiceGC, canvasFontPtr->fid);
-   XSetClipRectangles (mainDisplay, choiceGC, 0, 0, recs, 1, YXBanded);
+   XSetFont(mainDisplay, choiceGC, canvasFontPtr->fid);
+   XSetClipRectangles(mainDisplay, choiceGC, 0, 0, recs, 1, YXBanded);
 
    values.foreground = myFgPixel;
    values.background = myBgPixel;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground, &values);
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground, &values);
 
-   XDrawString (mainDisplay, choiceWindow, choiceGC, x, y, "W", 1);
+   XDrawString(mainDisplay, choiceWindow, choiceGC, x, y, "W", 1);
 
    values.foreground = xorOne;
    values.background = xorZero;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground, &values);
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground, &values);
 
    recs[0].x = 0;
    recs[0].y = 0;
    recs[0].width = choiceWindowW;
    recs[0].height = choiceWindowH;
-   XSetClipRectangles (mainDisplay, choiceGC, 0, 0, recs, 1, YXBanded);
+   XSetClipRectangles(mainDisplay, choiceGC, 0, 0, recs, 1, YXBanded);
 }
 
-void ShowTextVSpace ()
+void ShowTextVSpace()
 {
    int len, x, y;
    char s[80];
    XGCValues values;
 
-   XSetStipple (mainDisplay, rasterGC, vspacePixmap);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC, VSPACE_COL*choiceImageW,
+   XSetStipple(mainDisplay, rasterGC, vspacePixmap);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC, VSPACE_COL*choiceImageW,
          VSPACE_ROW*choiceImageH, choiceImageW, choiceImageH);
-   sprintf (s, "%1d", textVSpace);
-   len = strlen (s);
+   sprintf(s, "%1d", textVSpace);
+   len = strlen(s);
    x = (int)((VSPACE_COL+0.5)*choiceImageW-2);
    y = VSPACE_ROW*choiceImageH+((choiceImageH-rulerFontAsc)>>1)+rulerFontAsc;
 
    values.foreground = myFgPixel;
    values.background = myBgPixel;
    values.font = rulerFontPtr->fid;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground | GCFont,
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground | GCFont,
          &values);
 
-   XDrawString (mainDisplay, choiceWindow, choiceGC, x, y, s, len);
+   XDrawString(mainDisplay, choiceWindow, choiceGC, x, y, s, len);
 
    values.foreground = xorOne;
    values.background = xorZero;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground, &values);
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground, &values);
 }
 
-void ShowZoom ()
+void ShowZoom()
 {
    int len, x, y, w, x_w, one_w;
    char s[80];
    XGCValues values;
 
-   XClearArea (mainDisplay, choiceWindow, ZOOM_COL*choiceImageW,
+   XClearArea(mainDisplay, choiceWindow, ZOOM_COL*choiceImageW,
       ZOOM_ROW*choiceImageH, choiceImageW, choiceImageH, FALSE);
 
-   sprintf (s, "x%1d", 1<<zoomScale);
-   len = strlen (s);
+   sprintf(s, "x%1d", 1<<zoomScale);
+   len = strlen(s);
 
-   w = XTextWidth (rulerFontPtr, s, len)+1;
-   x_w = XTextWidth (rulerFontPtr, "x", 1)+1;
-   one_w = XTextWidth (rulerFontPtr, "1", 1);
+   w = XTextWidth(rulerFontPtr, s, len)+1;
+   x_w = XTextWidth(rulerFontPtr, "x", 1)+1;
+   one_w = XTextWidth(rulerFontPtr, "1", 1);
    x = ZOOM_COL*choiceImageW+((choiceImageW-w)>>1);
    y = ZOOM_ROW*choiceImageH+((choiceImageH-rulerFontAsc)>>1)+rulerFontAsc;
 
    values.foreground = myFgPixel;
    values.background = myBgPixel;
    values.font = rulerFontPtr->fid;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground | GCFont,
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground | GCFont,
          &values);
 
-   XDrawString (mainDisplay, choiceWindow, choiceGC, x, y, "x", 1);
+   XDrawString(mainDisplay, choiceWindow, choiceGC, x, y, "x", 1);
 
    x += x_w;
-   sprintf (s, "%1d", 1<<zoomScale);
+   sprintf(s, "%1d", 1<<zoomScale);
    len--;
-   if (zoomedIn || zoomScale==0)
-      XDrawString (mainDisplay, choiceWindow, choiceGC, x, y, s, len);
-   else
-   {
+   if (zoomedIn || zoomScale==0) {
+      XDrawString(mainDisplay, choiceWindow, choiceGC, x, y, s, len);
+   } else {
       y = ZOOM_ROW*choiceImageH + (choiceImageH>>1);
-      XDrawString (mainDisplay, choiceWindow, choiceGC, x+((w-x_w-one_w)>>1),
+      XDrawString(mainDisplay, choiceWindow, choiceGC, x+((w-x_w-one_w)>>1),
             y-2, "1", 1);
-      XDrawLine (mainDisplay, choiceWindow, choiceGC, x, y, x+(w-x_w-1), y);
-      XDrawString (mainDisplay, choiceWindow, choiceGC, x, y+rulerFontAsc,
+      XDrawLine(mainDisplay, choiceWindow, choiceGC, x, y, x+(w-x_w-1), y);
+      XDrawString(mainDisplay, choiceWindow, choiceGC, x, y+rulerFontAsc,
             s, len);
    }
 
    values.foreground = xorOne;
    values.background = xorZero;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground, &values);
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground, &values);
 }
 
-void ShowTextSize ()
+void ShowTextSize()
 {
    int len, x, y, w;
    char s[80];
    XGCValues values;
 
-   XClearArea (mainDisplay, choiceWindow, TEXT_SIZE_COL*choiceImageW,
+   XClearArea(mainDisplay, choiceWindow, TEXT_SIZE_COL*choiceImageW,
          TEXT_SIZE_ROW*choiceImageH, choiceImageW, choiceImageH, FALSE);
-   sprintf (s, "%1d",
+   sprintf(s, "%1d",
          (curChoice == DRAWTEXT && editingText && editTextSize != 0 &&
          savedEditTextSize != (-1)) ? savedEditTextSize : curSize);
-   len = strlen (s);
-   w = XTextWidth (defaultFontPtr, s, len);
+   len = strlen(s);
+   w = XTextWidth(defaultFontPtr, s, len);
    x = TEXT_SIZE_COL*choiceImageW + ((choiceImageW-w)>>1);
    y = TEXT_SIZE_ROW*choiceImageH + ((choiceImageH-defaultFontAsc)>>1) + 
          defaultFontAsc;
@@ -467,14 +465,14 @@ void ShowTextSize ()
    values.foreground = myFgPixel;
    values.background = myBgPixel;
    values.font = defaultFontPtr->fid;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground | GCFont,
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground | GCFont,
          &values);
 
-   XDrawString (mainDisplay, choiceWindow, choiceGC, x, y, s, len);
+   XDrawString(mainDisplay, choiceWindow, choiceGC, x, y, s, len);
 
    values.foreground = xorOne;
    values.background = xorZero;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground, &values);
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground, &values);
 }
 
 void ShowRotate()
@@ -528,7 +526,7 @@ void ShowRotate()
    values.ts_x_origin = ROTATE_COL*choiceImageW+ltx-x;
    values.ts_y_origin = ROTATE_ROW*choiceImageH+lty-y;
    values.stipple = bitmap;
-   XChangeGC (mainDisplay, patGC,
+   XChangeGC(mainDisplay, patGC,
          GCForeground | GCBackground | GCFunction | GCFillStyle | GCStipple |
          GCTileStipXOrigin | GCTileStipYOrigin, &values);
    XFillRectangle(mainDisplay, choiceWindow, patGC,
@@ -537,10 +535,10 @@ void ShowRotate()
    XSetTSOrigin(mainDisplay, patGC, 0, 0);
 }
 
-void ShowSpecial ()
+void ShowSpecial()
 {
-   XSetStipple (mainDisplay, rasterGC, specialPixmap);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC,
+   XSetStipple(mainDisplay, rasterGC, specialPixmap);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC,
          SPECIAL_COL*choiceImageW, SPECIAL_ROW*choiceImageH,
          choiceImageW, choiceImageH);
 }
@@ -576,98 +574,97 @@ void ShowLineWidth()
    XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground, &values);
 }
 
-void ShowLineStyle ()
+void ShowLineStyle()
 {
-   XSetStipple (mainDisplay, rasterGC, shortLineStylePixmap[lineStyle]);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC,
+   XSetStipple(mainDisplay, rasterGC, shortLineStylePixmap[lineStyle]);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC,
          LINE_STYLE_COL*choiceImageW, LINE_STYLE_ROW*choiceImageH,
          choiceImageW, choiceImageH);
 }
 
-void ShowLineType ()
+void ShowLineType()
 {
-   XSetStipple (mainDisplay, rasterGC, shortLineTypePixmap[curSpline]);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC,
+   XSetStipple(mainDisplay, rasterGC, shortLineTypePixmap[curSpline]);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC,
          LINE_TYPE_COL*choiceImageW, LINE_TYPE_ROW*choiceImageH,
          choiceImageW, choiceImageH);
 }
 
-void ShowDash ()
+void ShowDash()
 {
-   XSetStipple (mainDisplay, rasterGC, shortDashPixmap[curDash]);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC, DASH_COL*choiceImageW,
+   XSetStipple(mainDisplay, rasterGC, shortDashPixmap[curDash]);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC, DASH_COL*choiceImageW,
          DASH_ROW*choiceImageH, choiceImageW, choiceImageH);
 }
 
-void ShowFile ()
+void ShowFile()
 {
-   switch (pageStyle)
-   {
-      case PORTRAIT: XSetStipple(mainDisplay,rasterGC,filePixmap); break;
-      case LANDSCAPE: XSetStipple(mainDisplay,rasterGC,landscapePixmap); break;
+   switch (pageStyle) {
+   case PORTRAIT: XSetStipple(mainDisplay,rasterGC,filePixmap); break;
+   case LANDSCAPE: XSetStipple(mainDisplay,rasterGC,landscapePixmap); break;
    }
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC, FILE_COL*choiceImageW,
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC, FILE_COL*choiceImageW,
          FILE_ROW*choiceImageH, choiceImageW, choiceImageH);
 }
 
-void ShowEdit ()
+void ShowEdit()
 {
-   XSetStipple (mainDisplay, rasterGC, editPixmap);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC, EDIT_COL*choiceImageW,
+   XSetStipple(mainDisplay, rasterGC, editPixmap);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC, EDIT_COL*choiceImageW,
          EDIT_ROW*choiceImageH, choiceImageW, choiceImageH);
 }
 
-void ShowRCBRadius ()
+void ShowRCBRadius()
 {
    int len, x, y;
    char s[80];
    XGCValues values;
 
-   XSetStipple (mainDisplay, rasterGC, rcbRadiusPixmap);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC, RADIUS_COL*choiceImageW,
+   XSetStipple(mainDisplay, rasterGC, rcbRadiusPixmap);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC, RADIUS_COL*choiceImageW,
          RADIUS_ROW*choiceImageH, choiceImageW, choiceImageH);
-   sprintf (s, "%1d", rcbRadius);
-   len = strlen (s);
+   sprintf(s, "%1d", rcbRadius);
+   len = strlen(s);
    x = (int)((RADIUS_COL+0.5)*choiceImageW-2);
    y = (((RADIUS_ROW+1)*choiceImageH-rulerFontAsc)>>1)+rulerFontAsc;
 
    values.foreground = myFgPixel;
    values.background = myBgPixel;
    values.font = rulerFontPtr->fid;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground | GCFont,
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground | GCFont,
          &values);
 
-   XDrawString (mainDisplay, choiceWindow, choiceGC, x, y, s, len);
+   XDrawString(mainDisplay, choiceWindow, choiceGC, x, y, s, len);
 
    values.foreground = xorOne;
    values.background = xorZero;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground, &values);
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground, &values);
 }
 
-void ShowMoveMode ()
+void ShowMoveMode()
 {
-   XSetStipple (mainDisplay, rasterGC, moveModePixmap[moveMode]);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC,
+   XSetStipple(mainDisplay, rasterGC, moveModePixmap[moveMode]);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC,
          MOVE_MODE_COL*choiceImageW, MOVE_MODE_ROW*choiceImageH,
          choiceImageW, choiceImageH);
 }
 
-void ShowShape ()
+void ShowShape()
 {
    XSetStipple(mainDisplay, rasterGC, shapePixmap[STAR_SHAPE]);
    XFillRectangle(mainDisplay, choiceWindow, rasterGC, SHAPE_COL*choiceImageW,
          SHAPE_ROW*choiceImageH, choiceImageW, choiceImageH);
 }
 
-void ShowStretchableTextMode ()
+void ShowStretchableTextMode()
 {
-   XSetStipple (mainDisplay, rasterGC, stretchableModePixmap[stretchableText]);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC,
+   XSetStipple(mainDisplay, rasterGC, stretchableModePixmap[stretchableText]);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC,
          STRETCHTEXT_COL*choiceImageW, STRETCHTEXT_ROW*choiceImageH,
          choiceImageW, choiceImageH);
 }
 
-void ShowFill ()
+void ShowFill()
 {
    XGCValues values;
 
@@ -676,15 +673,15 @@ void ShowFill ()
    values.function = GXcopy;
    values.fill_style = FillOpaqueStippled;
    values.stipple = patPixmap[objFill];
-   XChangeGC (mainDisplay, patGC,
+   XChangeGC(mainDisplay, patGC,
          GCForeground | GCBackground | GCFunction | GCFillStyle | GCStipple,
          &values);
 
-   XFillRectangle (mainDisplay, choiceWindow, patGC, FILL_COL*choiceImageW,
+   XFillRectangle(mainDisplay, choiceWindow, patGC, FILL_COL*choiceImageW,
          FILL_ROW*choiceImageH, choiceImageW, choiceImageH);
 }
 
-void ShowPen ()
+void ShowPen()
 {
    XGCValues values;
 
@@ -693,35 +690,35 @@ void ShowPen ()
    values.function = GXcopy;
    values.fill_style = FillOpaqueStippled;
    values.stipple = patPixmap[penPat];
-   XChangeGC (mainDisplay, patGC,
+   XChangeGC(mainDisplay, patGC,
          GCForeground | GCBackground | GCFunction | GCFillStyle | GCStipple,
          &values);
 
-   XFillRectangle (mainDisplay, choiceWindow, patGC, PEN_COL*choiceImageW,
+   XFillRectangle(mainDisplay, choiceWindow, patGC, PEN_COL*choiceImageW,
          PEN_ROW*choiceImageH, choiceImageW, choiceImageH);
-   if (penPat != NONEPAT)
-      XClearArea (mainDisplay, choiceWindow,
+   if (penPat != NONEPAT) {
+      XClearArea(mainDisplay, choiceWindow,
             PEN_COL*choiceImageW+(choiceImageW>>2),
             PEN_ROW*choiceImageH+(choiceImageH>>2),
             (choiceImageW>>1), (choiceImageH>>1), FALSE);
+   }
 }
 
-void ShowPage ()
+void ShowPage()
 {
-   int                len, x, y, w;
-   char               s[80];
-   XGCValues  values;
+   int len, x, y, w;
+   char s[80];
+   XGCValues values;
 
-   XClearArea (mainDisplay, choiceWindow, PAGE_COL*choiceImageW,
+   XClearArea(mainDisplay, choiceWindow, PAGE_COL*choiceImageW,
       PAGE_ROW*choiceImageH, choiceImageW, choiceImageH, FALSE);
 
-   switch (pageLayoutMode)
-   {
-      case PAGE_STACK: sprintf (s, "%1d/%1d", curPageNum, lastPageNum); break;
-      case PAGE_TILE: sprintf (s, "%1dx%1d", paperCol, paperRow); break;
+   switch (pageLayoutMode) {
+   case PAGE_STACK: sprintf(s, "%1d/%1d", curPageNum, lastPageNum); break;
+   case PAGE_TILE: sprintf(s, "%1dx%1d", paperCol, paperRow); break;
    }
-   len = strlen (s);
-   w = XTextWidth (rulerFontPtr, s, len);
+   len = strlen(s);
+   w = XTextWidth(rulerFontPtr, s, len);
    x = PAGE_COL*choiceImageW+((choiceImageW-w)>>1);
    y = PAGE_ROW*choiceImageH+((choiceImageH-rulerFontAsc)>>1) +
          rulerFontAsc;
@@ -729,23 +726,23 @@ void ShowPage ()
    values.foreground = myFgPixel;
    values.background = myBgPixel;
    values.font = rulerFontPtr->fid;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground | GCFont,
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground | GCFont,
          &values);
 
-   XDrawString (mainDisplay, choiceWindow, choiceGC, x, y, s, len);
+   XDrawString(mainDisplay, choiceWindow, choiceGC, x, y, s, len);
 
    values.foreground = xorOne;
    values.background = xorZero;
-   XChangeGC (mainDisplay, choiceGC, GCForeground | GCBackground,
+   XChangeGC(mainDisplay, choiceGC, GCForeground | GCBackground,
          &values);
 
    RedrawPageWindow();
 }
 
-void ShowPageLayout ()
+void ShowPageLayout()
 {
-   XSetStipple (mainDisplay, rasterGC, pageLayoutPixmap[pageLayoutMode]);
-   XFillRectangle (mainDisplay, choiceWindow, rasterGC,
+   XSetStipple(mainDisplay, rasterGC, pageLayoutPixmap[pageLayoutMode]);
+   XFillRectangle(mainDisplay, choiceWindow, rasterGC,
          PAGELAYOUT_COL*choiceImageW, PAGELAYOUT_ROW*choiceImageH,
          choiceImageW, choiceImageH);
 }
@@ -906,15 +903,14 @@ void SetCurChoice(NewChoice)
 
 static int prevChoice=NOTHING;
 
-void PushCurChoice ()
+void PushCurChoice()
    /* Kouichi Matsuda's modification */
 {
-   if (curChoice == NOTHING)
-      SetCurChoice (prevChoice);
-   else
-   {
+   if (curChoice == NOTHING) {
+      SetCurChoice(prevChoice);
+   } else {
       prevChoice = curChoice;
-      SetCurChoice (NOTHING);
+      SetCurChoice(NOTHING);
    }
 }
 
@@ -963,47 +959,42 @@ void TextVSpaceLoop(button_ev)
 }
 
 static
-void RCBRadiusLoop (button_ev)
+void RCBRadiusLoop(button_ev)
    XButtonEvent *button_ev;
 {
    int saved_rcb_radius = rcbRadius, res=8, done=FALSE;
    int orig_x=button_ev->x, orig_y=button_ev->y, saved_change=0;
    XEvent ev;
 
-   XGrabPointer (mainDisplay, choiceWindow, False,
+   XGrabPointer(mainDisplay, choiceWindow, False,
          PointerMotionMask | ButtonReleaseMask, GrabModeAsync,
          GrabModeAsync, None, handCursor, CurrentTime);
 
-   while (!done)
-   {
-      XNextEvent (mainDisplay, &ev);
+   while (!done) {
+      XNextEvent(mainDisplay, &ev);
 
-      if (ev.type == Expose || ev.type == VisibilityNotify)
-         ExposeEventHandler (&ev, TRUE);
-      else if (ev.type == ButtonRelease)
-      {
-         XUngrabPointer (mainDisplay, CurrentTime);
+      if (ev.type == Expose || ev.type == VisibilityNotify) {
+         ExposeEventHandler(&ev, TRUE);
+      } else if (ev.type == ButtonRelease) {
+         XUngrabPointer(mainDisplay, CurrentTime);
          done = TRUE;
-      }
-      else if (ev.type == MotionNotify)
-      {
+      } else if (ev.type == MotionNotify) {
          int dx=ev.xmotion.x-orig_x, dy=ev.xmotion.y-orig_y;
          int change=((abs(dx)>abs(dy)) ? (int)(dx/res) : (int)(dy/res));
 
-         if (change != saved_change)
-         {
+         if (change != saved_change) {
             rcbRadius = max(MIN_RCB_RADIUS, saved_rcb_radius+change);
-            ShowRCBRadius ();
+            ShowRCBRadius();
             saved_change = change;
          }
-         while (XCheckMaskEvent (mainDisplay, PointerMotionMask, &ev)) ;
+         while (XCheckMaskEvent(mainDisplay, PointerMotionMask, &ev)) ;
       }
    }
-   if (topSel != NULL) ChangeAllSelRCBRadius (rcbRadius);
+   if (topSel != NULL) ChangeAllSelRCBRadius(rcbRadius);
 }
 
 static
-void ZoomLoop (button_ev)
+void ZoomLoop(button_ev)
    XButtonEvent *button_ev;
 {
    int saved_zoomed_in=zoomedIn, saved_zoom_scale=zoomScale, res=8;
@@ -1019,69 +1010,60 @@ void ZoomLoop (button_ev)
    win_h = drawWinH;
    new_zoomed_in = zoomedIn;
    new_zoom_scale = zoomScale;
-   while ((win_w>>1) >= paperWidth && (win_h>>1) >= paperHeight)
-   {
-      if (new_zoomed_in)
+   while ((win_w>>1) >= paperWidth && (win_h>>1) >= paperHeight) {
+      if (new_zoomed_in) {
          new_zoom_scale++;
-      else if (new_zoom_scale == 0)
-      {
+      } else if (new_zoom_scale == 0) {
          new_zoomed_in = TRUE;
          new_zoom_scale++;
-      }
-      else
+      } else {
          new_zoom_scale--;
+      }
       win_w >>= 1;
       win_h >>= 1;
    }
-   while (win_w < paperWidth || win_h < paperHeight)
-   {
-      if (!new_zoomed_in)
+   while (win_w < paperWidth || win_h < paperHeight) {
+      if (!new_zoomed_in) {
          new_zoom_scale++;
-      else if (new_zoom_scale == 1)
-      {
+      } else if (new_zoom_scale == 1) {
          new_zoomed_in = FALSE;
          new_zoom_scale--;
-      }
-      else
+      } else {
          new_zoom_scale--;
+      }
       win_w <<= 1;
       win_h <<= 1;
    }
    max_zoom = (new_zoomed_in) ? (MAX_ZOOMED_IN-new_zoom_scale) :
          (MAX_ZOOMED_IN+new_zoom_scale);
 
-   XGrabPointer (mainDisplay, choiceWindow, False,
+   XGrabPointer(mainDisplay, choiceWindow, False,
          PointerMotionMask | ButtonReleaseMask, GrabModeAsync,
          GrabModeAsync, None, handCursor, CurrentTime);
 
-   while (!done)
-   {
-      XNextEvent (mainDisplay, &ev);
+   while (!done) {
+      XNextEvent(mainDisplay, &ev);
 
-      if (ev.type == Expose || ev.type == VisibilityNotify)
-         ExposeEventHandler (&ev, TRUE);
-      else if (ev.type == ButtonRelease)
-      {
-         XUngrabPointer (mainDisplay, CurrentTime);
+      if (ev.type == Expose || ev.type == VisibilityNotify) {
+         ExposeEventHandler(&ev, TRUE);
+      } else if (ev.type == ButtonRelease) {
+         XUngrabPointer(mainDisplay, CurrentTime);
          done = TRUE;
-      }
-      else if (ev.type == MotionNotify)
-      {
+      } else if (ev.type == MotionNotify) {
          int dx=ev.xmotion.x-orig_x, dy=ev.xmotion.y-orig_y;
          int change=((abs(dx)>abs(dy)) ? (int)(dx/res) : (int)(dy/res));
 
-         if (change != saved_change)
-         {
+         if (change != saved_change) {
             zoom = initial_zoom+change;
             if (zoom < 0) zoom = 0;
             if (zoom > max_zoom) zoom = max_zoom;
             zoomedIn = (zoom < MAX_ZOOMED_IN);
             zoomScale = (zoomedIn) ? (MAX_ZOOMED_IN-zoom) :
                   (zoom-MAX_ZOOMED_IN);
-            ShowZoom ();
+            ShowZoom();
             saved_change = change;
          }
-         while (XCheckMaskEvent (mainDisplay, PointerMotionMask, &ev)) ;
+         while (XCheckMaskEvent(mainDisplay, PointerMotionMask, &ev)) ;
       }
    }
    if (saved_zoomed_in==zoomedIn && saved_zoom_scale==zoomScale) return;
@@ -1089,7 +1071,7 @@ void ZoomLoop (button_ev)
    new_zoom_scale = zoomScale;
    zoomedIn = saved_zoomed_in;
    zoomScale = saved_zoom_scale;
-   PreciseZoom (new_zoomed_in, new_zoom_scale, FALSE);
+   PreciseZoom(new_zoomed_in, new_zoom_scale, FALSE);
 }
 
 struct MouseStatusStrRec modeMouseStatus[] = {
@@ -1643,8 +1625,8 @@ int ChoiceEventHandler(input)
             if (topSel != NULL) {
                ChangeAllSelLineWidth(lineWidth, TRUE);
             } else {
-               sprintf(gszMsgBox, "Line width set to %1d.",
-                     curWidthOfLine[lineWidth]);
+               sprintf(gszMsgBox, "Line width set to %s.",
+                     curWidthOfLineSpec[lineWidth]);
                Msg(gszMsgBox);
             }
          }
