@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,13 +27,12 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/cmd.c,v 3.39 1998/11/05 22:56:08 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /n/opus/u/guest/william/src/tgif/v3/RCS/cmd.c,v 3.0 1996/05/06 16:04:09 william Exp $";
-#endif
 
 #include <stdio.h>
+#include <string.h>
 #include <X11/Xlib.h>
 #include "const.h"
 #include "types.h"
@@ -47,6 +47,7 @@ static char RCSid[] =
 #include "drawing.e"
 #include "dup.e"
 #include "imgproc.e"
+#include "mainmenu.e"
 #include "mark.e"
 #include "move.e"
 #include "msg.e"
@@ -532,16 +533,17 @@ int UpdatePixelInACmd(CmdPtr, old_color_str)
 {
    struct CmdRec *cmd_ptr;
    struct SelRec *sel_ptr;
+   int changed=FALSE;
 
    switch (CmdPtr->type) {
    case CMD_COMPOSITE:
       for (cmd_ptr=CmdPtr->first; cmd_ptr!=NULL; cmd_ptr=cmd_ptr->next) {
-         UpdatePixelInACmd(cmd_ptr, old_color_str);
+         if (UpdatePixelInACmd(cmd_ptr, old_color_str)) changed = TRUE;
       }
       break;
    case CMD_NEW:
       for (sel_ptr=CmdPtr->top_after; sel_ptr!=NULL; sel_ptr=sel_ptr->next) {
-         UpdatePixel(sel_ptr->obj, old_color_str);
+         if (UpdatePixel(sel_ptr->obj, old_color_str)) changed = TRUE;
       }
       break;
    case CMD_DELETE: break;
@@ -549,20 +551,21 @@ int UpdatePixelInACmd(CmdPtr, old_color_str)
    case CMD_STRETCH: break;
    case CMD_REPLACE:
       for (sel_ptr=CmdPtr->top_after; sel_ptr!=NULL; sel_ptr=sel_ptr->next) {
-         UpdatePixel(sel_ptr->obj, old_color_str);
+         if (UpdatePixel(sel_ptr->obj, old_color_str)) changed = TRUE;
       }
       break;
    case CMD_ONE_TO_MANY: break;
    case CMD_MANY_TO_ONE:
       for (sel_ptr=CmdPtr->top_before; sel_ptr!=NULL; sel_ptr=sel_ptr->next) {
-         UpdatePixel(sel_ptr->obj, old_color_str);
+         if (UpdatePixel(sel_ptr->obj, old_color_str)) changed = TRUE;
       }
       for (sel_ptr=CmdPtr->top_after; sel_ptr!=NULL; sel_ptr=sel_ptr->next) {
-         UpdatePixel(sel_ptr->obj, old_color_str);
+         if (UpdatePixel(sel_ptr->obj, old_color_str)) changed = TRUE;
       }
       break;
    case CMD_GOTO_PAGE: break;
    }
+   return changed;
 }
 
 static
