@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/dialog.c,v 3.23 1998/11/05 22:56:09 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/dialog.c,v 3.2 1996/09/14 18:59:50 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -53,10 +52,12 @@ static char RCSid[] =
 #include "drawing.e"
 #include "file.e"
 #include "font.e"
+#include "grid.e"
 #include "mainloop.e"
 #include "mainmenu.e"
 #include "msg.e"
 #include "raster.e"
+#include "ruler.e"
 #include "setup.e"
 #include "text.e"
 #include "util.e"
@@ -1146,9 +1147,14 @@ int MsgBox(Message, Title, IconAndBtns)
    char *Message, *Title;
    int IconAndBtns;
 {
-   char *dup_msg=UtilStrDup(Message);
+   char *dup_msg=NULL;
    int rc=MB_ID_FAILED, looping=TRUE;
 
+   if (PRTGIF) {
+      fprintf(stderr, "%s\n", Message);
+      return rc;
+   }
+   dup_msg = UtilStrDup(Message);
    if (dup_msg == NULL) {
       FailAllocMessage();
       return rc;
@@ -1335,6 +1341,7 @@ int Dialog(Message, Comment, ReturnStr)
    real_msg = (char*)malloc((real_len+1)*sizeof(char));
    if (real_msg == NULL) {
       FailAllocMessage();
+      if (info_bits) { } /* do nothing but reference the variable */
       return INVALID;
    }
    if (Comment == NULL) {
