@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/drawing.c,v 3.85 1998/11/05 22:56:10 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/drawing.c,v 3.8 1996/09/15 04:45:04 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <sys/time.h>
@@ -67,6 +66,7 @@ static char RCSid[] =
 #include "font.e"
 #include "grid.e"
 #include "group.e"
+#include "help.e"
 #include "imgproc.e"
 #include "import.e"
 #include "mark.e"
@@ -95,6 +95,7 @@ static char RCSid[] =
 #include "stk.e"
 #include "stretch.e"
 #include "text.e"
+#include "util.e"
 #ifdef _TGIF_WB
 #include "wb1.e"
 #endif /* _TGIF_WB */
@@ -303,7 +304,7 @@ static int interruptLevel=0;
 void ShowInterrupt(CheckInterval)
    int CheckInterval;
 {
-   if (interruptLevel++ > 0) return;
+   if (PRTGIF || interruptLevel++ > 0) return;
 
    if (CheckInterval > 0)
    {
@@ -319,7 +320,7 @@ void ShowInterrupt(CheckInterval)
 
 int HideInterrupt ()
 {
-   if (--interruptLevel > 0) return interruptLevel;
+   if (PRTGIF || --interruptLevel > 0) return interruptLevel;
    interruptLevel = 0;
    if (execAnimatePixmap == None) {
       XEvent ev;
@@ -352,6 +353,7 @@ void RedrawDummyWindow1()
    } else {
       HideInterrupt();
    }
+   if (intr_bits && trek_bits) { } /* do nothing but reference the variable */
 }
 
 void DummiesEventHandler(input)
@@ -406,6 +408,7 @@ int ESCPressed()
 {
    XEvent ev;
 
+   if (PRTGIF) return FALSE;
    if (XCheckIfEvent(mainDisplay, &ev, CheckESC, NULL)) {
       return TRUE;
    }
@@ -414,7 +417,8 @@ int ESCPressed()
 
 int CheckInterrupt()
 {
-   if (execAnimatePixmap == None && intrCheckInterval <= 0) return (FALSE);
+   if (PRTGIF) return FALSE;
+   if (execAnimatePixmap == None && intrCheckInterval <= 0) return FALSE;
    if (++checkCount >= intrCheckInterval) {
       XEvent ev;
 
@@ -517,6 +521,8 @@ int ObjInVisibleLayer(ObjPtr)
    struct ObjRec *obj_ptr;
    struct AttrRec *attr_ptr;
 
+   if (!colorLayers) return TRUE;
+
    switch (ObjPtr->type) {
    case OBJ_POLY:
    case OBJ_BOX:
@@ -1369,7 +1375,8 @@ void CleanUpDrawingWindow ()
 }
 
 static
-int DoShortCut(name, key_sym, state, args)
+int DoShortCut(key_ev, name, key_sym, state, args)
+   XKeyEvent *key_ev;
    char *name, *args;
    KeySym key_sym;
    unsigned int state;
@@ -1474,7 +1481,7 @@ int DoShortCut(name, key_sym, state, args)
       case 'f': /*^#f*/ InvertXBitmaps(); break;
       case 'g': /*^#g*/ ToggleSnapOn(); break;
       case 'h': /*^#h*/ HideAllAttrs(); break;
-      case 'i': /*^#i*/ MakeIconic(); break;
+      case 'i': /*^#i*/ MakeIconic(NULL); break;
       case 'j': /*^#j*/ UnMakeIconic(); break;
       case 'k': /*^#k*/ ToggleColorPostScript(); break;
       case 'l': /*^#l*/ ChangeFontJust(JUST_L); break;
@@ -1495,6 +1502,7 @@ int DoShortCut(name, key_sym, state, args)
       case '.': /*^#.*/ ImportXBitmapFile(); break;
       case ',': /*^#,*/ ImportXPixmapFile(); break;
       case '-': /*^#-*/ ToggleGridSystem(); break;
+      case '=': /*^#=*/ FindAgain(); break;
       }
    } else if (name != NULL && key_sym == '\0' && state == 0) {
       XButtonEvent button_ev;
@@ -1731,6 +1739,35 @@ int DoShortCut(name, key_sym, state, args)
          About();
       } else if (strcmp(name, "Copyright()") == 0) {
          Copyright();
+      } else if (strcmp(name, "SetSelFontSize()") == 0) {
+         SetSelectedFontSize();
+      } else if (strcmp(name, "ZoomInAtCursor()") == 0) {
+         if (key_ev != NULL) {
+            int abs_x=ABS_X(key_ev->x);
+            int abs_y=ABS_Y(key_ev->y);
+
+            ZoomInAtCursor(abs_x, abs_y);
+         }
+      } else if (strcmp(name, "CenterAtCursor()") == 0) {
+         if (key_ev != NULL) {
+            int abs_x=ABS_X(key_ev->x);
+            int abs_y=ABS_Y(key_ev->y);
+
+            CenterAtCursor(abs_x, abs_y);
+         }
+      } else if (strcmp(name, "SetEditTextSize()") == 0) {
+         SetEditTextSize();
+      } else if (strcmp(name, "FindCaseSensitive()") == 0) {
+         FindCaseSensitive();
+      } else if (strcmp(name, "FindNoCase()") == 0) {
+         FindNoCase();
+      } else if (strcmp(name, "FindAgain()") == 0) {
+         FindAgain();
+      } else if (strcmp(name, "CurrentVersionInfo()") == 0 ||
+            strcmp(name, "LatestReleaseInfo()") == 0) {
+         LatestReleaseInfo();
+      } else if (strcmp(name, "VectorWarp()") == 0) {
+         VectorWarp();
       }
    }
    return BAD;
@@ -1782,7 +1819,7 @@ int ShortHand(input)
 
    if (valid_shortcut) {
       Msg("");
-      return DoShortCut(name, key_sym, key_ev->state, args);
+      return DoShortCut(key_ev, name, key_sym, key_ev->state, args);
    }
    return (INVALID);
 }
@@ -1792,7 +1829,11 @@ int CallShortCut(name, argc, argv, code, state)
    int argc;
    unsigned int state;
 {
-   DoShortCut(name, (KeySym)(*code), state, (argc<=1 ? NULL : argv[1]));
+   if (UtilStrICmp(name, "ZoomInAtCursor") == 0 ||
+         UtilStrICmp(name, "CenterAtCursor") == 0) {
+      return FALSE;
+   }
+   DoShortCut(NULL, name, (KeySym)(*code), state, (argc<=1 ? NULL : argv[1]));
    return TRUE;
 }
 
@@ -1986,11 +2027,13 @@ int DrawingEventHandler(input)
       button_ev = &(input->xbutton);
       if ((button_ev->state & ShiftMask) && (button_ev->state & ControlMask))
       {
-         if (button_ev->button == Button1) {
-            int abs_x=ABS_X(button_ev->x);
-            int abs_y=ABS_Y(button_ev->y);
+         int abs_x=ABS_X(button_ev->x);
+         int abs_y=ABS_Y(button_ev->y);
 
+         if (button_ev->button == Button1) {
             ZoomInAtCursor(abs_x, abs_y);
+         } else if (button_ev->button == Button2) {
+            CenterAtCursor(abs_x, abs_y);
          } else if (button_ev->button == Button3) {
             ZoomOut();
          }
