@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,13 +27,12 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/dup.c,v 3.38 1998/11/05 22:56:10 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/dup.c,v 3.1 1996/05/10 06:33:46 william Exp $";
-#endif
 
 #include <stdio.h>
+#include <string.h>
 #include <X11/Xlib.h>
 #include "const.h"
 #include "types.h"
@@ -63,78 +63,81 @@ int	justDupped = FALSE;
 int	useRecentDupDistance = TRUE;
 int	dupDx = INVALID, dupDy = INVALID;
 
-void CopyObjId (FromObjPtr, ToObjPtr)
-   struct ObjRec	* FromObjPtr, * ToObjPtr;
+void CopyObjId(FromObjPtr, ToObjPtr)
+   struct ObjRec *FromObjPtr, *ToObjPtr;
 {
-   register struct ObjRec	* from_obj_ptr, * to_obj_ptr;
-   register struct AttrRec	* from_attr_ptr, * to_attr_ptr;
+   register struct ObjRec *from_obj_ptr, *to_obj_ptr;
+   register struct AttrRec *from_attr_ptr, *to_attr_ptr;
 
    ToObjPtr->id = FromObjPtr->id;
-   switch (FromObjPtr->type)
-   {
-      case OBJ_SYM:
-      case OBJ_GROUP:
-      case OBJ_ICON:
-         from_obj_ptr = FromObjPtr->detail.r->first;
-         to_obj_ptr = ToObjPtr->detail.r->first;
-         for ( ; from_obj_ptr!=NULL; from_obj_ptr=from_obj_ptr->next,
-               to_obj_ptr=to_obj_ptr->next)
-            CopyObjId (from_obj_ptr, to_obj_ptr);
+   switch (FromObjPtr->type) {
+   case OBJ_SYM:
+   case OBJ_GROUP:
+   case OBJ_ICON:
+      from_obj_ptr = FromObjPtr->detail.r->first;
+      to_obj_ptr = ToObjPtr->detail.r->first;
+      for ( ; from_obj_ptr!=NULL; from_obj_ptr=from_obj_ptr->next,
+            to_obj_ptr=to_obj_ptr->next) {
+         CopyObjId(from_obj_ptr, to_obj_ptr);
+      }
    }
    from_attr_ptr = FromObjPtr->fattr;
    to_attr_ptr = ToObjPtr->fattr;
    for ( ; from_attr_ptr!=NULL; from_attr_ptr=from_attr_ptr->next,
-         to_attr_ptr=to_attr_ptr->next)
-      CopyObjId (from_attr_ptr->obj, to_attr_ptr->obj);
+         to_attr_ptr=to_attr_ptr->next) {
+      CopyObjId(from_attr_ptr->obj, to_attr_ptr->obj);
+   }
 }
 
-void CopyObjLocks (FromObjPtr, ToObjPtr)
-   struct ObjRec	* FromObjPtr, * ToObjPtr;
+void CopyObjLocks(FromObjPtr, ToObjPtr)
+   struct ObjRec *FromObjPtr, *ToObjPtr;
 {
-   register struct ObjRec	* from_obj_ptr, * to_obj_ptr;
-   register struct AttrRec	* from_attr_ptr, * to_attr_ptr;
+   register struct ObjRec *from_obj_ptr, *to_obj_ptr;
+   register struct AttrRec *from_attr_ptr, *to_attr_ptr;
 
    ToObjPtr->locked = FromObjPtr->locked;
-   switch (FromObjPtr->type)
-   {
-      case OBJ_SYM:
-      case OBJ_GROUP:
-      case OBJ_ICON:
-         from_obj_ptr = FromObjPtr->detail.r->first;
-         to_obj_ptr = ToObjPtr->detail.r->first;
-         for ( ; from_obj_ptr!=NULL; from_obj_ptr=from_obj_ptr->next,
-               to_obj_ptr=to_obj_ptr->next)
-            CopyObjLocks (from_obj_ptr, to_obj_ptr);
+   switch (FromObjPtr->type) {
+   case OBJ_SYM:
+   case OBJ_GROUP:
+   case OBJ_ICON:
+      from_obj_ptr = FromObjPtr->detail.r->first;
+      to_obj_ptr = ToObjPtr->detail.r->first;
+      for ( ; from_obj_ptr!=NULL; from_obj_ptr=from_obj_ptr->next,
+            to_obj_ptr=to_obj_ptr->next) {
+         CopyObjLocks(from_obj_ptr, to_obj_ptr);
+      }
    }
    from_attr_ptr = FromObjPtr->fattr;
    to_attr_ptr = ToObjPtr->fattr;
    for ( ; from_attr_ptr!=NULL; from_attr_ptr=from_attr_ptr->next,
-         to_attr_ptr=to_attr_ptr->next)
-      CopyObjLocks (from_attr_ptr->obj, to_attr_ptr->obj);
+         to_attr_ptr=to_attr_ptr->next) {
+      CopyObjLocks(from_attr_ptr->obj, to_attr_ptr->obj);
+   }
 }
 
-void UnlockAnObj (ObjPtr)
-   struct ObjRec	* ObjPtr;
+void UnlockAnObj(ObjPtr)
+   struct ObjRec *ObjPtr;
 {
-   register struct ObjRec	* obj_ptr;
-   register struct AttrRec	* attr_ptr;
+   register struct ObjRec *obj_ptr;
+   register struct AttrRec *attr_ptr;
 
    ObjPtr->locked = FALSE;
-   switch (ObjPtr->type)
-   {
-      case OBJ_SYM:
-      case OBJ_GROUP:
-      case OBJ_ICON:
-         for (obj_ptr=ObjPtr->detail.r->first; obj_ptr!=NULL;
-               obj_ptr=obj_ptr->next)
-            UnlockAnObj (obj_ptr);
+   switch (ObjPtr->type) {
+   case OBJ_SYM:
+   case OBJ_GROUP:
+   case OBJ_ICON:
+      for (obj_ptr=ObjPtr->detail.r->first; obj_ptr!=NULL;
+            obj_ptr=obj_ptr->next) {
+         UnlockAnObj(obj_ptr);
+      }
    }
-   for (attr_ptr=ObjPtr->fattr; attr_ptr!=NULL; attr_ptr=attr_ptr->next)
+   for (attr_ptr=ObjPtr->fattr; attr_ptr!=NULL; attr_ptr=attr_ptr->next) {
       attr_ptr->obj->locked = FALSE;
+   }
 }
 
-void DupObjXfrmMtrx (FromObjPtr, ToObjPtr)
-   register struct ObjRec	* FromObjPtr, * ToObjPtr;
+void DupObjXfrmMtrx(FromObjPtr, ToObjPtr)
+   register struct ObjRec *FromObjPtr, *ToObjPtr;
 {
    ToObjPtr->ctm = NULL;
    if (FromObjPtr->ctm == NULL) return;
@@ -144,8 +147,8 @@ void DupObjXfrmMtrx (FromObjPtr, ToObjPtr)
    memcpy(&ToObjPtr->orig_obbox,&FromObjPtr->orig_obbox,sizeof(struct BBRec));
 }
 
-void DupObjBasics (FromObjPtr, ToObjPtr)
-   register struct ObjRec	* FromObjPtr, * ToObjPtr;
+void DupObjBasics(FromObjPtr, ToObjPtr)
+   register struct ObjRec *FromObjPtr, *ToObjPtr;
 {
    ToObjPtr->next = ToObjPtr->prev = NULL;
    ToObjPtr->x = FromObjPtr->x;
@@ -166,21 +169,21 @@ void DupObjBasics (FromObjPtr, ToObjPtr)
    ToObjPtr->locked = FALSE;
    ToObjPtr->invisible = FromObjPtr->invisible;
 
-   memcpy (&ToObjPtr->orig_obbox, &FromObjPtr->orig_obbox,
+   memcpy(&ToObjPtr->orig_obbox, &FromObjPtr->orig_obbox,
          sizeof(struct BBRec));
-   memcpy (ToObjPtr->rotated_obbox, FromObjPtr->rotated_obbox,
+   memcpy(ToObjPtr->rotated_obbox, FromObjPtr->rotated_obbox,
          5*sizeof(XPoint));
-   DupObjXfrmMtrx (FromObjPtr, ToObjPtr);
+   DupObjXfrmMtrx(FromObjPtr, ToObjPtr);
 }
 
-void DupPolyObj (PolyPtr, ObjPtr)
-   struct PolyRec	* PolyPtr;
-   struct ObjRec	* ObjPtr;
+void DupPolyObj(PolyPtr, ObjPtr)
+   struct PolyRec *PolyPtr;
+   struct ObjRec *ObjPtr;
 {
-   register int			i, num_pts;
-   register struct PolyRec	* poly_ptr;
-   register XPoint		*sv;
-   register IntPoint		*pv;
+   register int i, num_pts;
+   register struct PolyRec *poly_ptr;
+   register XPoint *sv;
+   register IntPoint *pv;
 
    poly_ptr = (struct PolyRec *)malloc(sizeof(struct PolyRec));
    if (poly_ptr == NULL) FailAllocMessage();
@@ -194,7 +197,7 @@ void DupPolyObj (PolyPtr, ObjPtr)
    } else {
       poly_ptr->smooth = NULL;
    }
-   for (i = 0; i < num_pts; i++) {
+   for (i=0; i < num_pts; i++) {
       pv[i].x = PolyPtr->vlist[i].x;
       pv[i].y = PolyPtr->vlist[i].y;
       if (PolyPtr->smooth != NULL && poly_ptr->smooth != NULL) {
@@ -216,7 +219,7 @@ void DupPolyObj (PolyPtr, ObjPtr)
       poly_ptr->sn = num_pts = PolyPtr->sn;
       sv = (XPoint*)malloc((num_pts+1)*sizeof(XPoint));
       if (sv == NULL) FailAllocMessage();
-      for (i = 0; i < num_pts; i++) {
+      for (i=0; i < num_pts; i++) {
          sv[i].x = PolyPtr->svlist[i].x;
          sv[i].y = PolyPtr->svlist[i].y;
       }
@@ -230,7 +233,7 @@ void DupPolyObj (PolyPtr, ObjPtr)
       poly_ptr->intn = num_pts = PolyPtr->intn;
       pv = (IntPoint*)malloc((num_pts+1)*sizeof(IntPoint));
       if (pv == NULL) FailAllocMessage();
-      for (i = 0; i < num_pts; i++) {
+      for (i=0; i < num_pts; i++) {
          pv[i].x = PolyPtr->intvlist[i].x;
          pv[i].y = PolyPtr->intvlist[i].y;
       }
@@ -245,7 +248,7 @@ void DupPolyObj (PolyPtr, ObjPtr)
       poly_ptr->rotated_n = num_pts = PolyPtr->rotated_n;
       sv = (XPoint*)malloc((num_pts+1)*sizeof(XPoint));
       if (sv == NULL) FailAllocMessage();
-      for (i = 0; i < num_pts; i++) {
+      for (i=0; i < num_pts; i++) {
          sv[i].x = PolyPtr->rotated_vlist[i].x;
          sv[i].y = PolyPtr->rotated_vlist[i].y;
       }
@@ -258,14 +261,14 @@ void DupPolyObj (PolyPtr, ObjPtr)
    ObjPtr->detail.p = poly_ptr;
 }
 
-void DupPolygonObj (PolygonPtr, ObjPtr)
-   struct PolygonRec	* PolygonPtr;
-   struct ObjRec	* ObjPtr;
+void DupPolygonObj(PolygonPtr, ObjPtr)
+   struct PolygonRec *PolygonPtr;
+   struct ObjRec *ObjPtr;
 {
-   register int			i, num_pts;
-   register struct PolygonRec	* polygon_ptr;
-   XPoint			*sv;
-   IntPoint			*pv;
+   register int i, num_pts;
+   register struct PolygonRec *polygon_ptr;
+   XPoint *sv;
+   IntPoint *pv;
 
    polygon_ptr = (struct PolygonRec *)malloc(sizeof(struct PolygonRec));
    if (polygon_ptr == NULL) FailAllocMessage();
@@ -279,7 +282,7 @@ void DupPolygonObj (PolygonPtr, ObjPtr)
    } else {
       polygon_ptr->smooth = NULL;
    }
-   for (i = 0; i < num_pts; i++) {
+   for (i=0; i < num_pts; i++) {
       pv[i].x = PolygonPtr->vlist[i].x;
       pv[i].y = PolygonPtr->vlist[i].y;
       if (PolygonPtr->smooth != NULL && polygon_ptr->smooth != NULL) {
@@ -296,7 +299,7 @@ void DupPolygonObj (PolygonPtr, ObjPtr)
       polygon_ptr->sn = num_pts = PolygonPtr->sn;
       sv = (XPoint*)malloc((num_pts+1)*sizeof(XPoint));
       if (sv == NULL) FailAllocMessage();
-      for (i = 0; i < num_pts; i++) {
+      for (i=0; i < num_pts; i++) {
          sv[i].x = PolygonPtr->svlist[i].x;
          sv[i].y = PolygonPtr->svlist[i].y;
       }
@@ -310,7 +313,7 @@ void DupPolygonObj (PolygonPtr, ObjPtr)
       polygon_ptr->intn = num_pts = PolygonPtr->intn;
       pv = (IntPoint*)malloc((num_pts+1)*sizeof(IntPoint));
       if (pv == NULL) FailAllocMessage();
-      for (i = 0; i < num_pts; i++) {
+      for (i=0; i < num_pts; i++) {
          pv[i].x = PolygonPtr->intvlist[i].x;
          pv[i].y = PolygonPtr->intvlist[i].y;
       }
@@ -325,7 +328,7 @@ void DupPolygonObj (PolygonPtr, ObjPtr)
       polygon_ptr->rotated_n = num_pts = PolygonPtr->rotated_n;
       sv = (XPoint*)malloc((num_pts+1)*sizeof(XPoint));
       if (sv == NULL) FailAllocMessage();
-      for (i = 0; i < num_pts; i++) {
+      for (i=0; i < num_pts; i++) {
          sv[i].x = PolygonPtr->rotated_vlist[i].x;
          sv[i].y = PolygonPtr->rotated_vlist[i].y;
       }
@@ -338,11 +341,11 @@ void DupPolygonObj (PolygonPtr, ObjPtr)
    ObjPtr->detail.g = polygon_ptr;
 }
 
-void DupOvalObj (OvalPtr, ObjPtr)
-   struct OvalRec	* OvalPtr;
-   struct ObjRec	* ObjPtr;
+void DupOvalObj(OvalPtr, ObjPtr)
+   struct OvalRec *OvalPtr;
+   struct ObjRec *ObjPtr;
 {
-   register struct OvalRec	* oval_ptr;
+   register struct OvalRec *oval_ptr;
 
    oval_ptr = (struct OvalRec *)malloc(sizeof(struct OvalRec));
    if (oval_ptr == NULL) FailAllocMessage();
@@ -353,23 +356,19 @@ void DupOvalObj (OvalPtr, ObjPtr)
    oval_ptr->pen = OvalPtr->pen;
    oval_ptr->dash = OvalPtr->dash;
    if (ObjPtr->ctm != NULL && OvalPtr->rotated_n != 0 &&
-         OvalPtr->rotated_vlist != NULL)
-   {
-      int	i, num_pts;
-      XPoint	* v;
+         OvalPtr->rotated_vlist != NULL) {
+      int i, num_pts;
+      XPoint *v;
 
       oval_ptr->rotated_n = num_pts = OvalPtr->rotated_n;
       v = (XPoint*)malloc((num_pts+1)*sizeof(XPoint));
       if (v == NULL) FailAllocMessage();
-      for (i = 0; i < num_pts; i++)
-      {
+      for (i=0; i < num_pts; i++) {
          v[i].x = OvalPtr->rotated_vlist[i].x;
          v[i].y = OvalPtr->rotated_vlist[i].y;
       }
       oval_ptr->rotated_vlist = v;
-   }
-   else
-   {
+   } else {
       oval_ptr->rotated_n = 0;
       oval_ptr->rotated_vlist = NULL;
    }
@@ -377,11 +376,11 @@ void DupOvalObj (OvalPtr, ObjPtr)
    ObjPtr->detail.o = oval_ptr;
 }
 
-void DupBoxObj (BoxPtr, ObjPtr)
-   struct BoxRec	* BoxPtr;
-   struct ObjRec	* ObjPtr;
+void DupBoxObj(BoxPtr, ObjPtr)
+   struct BoxRec *BoxPtr;
+   struct ObjRec *ObjPtr;
 {
-   register struct BoxRec	* box_ptr;
+   register struct BoxRec *box_ptr;
 
    box_ptr = (struct BoxRec *)malloc(sizeof(struct BoxRec));
    if (box_ptr == NULL) FailAllocMessage();
@@ -395,11 +394,11 @@ void DupBoxObj (BoxPtr, ObjPtr)
    ObjPtr->detail.b = box_ptr;
 }
 
-void DupRCBoxObj (RCBoxPtr, ObjPtr)
-   struct RCBoxRec	* RCBoxPtr;
-   struct ObjRec	* ObjPtr;
+void DupRCBoxObj(RCBoxPtr, ObjPtr)
+   struct RCBoxRec *RCBoxPtr;
+   struct ObjRec *ObjPtr;
 {
-   register struct RCBoxRec	* rcbox_ptr;
+   register struct RCBoxRec *rcbox_ptr;
 
    rcbox_ptr = (struct RCBoxRec *)malloc(sizeof(struct RCBoxRec));
    if (rcbox_ptr == NULL) FailAllocMessage();
@@ -418,7 +417,7 @@ void DupRCBoxObj (RCBoxPtr, ObjPtr)
       rcbox_ptr->rotated_n = num_pts = RCBoxPtr->rotated_n;
       v = (XPoint*)malloc((num_pts+1)*sizeof(XPoint));
       if (v == NULL) FailAllocMessage();
-      for (i = 0; i < num_pts; i++) {
+      for (i=0; i < num_pts; i++) {
          v[i].x = RCBoxPtr->rotated_vlist[i].x;
          v[i].y = RCBoxPtr->rotated_vlist[i].y;
       }
@@ -431,11 +430,11 @@ void DupRCBoxObj (RCBoxPtr, ObjPtr)
    ObjPtr->detail.rcb = rcbox_ptr;
 }
 
-void DupArcObj (ArcPtr, ObjPtr)
-   struct ArcRec	* ArcPtr;
-   struct ObjRec	* ObjPtr;
+void DupArcObj(ArcPtr, ObjPtr)
+   struct ArcRec *ArcPtr;
+   struct ObjRec *ObjPtr;
 {
-   register struct ArcRec	* arc_ptr;
+   register struct ArcRec *arc_ptr;
 
    arc_ptr = (struct ArcRec *)malloc(sizeof(struct ArcRec));
    if (arc_ptr == NULL) FailAllocMessage();
@@ -467,7 +466,7 @@ void DupArcObj (ArcPtr, ObjPtr)
       arc_ptr->rotated_n = num_pts = ArcPtr->rotated_n;
       v = (XPoint*)malloc((num_pts+2)*sizeof(XPoint));
       if (v == NULL) FailAllocMessage();
-      for (i = 0; i < num_pts+2; i++) {
+      for (i=0; i < num_pts+2; i++) {
          v[i].x = ArcPtr->rotated_vlist[i].x;
          v[i].y = ArcPtr->rotated_vlist[i].y;
       }
@@ -480,15 +479,14 @@ void DupArcObj (ArcPtr, ObjPtr)
    ObjPtr->detail.a = arc_ptr;
 }
 
-void DupXBmObj (XBmPtr, ObjPtr)
-   struct XBmRec	* XBmPtr;
-   struct ObjRec	* ObjPtr;
+void DupXBmObj(XBmPtr, ObjPtr)
+   struct XBmRec *XBmPtr;
+   struct ObjRec *ObjPtr;
 {
-   register struct XBmRec	* xbm_ptr;
-   register int			i;
-   Pixmap			bitmap, cached_bitmap;
-   int				w, h, image_w, image_h;
-   char				msg[MAXSTRING];
+   register struct XBmRec *xbm_ptr;
+   register int i;
+   Pixmap bitmap, cached_bitmap;
+   int w, h, image_w, image_h;
 
    xbm_ptr = (struct XBmRec *)malloc(sizeof(struct XBmRec));
    if (xbm_ptr == NULL) FailAllocMessage();
@@ -519,35 +517,30 @@ void DupXBmObj (XBmPtr, ObjPtr)
    xbm_ptr->save_epsf = XBmPtr->save_epsf;
    xbm_ptr->real_type = XBmPtr->real_type;
 
-   if (ObjPtr->ctm != NULL)
-      memcpy (&xbm_ptr->cached_ctm, &XBmPtr->cached_ctm,
+   if (ObjPtr->ctm != NULL) {
+      memcpy(&xbm_ptr->cached_ctm, &XBmPtr->cached_ctm,
             sizeof(struct XfrmMtrxRec));
+   }
    if (XBmPtr->real_type==XBM_XBM || (XBmPtr->real_type==XBM_EPS &&
-         XBmPtr->bitmap!=None))
-   {
-      bitmap = XCreatePixmap (mainDisplay, mainWindow, image_w, image_h, 1);
-      if (bitmap == None)
-      {
-         sprintf (msg,"Can not copy bitmap of size %1dx%1d.",image_w,image_h);
-         Msg (msg);
+         XBmPtr->bitmap!=None)) {
+      bitmap = XCreatePixmap(mainDisplay, mainWindow, image_w, image_h, 1);
+      if (bitmap == None) {
+         FailAllocBitmapMessage(image_w, image_h);
          return;
       }
-      XCopyArea (mainDisplay, XBmPtr->bitmap, bitmap, xbmGC, 0, 0,
+      XCopyArea(mainDisplay, XBmPtr->bitmap, bitmap, xbmGC, 0, 0,
             image_w, image_h, 0, 0);
       xbm_ptr->bitmap = bitmap;
-      if (XBmPtr->cached_bitmap != None)
-      {
+      if (XBmPtr->cached_bitmap != None) {
          w = ZOOMED_SIZE(ObjPtr->obbox.rbx - ObjPtr->obbox.ltx);
          h = ZOOMED_SIZE(ObjPtr->obbox.rby - ObjPtr->obbox.lty);
 
-         cached_bitmap = XCreatePixmap (mainDisplay, mainWindow, w, h, 1);
-         if (cached_bitmap == None)
-         {
-            sprintf (msg, "Can not copy bitmap of size %1dx%1d.", w, h);
-            Msg (msg);
+         cached_bitmap = XCreatePixmap(mainDisplay, mainWindow, w, h, 1);
+         if (cached_bitmap == None) {
+            FailAllocBitmapMessage(w, h);
             return;
          }
-         XCopyArea (mainDisplay, XBmPtr->cached_bitmap, cached_bitmap, xbmGC,
+         XCopyArea(mainDisplay, XBmPtr->cached_bitmap, cached_bitmap, xbmGC,
                0, 0, w, h, 0, 0);
          xbm_ptr->cached_bitmap = cached_bitmap;
       }
@@ -574,16 +567,15 @@ void DupXBmObj (XBmPtr, ObjPtr)
    }
 }
 
-void DupXPmObj (XPmPtr, ObjPtr)
-   struct XPmRec	* XPmPtr;
-   struct ObjRec	* ObjPtr;
+void DupXPmObj(XPmPtr, ObjPtr)
+   struct XPmRec *XPmPtr;
+   struct ObjRec *ObjPtr;
 {
-   register struct XPmRec	* xpm_ptr;
-   register int			j, i;
-   Pixmap			pixmap, bitmap, cached_pixmap, cached_bitmap;
-   int				w, h, ncolors, * pixels, len, chars_per_pixel;
-   int				image_w, image_h;
-   char				* color_char, * * color_str, msg[MAXSTRING];
+   register struct XPmRec *xpm_ptr;
+   register int j, i;
+   Pixmap pixmap, bitmap, cached_pixmap, cached_bitmap;
+   int w, h, ncolors, *pixels, len, chars_per_pixel, image_w, image_h;
+   char *color_char, **color_str;
 
    xpm_ptr = (struct XPmRec *)malloc(sizeof(struct XPmRec));
    if (xpm_ptr == NULL) FailAllocMessage();
@@ -612,25 +604,24 @@ void DupXPmObj (XPmPtr, ObjPtr)
    xpm_ptr->cached_bitmap = None;
    xpm_ptr->clip_mask = None;
 
-   if (ObjPtr->ctm != NULL)
-      memcpy (&xpm_ptr->cached_ctm, &XPmPtr->cached_ctm,
+   if (ObjPtr->ctm != NULL) {
+      memcpy(&xpm_ptr->cached_ctm, &XPmPtr->cached_ctm,
             sizeof(struct XfrmMtrxRec));
+   }
    pixmap = XCreatePixmap(mainDisplay,mainWindow,image_w,image_h,mainDepth);
    if (pixmap == None) {
-      sprintf(msg, "Can not copy pixmap of size %1dx%1d.", image_w, image_h);
-      Msg(msg);
+      FailAllocPixmapMessage(image_w, image_h);
       return;
    }
-   XCopyArea (mainDisplay,XPmPtr->pixmap,pixmap,xpmGC,0,0,image_w,image_h,0,0);
+   XCopyArea(mainDisplay,XPmPtr->pixmap,pixmap,xpmGC,0,0,image_w,image_h,0,0);
    xpm_ptr->pixmap = pixmap;
 
    bitmap = XCreatePixmap(mainDisplay,mainWindow,image_w,image_h,1);
    if (bitmap == None) {
-      sprintf(msg, "Can not copy bitmap of size %1dx%1d.", image_w, image_h);
-      Msg(msg);
+      FailAllocBitmapMessage(image_w, image_h);
       return;
    }
-   XCopyArea (mainDisplay,XPmPtr->bitmap,bitmap,xbmGC,0,0,image_w,image_h,0,0);
+   XCopyArea(mainDisplay,XPmPtr->bitmap,bitmap,xbmGC,0,0,image_w,image_h,0,0);
    xpm_ptr->bitmap = bitmap;
 
    w = ZOOMED_SIZE(ObjPtr->obbox.rbx - ObjPtr->obbox.ltx);
@@ -639,8 +630,7 @@ void DupXPmObj (XPmPtr, ObjPtr)
    if (XPmPtr->cached_pixmap != None) {
       cached_pixmap = XCreatePixmap(mainDisplay, mainWindow, w, h, mainDepth);
       if (cached_pixmap == None) {
-         sprintf(msg, "Can not copy pixmap of size %1dx%1d.", w, h);
-         Msg(msg);
+         FailAllocPixmapMessage(w, h);
          return;
       }
       XCopyArea(mainDisplay, XPmPtr->cached_pixmap, cached_pixmap, xpmGC, 0, 0,
@@ -650,8 +640,7 @@ void DupXPmObj (XPmPtr, ObjPtr)
    if (XPmPtr->cached_bitmap != None) {
       cached_bitmap = XCreatePixmap(mainDisplay, mainWindow, w, h, 1);
       if (cached_bitmap == None) {
-         sprintf(msg, "Can not copy bitmap of size %1dx%1d.", w, h);
-         Msg(msg);
+         FailAllocBitmapMessage(w, h);
          return;
       }
       XCopyArea(mainDisplay, XPmPtr->cached_bitmap, cached_bitmap, xbmGC, 0, 0,
@@ -668,46 +657,42 @@ void DupXPmObj (XPmPtr, ObjPtr)
    color_str = xpm_ptr->color_str = (char**)malloc(ncolors*sizeof(char*));
    pixels = xpm_ptr->pixels = (int*)malloc(ncolors*sizeof(int));
    if (color_char==NULL || color_str==NULL || pixels==NULL) FailAllocMessage();
-   for (i = 0; i < ncolors; i++) {
-      for (j = 0; j < chars_per_pixel; j++) {
+   for (i=0; i < ncolors; i++) {
+      for (j=0; j < chars_per_pixel; j++) {
          color_char[i*chars_per_pixel+j] =
                XPmPtr->color_char[i*chars_per_pixel+j];
       }
       pixels[i] = XPmPtr->pixels[i];
 
-      len = strlen (XPmPtr->color_str[i]);
+      len = strlen(XPmPtr->color_str[i]);
       color_str[i] = (char*)malloc((len+1)*sizeof(char));
       if (color_str[i] == NULL) FailAllocMessage();
       strcpy(color_str[i], XPmPtr->color_str[i]);
    }
    xpm_ptr->red = xpm_ptr->green = xpm_ptr->blue = NULL;
-   if (ObjPtr->ctm != NULL && XPmPtr->clip_mask != None)
-   {
+   if (ObjPtr->ctm != NULL && XPmPtr->clip_mask != None) {
       w = ZOOMED_SIZE(ObjPtr->obbox.rbx - ObjPtr->obbox.ltx);
       h = ZOOMED_SIZE(ObjPtr->obbox.rby - ObjPtr->obbox.lty);
 
-      pixmap = XCreatePixmap (mainDisplay, mainWindow, w, h, 1);
-      if (pixmap == None)
-      {
-         sprintf (msg, "Can not copy pixmap of size %1dx%1d.", w, h);
-         Msg (msg);
+      pixmap = XCreatePixmap(mainDisplay, mainWindow, w, h, 1);
+      if (pixmap == None) {
+         FailAllocBitmapMessage(w, h);
          return;
       }
-      XCopyArea (mainDisplay, XPmPtr->clip_mask, pixmap, xbmGC, 0, 0,
+      XCopyArea(mainDisplay, XPmPtr->clip_mask, pixmap, xbmGC, 0, 0,
             w, h, 0, 0);
       xpm_ptr->clip_mask = pixmap;
    }
 }
 
-void DupTextObj (TextPtr, FromObjPtr, ToObjPtr)
-   struct TextRec	* TextPtr;
-   struct ObjRec	* FromObjPtr, * ToObjPtr;
+void DupTextObj(TextPtr, FromObjPtr, ToObjPtr)
+   struct TextRec *TextPtr;
+   struct ObjRec *FromObjPtr, *ToObjPtr;
 {
-   register int			i, num_lines;
-   register struct TextRec	* text_ptr;
-   struct StrRec		* first_str;
-   struct StrRec		* from_str_ptr, * to_str_ptr;
-   char				msg[MAXSTRING];
+   register int i, num_lines;
+   register struct TextRec *text_ptr;
+   struct StrRec *first_str;
+   struct StrRec *from_str_ptr, *to_str_ptr;
 
    text_ptr = (struct TextRec *)malloc(sizeof(struct TextRec));
    if (text_ptr == NULL) FailAllocMessage();
@@ -717,15 +702,15 @@ void DupTextObj (TextPtr, FromObjPtr, ToObjPtr)
    num_lines = text_ptr->lines = TextPtr->lines;
    from_str_ptr = TextPtr->last;
    first_str = NULL;
-   for (i = 0; i < num_lines; i++, from_str_ptr = from_str_ptr->prev)
-   {
-      to_str_ptr = NewStr ();
-      DynStrCpy (&to_str_ptr->dyn_str, &from_str_ptr->dyn_str);
+   for (i=0; i < num_lines; i++, from_str_ptr=from_str_ptr->prev) {
+      to_str_ptr = NewStr();
+      DynStrCpy(&to_str_ptr->dyn_str, &from_str_ptr->dyn_str);
       to_str_ptr->next = first_str;
-      if (first_str == NULL)
+      if (first_str == NULL) {
          text_ptr->last = to_str_ptr;
-      else
+      } else {
          first_str->prev = to_str_ptr;
+      }
       first_str = to_str_ptr;
    }
    first_str->prev = NULL;
@@ -745,11 +730,12 @@ void DupTextObj (TextPtr, FromObjPtr, ToObjPtr)
    text_ptr->max_rextra = TextPtr->max_rextra;
    text_ptr->double_byte = TextPtr->double_byte;
    text_ptr->direction = TextPtr->direction;
-   if (TextPtr->custom_screen_font_name == NULL)
+   if (TextPtr->custom_screen_font_name == NULL) {
       text_ptr->custom_screen_font_name = NULL;
-   else
+   } else {
       text_ptr->custom_screen_font_name =
             UtilStrDup(TextPtr->custom_screen_font_name);
+   }
    text_ptr->cached_zoom = TextPtr->cached_zoom;
    text_ptr->cached_bitmap = None;
    text_ptr->image = NULL;
@@ -763,24 +749,22 @@ void DupTextObj (TextPtr, FromObjPtr, ToObjPtr)
 
    ToObjPtr->detail.t = text_ptr;
 
-   if (ToObjPtr->ctm != NULL)
-      memcpy (&text_ptr->cached_ctm, &TextPtr->cached_ctm,
+   if (ToObjPtr->ctm != NULL) {
+      memcpy(&text_ptr->cached_ctm, &TextPtr->cached_ctm,
             sizeof(struct XfrmMtrxRec));
-   if (TextPtr->cached_bitmap != None)
-   {
-      int	w=ZOOMED_SIZE(FromObjPtr->bbox.rbx - FromObjPtr->bbox.ltx - 2);
-      int	h=ZOOMED_SIZE(FromObjPtr->bbox.rby - FromObjPtr->bbox.lty - 2);
+   }
+   if (TextPtr->cached_bitmap != None) {
+      int w=ZOOMED_SIZE(FromObjPtr->bbox.rbx - FromObjPtr->bbox.ltx - 2);
+      int h=ZOOMED_SIZE(FromObjPtr->bbox.rby - FromObjPtr->bbox.lty - 2);
 
       if (w == 0) w = 1;
       if (h == 0) h = 1;
-      text_ptr->cached_bitmap = XCreatePixmap (mainDisplay,mainWindow,w,h,1);
-      if (text_ptr->cached_bitmap == None)
-      {
-         sprintf (msg, "Can not create bitmap of size %1dx%1d.", w, h);
-         Msg (msg);
+      text_ptr->cached_bitmap = XCreatePixmap(mainDisplay,mainWindow,w,h,1);
+      if (text_ptr->cached_bitmap == None) {
+         FailAllocBitmapMessage(w, h);
          return;
       }
-      XCopyArea (mainDisplay, TextPtr->cached_bitmap, text_ptr->cached_bitmap,
+      XCopyArea(mainDisplay, TextPtr->cached_bitmap, text_ptr->cached_bitmap,
             rotateGC, 0, 0, w, h, 0, 0);
    }
    if (ToObjPtr->ctm != NULL) {
@@ -789,30 +773,30 @@ void DupTextObj (TextPtr, FromObjPtr, ToObjPtr)
 }
 
 #ifdef _NO_EXTERN
-struct ObjRec	* DupObj ARGS_DECL((struct ObjRec *));
+struct ObjRec *DupObj ARGS_DECL((struct ObjRec *));
 #endif /* _NO_EXTERN */
 
-void DupGroupObj (GroupPtr, ObjPtr)
-   struct GroupRec	* GroupPtr;
-   struct ObjRec	* ObjPtr;
+void DupGroupObj(GroupPtr, ObjPtr)
+   struct GroupRec *GroupPtr;
+   struct ObjRec *ObjPtr;
 {
-   register struct GroupRec	* group_ptr;
-   struct ObjRec		* top_obj;
-   struct ObjRec		* from_obj_ptr, * to_obj_ptr;
+   register struct GroupRec *group_ptr;
+   struct ObjRec *top_obj;
+   struct ObjRec *from_obj_ptr, *to_obj_ptr;
 
    group_ptr = (struct GroupRec *)malloc(sizeof(struct GroupRec));
    if (group_ptr == NULL) FailAllocMessage();
    memset(group_ptr, 0, sizeof(struct GroupRec));
    top_obj = NULL;
    from_obj_ptr = GroupPtr->last;
-   for ( ; from_obj_ptr != NULL; from_obj_ptr = from_obj_ptr->prev)
-   {
-      to_obj_ptr = DupObj (from_obj_ptr);
+   for ( ; from_obj_ptr != NULL; from_obj_ptr=from_obj_ptr->prev) {
+      to_obj_ptr = DupObj(from_obj_ptr);
       to_obj_ptr->next = top_obj;
-      if (top_obj == NULL)
+      if (top_obj == NULL) {
          group_ptr->last = to_obj_ptr;
-      else
+      } else {
          top_obj->prev = to_obj_ptr;
+      }
       top_obj = to_obj_ptr;
    }
    top_obj->prev = NULL;
@@ -821,95 +805,92 @@ void DupGroupObj (GroupPtr, ObjPtr)
    ObjPtr->detail.r = group_ptr;
 }
 
-struct ObjRec * DupObj (ObjPtr)
-   struct ObjRec	* ObjPtr;
+struct ObjRec *DupObj(ObjPtr)
+   struct ObjRec *ObjPtr;
 {
-   struct ObjRec	* obj_ptr;
+   struct ObjRec *obj_ptr;
 
    obj_ptr = (struct ObjRec *)malloc(sizeof(struct ObjRec));
    if (obj_ptr == NULL) FailAllocMessage();
    memset(obj_ptr, 0, sizeof(struct ObjRec));
-   DupObjBasics (ObjPtr, obj_ptr);
+   DupObjBasics(ObjPtr, obj_ptr);
 
-   switch (ObjPtr->type)
-   {
-      case OBJ_POLY:
-         DupPolyObj (ObjPtr->detail.p, obj_ptr);
-         DupAttrs (ObjPtr, obj_ptr);
-         break;
-      case OBJ_BOX:
-         DupBoxObj (ObjPtr->detail.b, obj_ptr);
-         DupAttrs (ObjPtr, obj_ptr);
-         break;
-      case OBJ_OVAL:
-         DupOvalObj (ObjPtr->detail.o, obj_ptr);
-         DupAttrs (ObjPtr, obj_ptr);
-         break;
-      case OBJ_TEXT: DupTextObj (ObjPtr->detail.t, ObjPtr, obj_ptr); break;
-      case OBJ_POLYGON:
-         DupPolygonObj (ObjPtr->detail.g, obj_ptr);
-         DupAttrs (ObjPtr, obj_ptr);
-         break;
-      case OBJ_ARC:
-         DupArcObj (ObjPtr->detail.a, obj_ptr);
-         DupAttrs (ObjPtr, obj_ptr);
-         break;
-      case OBJ_RCBOX:
-         DupRCBoxObj (ObjPtr->detail.rcb, obj_ptr);
-         DupAttrs (ObjPtr, obj_ptr);
-         break;
-      case OBJ_XBM:
-         DupXBmObj (ObjPtr->detail.xbm, obj_ptr);
-         DupAttrs (ObjPtr, obj_ptr);
-         break;
-      case OBJ_XPM:
-         DupXPmObj (ObjPtr->detail.xpm, obj_ptr);
-         DupAttrs (ObjPtr, obj_ptr);
-         break;
-      case OBJ_SYM:
-      case OBJ_GROUP:
-      case OBJ_ICON:
-         DupGroupObj (ObjPtr->detail.r, obj_ptr);
-         DupAttrs (ObjPtr, obj_ptr);
-         if (obj_ptr->type == OBJ_ICON)
-         {
-            strcpy (obj_ptr->detail.r->s, ObjPtr->detail.r->s);
-            obj_ptr->detail.r->rotate = ObjPtr->detail.r->rotate;
-            obj_ptr->detail.r->flip = ObjPtr->detail.r->flip;
-            obj_ptr->detail.r->deck_index = (-1);
-         }
-         break;
+   switch (ObjPtr->type) {
+   case OBJ_POLY:
+      DupPolyObj(ObjPtr->detail.p, obj_ptr);
+      DupAttrs(ObjPtr, obj_ptr);
+      break;
+   case OBJ_BOX:
+      DupBoxObj(ObjPtr->detail.b, obj_ptr);
+      DupAttrs(ObjPtr, obj_ptr);
+      break;
+   case OBJ_OVAL:
+      DupOvalObj(ObjPtr->detail.o, obj_ptr);
+      DupAttrs(ObjPtr, obj_ptr);
+      break;
+   case OBJ_TEXT: DupTextObj(ObjPtr->detail.t, ObjPtr, obj_ptr); break;
+   case OBJ_POLYGON:
+      DupPolygonObj(ObjPtr->detail.g, obj_ptr);
+      DupAttrs(ObjPtr, obj_ptr);
+      break;
+   case OBJ_ARC:
+      DupArcObj(ObjPtr->detail.a, obj_ptr);
+      DupAttrs(ObjPtr, obj_ptr);
+      break;
+   case OBJ_RCBOX:
+      DupRCBoxObj(ObjPtr->detail.rcb, obj_ptr);
+      DupAttrs(ObjPtr, obj_ptr);
+      break;
+   case OBJ_XBM:
+      DupXBmObj(ObjPtr->detail.xbm, obj_ptr);
+      DupAttrs(ObjPtr, obj_ptr);
+      break;
+   case OBJ_XPM:
+      DupXPmObj(ObjPtr->detail.xpm, obj_ptr);
+      DupAttrs(ObjPtr, obj_ptr);
+      break;
+   case OBJ_SYM:
+   case OBJ_GROUP:
+   case OBJ_ICON:
+      DupGroupObj(ObjPtr->detail.r, obj_ptr);
+      DupAttrs(ObjPtr, obj_ptr);
+      if (obj_ptr->type == OBJ_ICON) {
+         strcpy(obj_ptr->detail.r->s, ObjPtr->detail.r->s);
+         obj_ptr->detail.r->rotate = ObjPtr->detail.r->rotate;
+         obj_ptr->detail.r->flip = ObjPtr->detail.r->flip;
+         obj_ptr->detail.r->deck_index = (-1);
+      }
+      break;
    }
-   return (obj_ptr);
+   return obj_ptr;
 }
 
-void DupSelObj ()
+void DupSelObj()
 {
-   struct SelRec	* sel_ptr, * sel_ptr1;
-   struct ObjRec	* obj_ptr, * top_obj, * bot_obj;
-   int			dx = 0, dy = 0;
+   struct SelRec *sel_ptr, *sel_ptr1;
+   struct ObjRec *obj_ptr, *top_obj, *bot_obj;
+   int dx=0, dy=0;
 
    if (topSel==NULL || curChoice==VERTEXMODE) return;
 
    top_obj = bot_obj = NULL;
-   for (sel_ptr = botSel; sel_ptr != NULL; sel_ptr = sel_ptr->prev)
-   {
-      obj_ptr = DupObj (sel_ptr->obj);
+   for (sel_ptr=botSel; sel_ptr != NULL; sel_ptr=sel_ptr->prev) {
+      obj_ptr = DupObj(sel_ptr->obj);
       obj_ptr->next = top_obj;
-      if (top_obj == NULL)
+      if (top_obj == NULL) {
          bot_obj = obj_ptr;
-      else
+      } else {
          top_obj->prev = obj_ptr;
+      }
       top_obj = obj_ptr;
    }
    top_obj->prev = NULL;
 
-   HighLightReverse ();
+   HighLightReverse();
 
    sel_ptr = botSel;
    sel_ptr1 = sel_ptr->prev;
-   for (obj_ptr = bot_obj; sel_ptr1 != NULL; obj_ptr = obj_ptr->prev)
-   {
+   for (obj_ptr=bot_obj; sel_ptr1 != NULL; obj_ptr=obj_ptr->prev) {
       sel_ptr->obj = obj_ptr;
       sel_ptr = sel_ptr1;
       sel_ptr1 = sel_ptr1->prev;
@@ -920,39 +901,37 @@ void DupSelObj ()
    topObj->prev = bot_obj;
    curPage->top = topObj = top_obj;
 
-   if (justDupped && useRecentDupDistance)
-   {
+   if (justDupped && useRecentDupDistance) {
       dx = dupDx;
       dy = dupDy;
-   }
-   else
-   {
-      switch (gridSystem)
-      {
-         case ENGLISH_GRID:
-            if (gridOn)
-               dupDx = dupDy = dx = dy = GRID_ABS_SIZE(xyEnglishGrid);
-            else
-               dupDx = dupDy = dx = dy = GRID_ABS_SIZE(DEFAULT_ENGLISH_GRID);
-            break;
-         case METRIC_GRID:
-            if (gridOn)
-               dupDx = dupDy = dx = dy = GRID_ABS_SIZE(xyMetricGrid);
-            else
-               dupDx = dupDy = dx = dy = GRID_ABS_SIZE(DEFAULT_METRIC_GRID);
-            break;
+   } else {
+      switch (gridSystem) {
+      case ENGLISH_GRID:
+         if (gridOn) {
+            dupDx = dupDy = dx = dy = GRID_ABS_SIZE(xyEnglishGrid);
+         } else {
+            dupDx = dupDy = dx = dy = GRID_ABS_SIZE(DEFAULT_ENGLISH_GRID);
+         }
+         break;
+      case METRIC_GRID:
+         if (gridOn) {
+            dupDx = dupDy = dx = dy = GRID_ABS_SIZE(xyMetricGrid);
+         } else {
+            dupDx = dupDy = dx = dy = GRID_ABS_SIZE(DEFAULT_METRIC_GRID);
+         }
+         break;
       }
       justDupped = TRUE;
    }
 
-   MoveAllSelObjects (dx, dy);
-   PrepareToRecord (CMD_NEW, NULL, NULL, 0);
-   RecordCmd (CMD_NEW, NULL, topSel, botSel, numObjSelected);
-   UpdSelBBox ();
-   RedrawAnArea (botObj, selLtX-(GRID_ABS_SIZE(1)), selLtY-(GRID_ABS_SIZE(1)),
+   MoveAllSelObjects(dx, dy);
+   PrepareToRecord(CMD_NEW, NULL, NULL, 0);
+   RecordCmd(CMD_NEW, NULL, topSel, botSel, numObjSelected);
+   UpdSelBBox();
+   RedrawAnArea(botObj, selLtX-(GRID_ABS_SIZE(1)), selLtY-(GRID_ABS_SIZE(1)),
          selRbX+(GRID_ABS_SIZE(1)), selRbY+(GRID_ABS_SIZE(1)));
-   HighLightForward ();
-   SetFileModified (TRUE);
+   HighLightForward();
+   SetFileModified(TRUE);
 }
 
 void DupTheseObjects(TopSel, BotSel, NewTopSel, NewBotSel)
@@ -985,8 +964,8 @@ void DupTheseObjects(TopSel, BotSel, NewTopSel, NewBotSel)
    (*NewTopSel)->prev = NULL;
 }
 
-void JustDupSelObj (NewTopSel, NewBotSel)
-   struct SelRec	* * NewTopSel, * * NewBotSel;
+void JustDupSelObj(NewTopSel, NewBotSel)
+   struct SelRec **NewTopSel, **NewBotSel;
 {
-   DupTheseObjects (topSel, botSel, NewTopSel, NewBotSel);
+   DupTheseObjects(topSel, botSel, NewTopSel, NewBotSel);
 }
