@@ -5,7 +5,7 @@
  *
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -19,9 +19,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -30,11 +31,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/ftp.c,v 3.13 1998/11/05 22:56:14 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/ftp.c,v 3.0 1996/05/06 22:06:00 william Exp $";
-#endif
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -49,9 +48,12 @@ static char RCSid[] =
 #ifdef isc /* SunSoft/Interactive UNIX */
 #include <net/errno.h>
 #endif
+#include <X11/Xlib.h>
 
 #include "const.h"
+#include "types.h"
 
+#include "file.e"
 #ifndef _NO_EXTERN
 #include "ftp.e"
 #endif /* !_NO_EXTERN */
@@ -59,7 +61,8 @@ static char RCSid[] =
 #include "tcp.e"
 #include "util.e"
 
-static int debugFtp=FALSE;
+int debugFtp=0;
+
 static int gnReadyToReceiveData=FALSE;
 
 void FtpFreeBuf(buf)
@@ -150,7 +153,7 @@ void FtpDumpResponse(func_name, buf)
    char *c_ptr=strchr(buf, '\n'), *line_ptr=buf;
    FILE *fp=stdout;
 
-   if (debugFtp) fprintf(fp, "In %s:\n", func_name);
+   if (debugFtp > 0) fprintf(fp, "In %s:\n", func_name);
    while (c_ptr != NULL) {
       char *prev_ptr=c_ptr;
 
@@ -160,7 +163,7 @@ void FtpDumpResponse(func_name, buf)
          prev_ptr = NULL;
          *c_ptr = '\0';
       }
-      if (debugFtp) fprintf(fp, "  %s\n", line_ptr);
+      if (debugFtp > 0) fprintf(fp, "  %s\n", line_ptr);
       if (prev_ptr == NULL) {
          *c_ptr = '\n';
       } else {
@@ -174,10 +177,10 @@ void FtpDumpResponse(func_name, buf)
 
       if (len > 0 && line_ptr[len-1] == '\r') {
          line_ptr[len-1] = '\0';
-         if (debugFtp) fprintf(fp, "  %s\n", line_ptr);
+         if (debugFtp > 0) fprintf(fp, "  %s\n", line_ptr);
          line_ptr[len-1] = '\r';
       } else {
-         if (debugFtp) fprintf(fp, "  %s\n", line_ptr);
+         if (debugFtp > 0) fprintf(fp, "  %s\n", line_ptr);
       }
    }
 }
@@ -207,6 +210,10 @@ int FtpDoRead(n_socket, ppsz_buf, pn_buf_sz)
          buf_sz += 0x400;
          if ((buf=(char*)realloc(buf, buf_sz)) == NULL) {
             fprintf(stderr, "Memory allocation failed.\n");
+            if (PRTGIF && cmdLineDumpURL && cmdLineDumpURLShowStatus &&
+                  pn_buf_sz != NULL) {
+               fprintf(stderr, "\n");
+            }
             return TG_REMOTE_STATUS_MEM;
          }
       }
@@ -217,10 +224,18 @@ int FtpDoRead(n_socket, ppsz_buf, pn_buf_sz)
                errno == EPIPE)) {
             free(buf);
             fprintf(stderr, "Network read error.\n");
+            if (PRTGIF && cmdLineDumpURL && cmdLineDumpURLShowStatus &&
+                  pn_buf_sz != NULL) {
+               fprintf(stderr, "\n");
+            }
             return TG_REMOTE_STATUS_READ;
          } else if (bytes_read < 0) {
             free(buf);
             fprintf(stderr, "Network error.\n");
+            if (PRTGIF && cmdLineDumpURL && cmdLineDumpURLShowStatus &&
+                  pn_buf_sz != NULL) {
+               fprintf(stderr, "\n");
+            }
             return TG_REMOTE_STATUS_NET;
          }
          end_of_file = TRUE;
@@ -230,6 +245,10 @@ int FtpDoRead(n_socket, ppsz_buf, pn_buf_sz)
       if (!end_of_file && UserAbortComm()) {
          if (buf != NULL) free(buf);
          ShowRemoteStatus("FTP: aborted by the user.");
+         if (PRTGIF && cmdLineDumpURL && cmdLineDumpURLShowStatus &&
+               pn_buf_sz != NULL) {
+            fprintf(stderr, "\n");
+         }
          return TG_REMOTE_STATUS_INTR;
       } else {
          char msg[40], *c_ptr;
@@ -237,6 +256,10 @@ int FtpDoRead(n_socket, ppsz_buf, pn_buf_sz)
 
          sprintf(msg, "FTP: %1d bytes...", len);
          ShowRemoteStatus(msg);
+         if (PRTGIF && cmdLineDumpURL && cmdLineDumpURLShowStatus &&
+               pn_buf_sz != NULL) {
+            fprintf(stderr, "FTP: %1d bytes...\r", len);
+         }
          buf[len] = '\0';
          if (!ftpReadData) {
             for (c_ptr=buf; *c_ptr != '\0'; c_ptr++) {
@@ -262,6 +285,10 @@ int FtpDoRead(n_socket, ppsz_buf, pn_buf_sz)
          }
       }
    } while (!end_of_file);
+   if (PRTGIF && cmdLineDumpURL && cmdLineDumpURLShowStatus &&
+         pn_buf_sz != NULL) {
+      fprintf(stderr, "\n");
+   }
    if (debugFtp >= 2) fprintf(stderr, "    rc = %1d in FtpDoRead().\n", rc);
    if (rc == 421) {
       free(buf);
@@ -308,6 +335,14 @@ int FtpSendPassword(n_socket, password)
    return FtpSendSimpleCmd(n_socket, password);
 }
 
+static
+int FtpSendType(n_socket, type_cmd)
+   int n_socket;
+   char *type_cmd;
+{
+   return FtpSendSimpleCmd(n_socket, type_cmd);
+}
+
 static
 int FtpSendRetrieveCmd(n_socket, psz_path)
    int n_socket;
@@ -521,6 +556,24 @@ int FtpPort(n_socket, pn_data_socket)
    return status;
 }
 
+static
+int FtpType(n_socket)
+   int n_socket;
+{
+   char *buf=NULL;
+   int status, ftp_cmd=(-1);
+
+   if ((status=FtpReadCmd(n_socket, &buf, &ftp_cmd)) == TG_REMOTE_STATUS_OK) {
+      FtpDumpResponse("FtpType", buf);
+      status = TG_REMOTE_STATUS_FORMAT;
+      if (ftp_cmd == 2) {
+         status = FtpSendType(n_socket, "TYPE I");
+      }
+      FtpFreeBuf(buf);
+   }
+   return status;
+}
+
 static
 int FtpRetr(n_socket, psz_path)
    int n_socket;
@@ -616,6 +669,7 @@ int FtpDoTalk(n_socket, psz_path, ppsz_buf, pn_buf_sz)
    if ((status=FtpPort(n_socket, &data_socket)) != TG_REMOTE_STATUS_OK) {
       return status;
    }
+   if ((status=FtpType(n_socket)) != TG_REMOTE_STATUS_OK) return status;
    if ((status=FtpRetr(n_socket, psz_path)) != TG_REMOTE_STATUS_OK) {
       if (data_socket != (-1)) close(data_socket);
       return (FTP_LOGGED_IN|status);
