@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/group.c,v 3.15 1998/11/05 22:56:14 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /n/opus/u/guest/william/src/tgif/v3/RCS/group.c,v 3.0 1996/05/06 16:05:24 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -54,13 +53,13 @@ static char RCSid[] =
 #include "select.e"
 #include "setup.e"
 
-static struct SelRec	* tmpTopSel, * tmpBotSel;
+int gnDeleteAttrsWhileUngrouping=FALSE;
 
-void CreateGroupObj (TopObjPtr, BotObjPtr)
-   struct ObjRec	* TopObjPtr, * BotObjPtr;
+void CreateGroupObj(TopObjPtr, BotObjPtr)
+   struct ObjRec *TopObjPtr, *BotObjPtr;
 {
-   struct GroupRec	* group_ptr;
-   struct ObjRec	* obj_ptr;
+   struct GroupRec *group_ptr;
+   struct ObjRec *obj_ptr;
 
    group_ptr = (struct GroupRec *)malloc(sizeof(struct GroupRec));
    if (group_ptr == NULL) FailAllocMessage();
@@ -91,69 +90,69 @@ void CreateGroupObj (TopObjPtr, BotObjPtr)
    obj_ptr->ctm = NULL;
    obj_ptr->invisible = FALSE;
    if (numObjLocked > 0) obj_ptr->locked = TRUE;
-   AddObj (NULL, topObj, obj_ptr);
+   AddObj(NULL, topObj, obj_ptr);
 }
 
-void SaveGroupObj (FP, ObjPtr, Level)
-   FILE			* FP;
-   struct ObjRec	* ObjPtr;
-   int			Level;
+void SaveGroupObj(FP, ObjPtr, Level)
+   FILE *FP;
+   struct ObjRec *ObjPtr;
+   int Level;
 {
-   if (fprintf (FP, "group([\n") == EOF) writeFileFailed = TRUE;
-   Save (FP, ObjPtr->detail.r->last, Level+1, INVALID);
-   if (fprintf (FP, "],\n") == EOF) writeFileFailed = TRUE;
-   if (fprintf (FP, "%1d,%1d,%1d,", ObjPtr->id, ObjPtr->locked,
+   if (fprintf(FP, "group([\n") == EOF) writeFileFailed = TRUE;
+   Save(FP, ObjPtr->detail.r->last, Level+1, INVALID);
+   if (fprintf(FP, "],\n") == EOF) writeFileFailed = TRUE;
+   if (fprintf(FP, "%1d,%1d,%1d,", ObjPtr->id, ObjPtr->locked,
          ObjPtr->invisible) == EOF) {
       writeFileFailed = TRUE;
    }
-   SaveAttrs (FP, ObjPtr->lattr);
-   if (fprintf (FP, ")") == EOF) writeFileFailed = TRUE;
+   SaveAttrs(FP, ObjPtr->lattr);
+   if (fprintf(FP, ")") == EOF) writeFileFailed = TRUE;
 }
 
-void SaveCompObj (FP, ObjPtr, Level)
-   FILE			* FP;
-   struct ObjRec	* ObjPtr;
-   int			Level;
+void SaveCompObj(FP, ObjPtr, Level)
+   FILE *FP;
+   struct ObjRec *ObjPtr;
+   int Level;
 {
-   if (fprintf (FP, "sym([\n") == EOF) writeFileFailed = TRUE;
-   Save (FP, ObjPtr->detail.r->last, Level+1, INVALID);
-   if (fprintf (FP, "],\n") == EOF) writeFileFailed = TRUE;
-   if (fprintf (FP, "%1d,%1d,%1d,", ObjPtr->id, ObjPtr->locked,
+   if (fprintf(FP, "sym([\n") == EOF) writeFileFailed = TRUE;
+   Save(FP, ObjPtr->detail.r->last, Level+1, INVALID);
+   if (fprintf(FP, "],\n") == EOF) writeFileFailed = TRUE;
+   if (fprintf(FP, "%1d,%1d,%1d,", ObjPtr->id, ObjPtr->locked,
          ObjPtr->invisible) == EOF) {
       writeFileFailed = TRUE;
    }
-   SaveAttrs (FP, ObjPtr->lattr);
-   if (fprintf (FP, ")") == EOF) writeFileFailed = TRUE;
+   SaveAttrs(FP, ObjPtr->lattr);
+   if (fprintf(FP, ")") == EOF) writeFileFailed = TRUE;
 }
 
-void SaveIconObj (FP, ObjPtr, Level)
-   FILE			* FP;
-   struct ObjRec	* ObjPtr;
-   int			Level;
+void SaveIconObj(FP, ObjPtr, Level)
+   FILE *FP;
+   struct ObjRec *ObjPtr;
+   int Level;
 {
-   if (fprintf (FP, "icon([\n") == EOF) writeFileFailed = TRUE;
-   Save (FP, ObjPtr->detail.r->last, Level+1, INVALID);
-   if (fprintf (FP, "],\n") == EOF) writeFileFailed = TRUE;
-   if (fprintf (FP, "\"%s\",%1d,%1d,%1d,%1d,%1d,",
+   if (fprintf(FP, "icon([\n") == EOF) writeFileFailed = TRUE;
+   Save(FP, ObjPtr->detail.r->last, Level+1, INVALID);
+   if (fprintf(FP, "],\n") == EOF) writeFileFailed = TRUE;
+   if (fprintf(FP, "\"%s\",%1d,%1d,%1d,%1d,%1d,",
          ObjPtr->detail.r->s, ObjPtr->id, ObjPtr->detail.r->rotate,
          ObjPtr->detail.r->flip, ObjPtr->locked, ObjPtr->invisible) == EOF) {
       writeFileFailed = TRUE;
    }
-   SaveAttrs (FP, ObjPtr->lattr);
-   if (fprintf (FP, ")") == EOF) writeFileFailed = TRUE;
+   SaveAttrs(FP, ObjPtr->lattr);
+   if (fprintf(FP, ")") == EOF) writeFileFailed = TRUE;
 }
 
-void ReadGroupObj (FP, ObjType, ObjPtr)
-   FILE			* FP;
-   int			ObjType;
-   struct ObjRec	* * ObjPtr;
+void ReadGroupObj(FP, ObjType, ObjPtr)
+   FILE *FP;
+   int ObjType;
+   struct ObjRec **ObjPtr;
 {
-   struct GroupRec	* group_ptr;
-   struct ObjRec	* top_obj = NULL, * bot_obj = NULL, * obj_ptr;
-   int			ltx, lty, rbx, rby, id=0, locked=FALSE;
-   int			obj_ltx, obj_lty, obj_rbx, obj_rby, rotate=0, flip=0;
-   int			invisible=FALSE;
-   char			line[MAXSTRING+1], * s, * s1, tmp_str[MAXSTRING+1];
+   struct GroupRec *group_ptr;
+   struct ObjRec *top_obj=NULL, *bot_obj=NULL, *obj_ptr;
+   int ltx, lty, rbx, rby, id=0, locked=FALSE;
+   int obj_ltx, obj_lty, obj_rbx, obj_rby, rotate=0, flip=0;
+   int invisible=FALSE;
+   char line[MAXSTRING+1], *s, *s1, tmp_str[MAXSTRING+1];
 
    *ObjPtr = NULL;
    while (ReadObj(FP, &obj_ptr)) {
@@ -310,9 +309,9 @@ void ReadGroupObj (FP, ObjType, ObjPtr)
 }
 
 void FreeGroupObj (ObjPtr)
-   struct ObjRec	* ObjPtr;
+   struct ObjRec *ObjPtr;
 {
-   register struct ObjRec	* ptr, * next_obj;
+   register struct ObjRec *ptr, *next_obj;
 
    for (ptr = ObjPtr->detail.r->first; ptr != NULL; ptr = next_obj) {
       next_obj = ptr->next;
@@ -322,38 +321,36 @@ void FreeGroupObj (ObjPtr)
    free(ObjPtr);
 }
 
-static
-void UngroupObj (ObjPtr)
-   struct ObjRec	* ObjPtr;
+void UngroupObj(ObjPtr, TopSelPtr, BotSelPtr)
+   struct ObjRec *ObjPtr;
+   struct SelRec **TopSelPtr, **BotSelPtr;
    /* ungroup the grouped object ObjPtr to a list of objects   */
    /* when returns, a list of select pointers will be created, */
-   /*    tmpTopSel will point to the top of the list, and      */
-   /*    tmpBotSel will point to the bottom of the list.       */
+   /*    *TopSelPtr will point to the top of the list, and     */
+   /*    *BotSelPtr will point to the bottom of the list.      */
 {
-   register struct SelRec	* sel_ptr;
-   register struct ObjRec	* obj_ptr = ObjPtr->detail.r->last;
-
-   tmpTopSel = tmpBotSel = NULL;
+   register struct SelRec *sel_ptr;
+   register struct ObjRec *obj_ptr=ObjPtr->detail.r->last;
 
    for ( ; obj_ptr != NULL; obj_ptr=obj_ptr->prev) {
       sel_ptr = (struct SelRec *)malloc(sizeof(struct SelRec));
       if (sel_ptr == NULL) FailAllocMessage();
       sel_ptr->obj = obj_ptr;
-      sel_ptr->next = tmpTopSel;
-      if (tmpTopSel == NULL) {
-         tmpBotSel = sel_ptr;
+      sel_ptr->next = (*TopSelPtr);
+      if (*TopSelPtr == NULL) {
+         *BotSelPtr = sel_ptr;
       } else {
-         tmpTopSel->prev = sel_ptr;
+         (*TopSelPtr)->prev = sel_ptr;
       }
-      tmpTopSel = sel_ptr;
+      *TopSelPtr = sel_ptr;
    }
-   tmpTopSel->prev = NULL;
+   (*TopSelPtr)->prev = NULL;
 }
 
 static
 int NoObjToUngroup ()
 {
-   register struct SelRec	* sel_ptr;
+   register struct SelRec *sel_ptr;
 
    for (sel_ptr = topSel; sel_ptr != NULL; sel_ptr = sel_ptr->next)
       if (sel_ptr->obj->type == OBJ_GROUP)
@@ -361,88 +358,91 @@ int NoObjToUngroup ()
    return (TRUE);
 }
 
-void UngroupSelObj ()
+void UngroupSelObj()
 {
-   register struct SelRec	* sel_ptr, * next_sel;
-   register struct ObjRec	* obj_ptr;
-   int				sel_ltx, sel_lty, sel_rbx, sel_rby;
-   int				changed=FALSE;
+   register struct SelRec *sel_ptr, *next_sel;
+   register struct ObjRec *obj_ptr;
+   int sel_ltx, sel_lty, sel_rbx, sel_rby;
+   int changed=FALSE;
 
-   if (topSel==NULL || NoObjToUngroup ()) return;
+   if (topSel==NULL || NoObjToUngroup()) return;
 
    sel_ltx = selLtX; sel_lty = selLtY;
    sel_rbx = selRbX; sel_rby = selRbY;
 
-   HighLightReverse ();
-   StartCompositeCmd ();
-   for (sel_ptr = topSel; sel_ptr != NULL; sel_ptr = next_sel)
-   {
+   HighLightReverse();
+   StartCompositeCmd();
+   for (sel_ptr=topSel; sel_ptr != NULL; sel_ptr=next_sel) {
       next_sel = sel_ptr->next;
       obj_ptr = sel_ptr->obj;
-      if (obj_ptr->type == OBJ_GROUP)
-      {
-         int		count;
-         struct SelRec	* tmp_sel_ptr;
+      if (obj_ptr->type == OBJ_GROUP) {
+         int count;
+         struct SelRec *tmp_sel_ptr, *tmp_top_sel=NULL, *tmp_bot_sel=NULL;
 
          changed = TRUE;
-         PrepareToReplaceAnObj (obj_ptr);
-
-         UngroupObj (obj_ptr);
-         DetachGroupAttrs (obj_ptr, &tmpTopSel, &tmpBotSel);
+         PrepareToReplaceAnObj(obj_ptr);
 
+         UngroupObj(obj_ptr, &tmp_top_sel, &tmp_bot_sel);
+         if (gnDeleteAttrsWhileUngrouping) {
+            DelAllAttrs(obj_ptr->fattr);
+         } else {
+            DetachGroupAttrs(obj_ptr, &tmp_top_sel, &tmp_bot_sel);
+         }
          obj_ptr->detail.r->first->prev = obj_ptr->prev;
-         if (obj_ptr->prev == NULL)
+         if (obj_ptr->prev == NULL) {
             curPage->top = topObj = obj_ptr->detail.r->first;
-         else
+         } else {
             obj_ptr->prev->next = obj_ptr->detail.r->first;
+         }
          obj_ptr->detail.r->last->next = obj_ptr->next;
-         if (obj_ptr->next == NULL)
+         if (obj_ptr->next == NULL) {
             curPage->bot = botObj = obj_ptr->detail.r->last;
-         else
+         } else {
             obj_ptr->next->prev = obj_ptr->detail.r->last;
-
+         }
          count = 0;
-         for (tmp_sel_ptr=tmpTopSel; tmp_sel_ptr!=NULL;
-               tmp_sel_ptr=tmp_sel_ptr->next)
+         for (tmp_sel_ptr=tmp_top_sel; tmp_sel_ptr!=NULL;
+               tmp_sel_ptr=tmp_sel_ptr->next) {
             count++;
-         RecordCmd (CMD_ONE_TO_MANY, NULL, tmpTopSel, tmpBotSel, count);
-
-         tmpTopSel->prev = sel_ptr->prev;
-         if (sel_ptr->prev == NULL)
-            topSel = tmpTopSel;
-         else
-            sel_ptr->prev->next = tmpTopSel;
-         tmpBotSel->next = sel_ptr->next;
-         if (sel_ptr->next == NULL)
-            botSel = tmpBotSel;
-         else
-            sel_ptr->next->prev = tmpBotSel;
+         }
+         RecordCmd(CMD_ONE_TO_MANY, NULL, tmp_top_sel, tmp_bot_sel, count);
 
+         tmp_top_sel->prev = sel_ptr->prev;
+         if (sel_ptr->prev == NULL) {
+            topSel = tmp_top_sel;
+         } else {
+            sel_ptr->prev->next = tmp_top_sel;
+         }
+         tmp_bot_sel->next = sel_ptr->next;
+         if (sel_ptr->next == NULL) {
+            botSel = tmp_bot_sel;
+         } else {
+            sel_ptr->next->prev = tmp_bot_sel;
+         }
          free(sel_ptr);
          free(obj_ptr);
       }
    }
-   EndCompositeCmd ();
-   if (changed)
-   {
-      UpdSelBBox ();
-      RedrawAreas (botObj,
+   EndCompositeCmd();
+   if (changed) {
+      UpdSelBBox();
+      RedrawAreas(botObj,
             sel_ltx-GRID_ABS_SIZE(1), sel_lty-GRID_ABS_SIZE(1),
             sel_rbx+GRID_ABS_SIZE(1), sel_rby+GRID_ABS_SIZE(1),
             selLtX-GRID_ABS_SIZE(1), selLtY-GRID_ABS_SIZE(1),
             selRbX+GRID_ABS_SIZE(1), selRbY+GRID_ABS_SIZE(1));
-      SetFileModified (TRUE);
+      SetFileModified(TRUE);
       justDupped = FALSE;
-      Msg ("Selected objects are ungrouped.");
+      Msg("Selected objects are ungrouped.");
    }
-   HighLightForward ();
+   HighLightForward();
 }
 
 void LockSelObj ()
 {
-   register struct SelRec	* sel_ptr;
-   register struct ObjRec	* obj_ptr;
-   int				changed=FALSE;
+   register struct SelRec *sel_ptr;
+   register struct ObjRec *obj_ptr;
+   int changed=FALSE;
 
    if (topSel==NULL) { Msg ("No object to lock!"); return; }
    if (curChoice==VERTEXMODE) { Msg ("Can not lock in vertex mode!"); return; }
@@ -473,9 +473,9 @@ void LockSelObj ()
 
 void UnlockSelObj ()
 {
-   register struct SelRec	* sel_ptr;
-   register struct ObjRec	* obj_ptr;
-   int				changed=FALSE;
+   register struct SelRec *sel_ptr;
+   register struct ObjRec *obj_ptr;
+   int changed=FALSE;
 
    if (topSel==NULL) { Msg ("No object to unlock!"); return; }
    if (curChoice==VERTEXMODE) { Msg("Can not unlock in vertex mode!"); return; }
