@@ -5,7 +5,7 @@
  *
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -19,9 +19,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -30,11 +31,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/http.c,v 3.21 1998/11/05 22:56:15 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/http.c,v 3.4 1996/11/29 23:08:26 william Exp $";
-#endif
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -963,7 +962,7 @@ char *HttpExtractText(buf, pn_buf_sz, pn_html, ppsz_content_type)
       c_ptr = strchr(line_ptr, '\n');
    }
    if (content_type != NULL) free(content_type);
-   if (text_type) {
+   if (text_type || content_length == (-1)) {
       int buf_len=strlen(line_ptr);
       char *return_buf;
 
@@ -1008,6 +1007,74 @@ char *HttpExtractText(buf, pn_buf_sz, pn_html, ppsz_content_type)
    return NULL;
 }
 
+static
+int GetContentLength(buf, pn_header_len)
+   char *buf;
+   int *pn_header_len;
+{
+   char *c_ptr, *line_ptr=buf;
+   int content_len=(-1);
+
+   c_ptr = strstr(line_ptr, "\r\n");
+   if (c_ptr == NULL) {
+      for (c_ptr=strchr(line_ptr, '\n'); c_ptr != NULL;
+            c_ptr=strchr(line_ptr, '\n')) {
+         char *colon_ptr;
+
+         if (c_ptr == line_ptr) {
+            *pn_header_len = ((&c_ptr[1]) - buf);
+            return (content_len==(-1) ? 0 : content_len);
+         }
+         *c_ptr = '\0';
+         colon_ptr = strchr(line_ptr, ':');
+         if (colon_ptr != NULL) {
+            *colon_ptr = '\0';
+            if (UtilStrICmp(line_ptr, "Content-Length") == 0) {
+               char length_str[MAXSTRING];
+               int len;
+
+               UtilStrCpy(length_str, MAXSTRING-1, &colon_ptr[1]);
+               UtilTrimBlanks(length_str);
+               if (sscanf(length_str, "%d", &len) == 1) {
+                  content_len = len;
+               }
+            }
+            *colon_ptr = ':';
+         }
+         *c_ptr = '\n';
+         line_ptr = (&c_ptr[1]);
+      }
+   } else {
+      for ( ; c_ptr != NULL; c_ptr=strstr(line_ptr, "\r\n")) {
+         char *colon_ptr;
+
+         if (c_ptr == line_ptr) {
+            *pn_header_len = ((&c_ptr[2]) - buf);
+            return (content_len==(-1) ? 0 : content_len);
+         }
+         *c_ptr = '\0';
+         colon_ptr = strchr(line_ptr, ':');
+         if (colon_ptr != NULL) {
+            *colon_ptr = '\0';
+            if (UtilStrICmp(line_ptr, "Content-Length") == 0) {
+               char length_str[MAXSTRING];
+               int len;
+
+               UtilStrCpy(length_str, MAXSTRING-1, &colon_ptr[1]);
+               UtilTrimBlanks(length_str);
+               if (sscanf(length_str, "%d", &len) == 1) {
+                  content_len = len;
+               }
+            }
+            *colon_ptr = ':';
+         }
+         *c_ptr = '\r';
+         line_ptr = (&c_ptr[2]);
+      }
+   }
+   return (-1);
+}
+
 #define MIN_READ_SIZE 0x100
 
 int HttpDoRead(n_socket, ppsz_buf, pn_buf_sz)
@@ -1015,8 +1082,8 @@ int HttpDoRead(n_socket, ppsz_buf, pn_buf_sz)
    char **ppsz_buf;
 {
    int buf_sz=0x400, len=0, end_of_file=FALSE;
-   int status=TG_REMOTE_STATUS_OK;
-   char *buf=(char*)malloc(buf_sz*sizeof(char)), msg[40];
+   int status=TG_REMOTE_STATUS_OK, content_len=(-1), header_len=0;
+   char *buf=(char*)malloc(buf_sz*sizeof(char)), msg[MAXSTRING];
 
    if (pn_buf_sz != NULL) *pn_buf_sz = 0;
    *ppsz_buf = NULL;
@@ -1055,10 +1122,30 @@ int HttpDoRead(n_socket, ppsz_buf, pn_buf_sz)
       if (status == TG_REMOTE_STATUS_OK && !end_of_file && UserAbortComm()) {
          if (buf != NULL) free(buf);
          ShowRemoteStatus("HTTP: aborted by the user.");
+         if (PRTGIF && cmdLineDumpURL && cmdLineDumpURLShowStatus) {
+            fprintf(stderr, "\n");
+         }
          return TG_REMOTE_STATUS_INTR;
       } else {
-         sprintf(msg, "HTTP: %1d bytes...", len);
+         if (status == TG_REMOTE_STATUS_OK && content_len == (-1)) {
+            buf[len] = '\0';
+            content_len = GetContentLength(buf, &header_len);
+         }
+         if (content_len == (-1) || content_len == 0) {
+            sprintf(msg, "HTTP: %1d bytes...", len);
+         } else {
+            sprintf(msg, "HTTP: %1d of %1d bytes...", len-header_len,
+                  content_len);
+         }
          ShowRemoteStatus(msg);
+         if (PRTGIF && cmdLineDumpURL && cmdLineDumpURLShowStatus) {
+            if (content_len == (-1) || content_len == 0) {
+               fprintf(stderr, "HTTP: %1d bytes...\r", len);
+            } else {
+               fprintf(stderr, "HTTP: %1d of %1d bytes...\r", len-header_len,
+                     content_len);
+            }
+         }
       }
    } while (status == TG_REMOTE_STATUS_OK && !end_of_file);
    if (status == TG_REMOTE_STATUS_OK) {
@@ -1078,5 +1165,8 @@ int HttpDoRead(n_socket, ppsz_buf, pn_buf_sz)
       sprintf(msg, "HTTP: error encountered in receiving responses.");
    }
    ShowRemoteStatus(msg);
+   if (PRTGIF && cmdLineDumpURL && cmdLineDumpURLShowStatus) {
+      fprintf(stderr, "\n");
+   }
    return status;
 }
