@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/mainmenu.c,v 3.51 1998/11/05 22:56:17 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/mainmenu.c,v 3.1 1996/07/08 14:53:17 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -69,16 +68,18 @@ extern int	atoi ARGS_DECL((char *));
 
 #define DEF_MAINMENUPINDIST 80
 
-int	pinnedMainMenu = FALSE;
-int	mainMenuPinDistance = DEF_MAINMENUPINDIST;
-int	mainMenuX;
-int	mainMenuY;
-int	mainMenuW;
-int	mainMenuH;
-Window	mainMenuWindow;
+int	pinnedMainMenu=FALSE;
+int	mainMenuPinDistance=DEF_MAINMENUPINDIST;
+int	mainMenuX=0;
+int	mainMenuY=0;
+int	mainMenuW=0;
+int	mainMenuH=0;
+Window	mainMenuWindow=None;
 
-int	numStacking = 0;
-Window	* stackingWins = NULL;
+int	numStacking=0;
+Window	*stackingWins=NULL;
+
+int	titledPinnedMenu=FALSE;
 
 typedef struct SubMenuRec {
    Window	win;
@@ -131,11 +132,14 @@ void InitMainMenu ()
    { fprintf (stderr, "Can not create main menu window!\n"); exit(1); }
 
    win_attrs.save_under = True;
-   win_attrs.override_redirect = True;
+   win_attrs.override_redirect = (titledPinnedMenu ? False : True);
    XChangeWindowAttributes (mainDisplay, mainMenuWindow,
          CWSaveUnder | CWOverrideRedirect, &win_attrs);
 
-   XSetTransientForHint (mainDisplay, mainMenuWindow, mainWindow);
+   if (!titledPinnedMenu) {
+      XSetTransientForHint (mainDisplay, mainMenuWindow, mainWindow);
+   }
+   XStoreName (mainDisplay, mainMenuWindow, "Main Menu");
 
    XSelectInput (mainDisplay, mainMenuWindow, StructureNotifyMask |
          ExposureMask | ButtonPressMask | ButtonReleaseMask | KeyPressMask |
@@ -301,8 +305,11 @@ int MainMenuEventHandler (input)
       switch (button_ev->button)
       {
          case Button1:
-            RepositionMainMenuWindow (button_ev->x_root, button_ev->y_root);
-            break;
+            if (!titledPinnedMenu) {
+               RepositionMainMenuWindow (button_ev->x_root, button_ev->y_root);
+               break;
+            }
+            /* dropping through if titledPinnedMenu ! */
          case Button2:
             index = button_ev->y/defaultFontHeight;
             x = button_ev->x_root;
@@ -898,9 +905,12 @@ int SubMenuEventHandler(input)
       button_ev = &(input->xbutton);
       switch (button_ev->button) {
       case Button1:
-         RepositionSubMenuWindow(win, menu_index, button_ev->x_root,
-               button_ev->y_root);
-         break;
+         if (!titledPinnedMenu) {
+            RepositionSubMenuWindow(win, menu_index, button_ev->x_root,
+                  button_ev->y_root);
+            break;
+         }
+         /* dropping through if titledPinnedMenu ! */
       case Button2:
          GetRowCol(menu_index, button_ev->x, button_ev->y, &down_row,
                &down_col, &unit_w, &unit_h, &num_rows);
@@ -989,6 +999,18 @@ void SubMenuCleanUp ()
 {
 }
 
+void RealizeMainMenuWindow (win_x, win_y)
+   int win_x, win_y;
+{
+   XMoveWindow(mainDisplay, mainMenuWindow, win_x, win_y);
+   XMapRaised(mainDisplay, mainMenuWindow);
+   XSetWindowColormap(mainDisplay, mainMenuWindow, mainColormap);
+   XDefineCursor(mainDisplay, mainMenuWindow, defaultCursor);
+   pinnedMainMenu = TRUE;
+   mainMenuX = win_x;
+   mainMenuY = win_y;
+}
+
 void RealizeSubMenuWindow (win_x, win_y, win_w, win_h)
    int		win_x, win_y, win_w, win_h;
 {
@@ -1004,12 +1026,15 @@ void RealizeSubMenuWindow (win_x, win_y, win_w, win_h)
    XDefineCursor (mainDisplay, win, defaultCursor);
 
    win_attrs.save_under = True;
-   win_attrs.override_redirect = True;
+   win_attrs.override_redirect = (titledPinnedMenu ? False : True);
    win_attrs.colormap = mainColormap;
    XChangeWindowAttributes (mainDisplay, win,
          CWSaveUnder | CWOverrideRedirect | CWColormap, &win_attrs);
 
-   XSetTransientForHint (mainDisplay, win, mainWindow);
+   if (!titledPinnedMenu) {
+      XSetTransientForHint (mainDisplay, win, mainWindow);
+   }
+   XStoreName (mainDisplay, win, mainMenuDescription[activeMenu]);
 
    sizehints.flags = PSize | PMinSize | PMaxSize;
    sizehints.width = sizehints.min_width = sizehints.max_width = win_w;
