@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/menu.c,v 3.76 1998/11/06 16:41:43 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /n/opus/u/guest/william/src/tgif/v3/RCS/menu.c,v 3.0 1996/05/06 16:06:00 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -54,6 +53,7 @@ static char RCSid[] =
 #include "file.e"
 #include "font.e"
 #include "grid.e"
+#include "help.e"
 #include "imgproc.e"
 #include "mainloop.e"
 #include "mainmenu.e"
@@ -76,6 +76,7 @@ static char RCSid[] =
 #include "special.e"
 #include "stk.e"
 #include "text.e"
+#include "util.e"
 #include "version.e"
 
 typedef int (*MenuProc)ARGS_DECL((int X, int Y, int TrackMenubar));
@@ -95,7 +96,7 @@ char	* mainMenuStr[MAXMENUS+1] = {
       "Fill", "Pen", "Color", "ImageProc", "Navigate", "Special",
       "Help", NULL
 };
-static char * mainMenuDescription[] = {
+char	* mainMenuDescription[] = {
       "Mode Menu",
       "File Menu",
       "Edit Menu",
@@ -454,13 +455,7 @@ int TextMenuLoop (OrigX, OrigY, Strings, Entries, ForeColors, Valid, InitRV,
             pinned_x = root_x;
             pinned_y = root_y;
             if (menuIsMainMenu) {
-               XMoveWindow (mainDisplay, mainMenuWindow, pinned_x, pinned_y);
-               XMapRaised (mainDisplay, mainMenuWindow);
-               XSetWindowColormap (mainDisplay, mainMenuWindow, mainColormap);
-               XDefineCursor (mainDisplay, mainMenuWindow, defaultCursor);
-               pinnedMainMenu = TRUE;
-               mainMenuX = pinned_x;
-               mainMenuY = pinned_y;
+               RealizeMainMenuWindow (pinned_x, pinned_y);
             } else {
                RealizeSubMenuWindow (pinned_x, pinned_y,
                      menu_w+2*brdrW, menu_h+2*brdrW);
@@ -1044,9 +1039,11 @@ void RedrawTitleWindow()
       } else {
          c_ptr = name;
       }
-      sprintf(s, "%s:%s (%1d%%)", curDomainName, c_ptr, printMag);
+      FormatFloat(&printMag, gszMsgBox);
+      sprintf(s, "%s:%s (%s%%)", curDomainName, c_ptr, gszMsgBox);
    } else {
-      sprintf(s, "%s:[Unnamed] (%1d%%)", curDomainName, printMag);
+      FormatFloat(&printMag, gszMsgBox);
+      sprintf(s, "%s:[Unnamed] (%s%%)", curDomainName, gszMsgBox);
    }
    if (pageLayoutMode==PAGE_STACK && curPage!=NULL) {
       sprintf(&s[strlen(s)], " \"%s\"",
@@ -1068,11 +1065,8 @@ void RedrawTitleWindow()
       }
    }
    if (showVersion) {
-      if (TGIF_PATCHLEVEL == 0) {
-         sprintf(s, "%s-%s", TOOL_NAME, versionString);
-      } else {
-         sprintf(s, "%s-%s-p%1d", TOOL_NAME, versionString, TGIF_PATCHLEVEL);
-      }
+      SetFullVersionString();
+      strcpy(s, fullToolName);
 
       len = strlen(s);
       amount = defaultFontWidth * len;
@@ -1153,13 +1147,14 @@ void InitIcon ()
    InitPage ();
 
    iconWindowCreated = FALSE;
-   if (((c_ptr = XGetDefault(mainDisplay,TOOL_NAME,"NoTgifIcon")) != NULL)
-         && (strcmp(c_ptr,"True") == 0 || strcmp(c_ptr,"true") == 0))
+   if (((c_ptr=XGetDefault(mainDisplay,TOOL_NAME,"UseWMIconPixmap")) == NULL) ||
+         UtilStrICmp(c_ptr,"false") != 0) {
       return;
-   if (((c_ptr = XGetDefault(mainDisplay,TOOL_NAME,"UseWMIconPixmap")) != NULL)
-         && (strcmp(c_ptr,"True") == 0 || strcmp(c_ptr,"true") == 0))
+   }
+   if (((c_ptr=XGetDefault(mainDisplay,TOOL_NAME,"NoTgifIcon")) == NULL) ||
+         UtilStrICmp(c_ptr,"false") != 0) {
       return;
-
+   }
    strcpy (s, drawPath);
    strcat (s, "/");
    if ((c_ptr = getenv ("TGIFICON")) == NULL)
@@ -1189,9 +1184,8 @@ void InitIcon ()
    if (len<ext_len || strcmp(&s[len-ext_len],ext_str) != 0)
       sprintf (&(s[len]), ".%s", OBJ_FILE_EXT);
 
-   if ((fp = fopen (s, "r")) == NULL)
-   {
-      fprintf (stderr, "Warning:  Can not open the tgif icon file '%s'\n.", s);
+   if ((fp=fopen(s, "r")) == NULL) {
+      fprintf(stderr, "Warning:  Can not open the tgif icon file '%s'.\n", s);
       return;
    }
 
