@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/names.c,v 3.17 1998/11/05 22:56:19 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/names.c,v 3.1 1996/06/17 21:18:18 william Exp $";
-#endif
 
 #include <sys/types.h>
 #ifdef VMS
@@ -404,17 +403,23 @@ DspList *DirListing(Path, ExtStr, OtherExtStr)
             continue;
          } else {
             sprintf(s, "%s%s", path, d->d_name);
-            stat(s, &stat_buf);
-            dsp_ptr = (DspList*)malloc(sizeof(DspList));
-            if (dsp_ptr == NULL) FailAllocMessage();
-            memset(dsp_ptr, 0, sizeof(DspList));
-            if (stat_buf.st_mode & S_IFDIR) {
-               dsp_ptr->directory = TRUE;
-               strcat(d->d_name, "/");
+            if (stat(s, &stat_buf) != 0) {
+               sprintf(gszMsgBox, "Fail to stat '%s'.", s);
+               Msg(gszMsgBox);
+               continue;
             } else {
-               dsp_ptr->directory = FALSE;
+               dsp_ptr = (DspList*)malloc(sizeof(DspList));
+               if (dsp_ptr == NULL) FailAllocMessage();
+               memset(dsp_ptr, 0, sizeof(DspList));
+               if (stat_buf.st_mode & S_IFDIR) {
+                  dsp_ptr->directory = TRUE;
+                  strcat(d->d_name, "/");
+               } else {
+                  dsp_ptr->directory = FALSE;
+               }
+               UtilStrCpy(dsp_ptr->itemstr, sizeof(dsp_ptr->itemstr),
+                     d->d_name);
             }
-            UtilStrCpy(dsp_ptr->itemstr, sizeof(dsp_ptr->itemstr), d->d_name);
          }
       } else if (ExtensionMatch(ext_str, d->d_name)) {
          dsp_ptr = (DspList*)malloc(sizeof(DspList));
@@ -436,8 +441,11 @@ DspList *DirListing(Path, ExtStr, OtherExtStr)
          continue;
       } else {
          sprintf(s, "%s%s", path, d->d_name);
-         stat(s, &stat_buf);
-         if (stat_buf.st_mode & S_IFDIR) {
+         if (stat(s, &stat_buf) != 0) {
+            sprintf(gszMsgBox, "Fail to stat '%s'.", s);
+            Msg(gszMsgBox);
+            continue;
+         } else if (stat_buf.st_mode & S_IFDIR) {
             dsp_ptr = (DspList*)malloc(sizeof(DspList));
             if (dsp_ptr == NULL) FailAllocMessage();
             memset(dsp_ptr, 0, sizeof(DspList));
@@ -663,6 +671,21 @@ char **MakeNameDspItemArray(Entries, DLPtr)
    return dsp_ptr;
 }
 
+int DirInSymPath(DirName)
+   char *DirName;
+{
+   register int i;
+
+   if (symPath == NULL) return FALSE;
+
+   for (i = 0; i < symPathNumEntries; i++) {
+      if (strcmp(DirName, symPath[i]) == 0) {
+         return TRUE;
+      }
+   }
+   return FALSE;
+}
+
 static int lengthOfLongestItem=INVALID;
 
 static
@@ -771,7 +794,7 @@ int DirNames(TopStr, ExtStr, SelStr, JustSetDir)
    char *TopStr, *ExtStr, *SelStr;
    int *JustSetDir;
 {
-   char win_name[128], other_ext_str[MAXSTRING+1], selected_str[MAXSTRING+1];
+   char win_name[128], selected_str[MAXSTRING+1];
    int selected_index=INVALID, selected_btn_id;
    struct DirNamesInfoRec dninfo;
 
@@ -1012,21 +1035,6 @@ int NameInCurDir(FileName)
    return FALSE;
 }
 
-int DirInSymPath(DirName)
-   char *DirName;
-{
-   register int i;
-
-   if (symPath == NULL) return FALSE;
-
-   for (i = 0; i < symPathNumEntries; i++) {
-      if (strcmp(DirName, symPath[i]) == 0) {
-         return TRUE;
-      }
-   }
-   return FALSE;
-}
-
 static char **tmpDomainName=NULL;
 
 static
@@ -1361,7 +1369,7 @@ int SelectFromLibrary(MsgStr, ExtStr, SelStr, PathStr)
 {
    int index, num_entries=0;
    char **entries=NULL;
-   char s[MAXPATHLENGTH], other_ext_str[MAXSTRING];
+   char other_ext_str[MAXSTRING];
    DspList *dsp_ptr, *next_dsp;
 
    *other_ext_str = '\0';
