@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/obj.c,v 3.19 1998/11/05 22:56:19 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/obj.c,v 3.3 1996/10/30 22:11:57 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <math.h>
@@ -96,8 +95,27 @@ void UnlinkObj (ObjPtr)
       ObjPtr->next->prev = ObjPtr->prev;
 }
 
-void FreeObj (ObjPtr)
-   register struct ObjRec	* ObjPtr;
+void ReplaceObj(old_obj, new_obj)
+   struct ObjRec *old_obj, *new_obj;
+{
+   if (topObj == old_obj) {
+      curPage->top = topObj = new_obj;
+      new_obj->prev = NULL;
+   } else {
+      old_obj->prev->next = new_obj;
+      new_obj->prev = old_obj->prev;
+   }
+   if (botObj == old_obj) {
+      curPage->bot = botObj = new_obj;
+      new_obj->next = NULL;
+   } else {
+      old_obj->next->prev = new_obj;
+      new_obj->next = old_obj->next;
+   }
+}
+
+void FreeObj(ObjPtr)
+   register struct ObjRec *ObjPtr;
 {
    if (ObjPtr->ctm != NULL) {
       free(ObjPtr->ctm);
@@ -113,26 +131,26 @@ void FreeObj (ObjPtr)
    case OBJ_RCBOX: DelAllAttrs(ObjPtr->fattr); FreeRCBoxObj(ObjPtr); break;
    case OBJ_XBM: DelAllAttrs(ObjPtr->fattr); FreeXBmObj(ObjPtr); break;
    case OBJ_XPM: DelAllAttrs(ObjPtr->fattr); FreeXPmObj(ObjPtr); break;
-   case OBJ_SYM:
+   case OBJ_GROUP:
    case OBJ_ICON:
-   case OBJ_GROUP: DelAllAttrs(ObjPtr->fattr); FreeGroupObj(ObjPtr); break;
+   case OBJ_SYM: DelAllAttrs(ObjPtr->fattr); FreeGroupObj(ObjPtr); break;
    }
 }
 
-void DelObj (ObjPtr)
-   struct ObjRec	*ObjPtr;
+void DelObj(ObjPtr)
+   struct ObjRec *ObjPtr;
 {
-   if (topObj == ObjPtr)
+   if (topObj == ObjPtr) {
       curPage->top = topObj = ObjPtr->next;
-   else
+   } else {
       ObjPtr->prev->next = ObjPtr->next;
-
-   if (botObj == ObjPtr)
+   }
+   if (botObj == ObjPtr) {
       curPage->bot = botObj = ObjPtr->prev;
-   else
+   } else {
       ObjPtr->next->prev = ObjPtr->prev;
-
-   FreeObj (ObjPtr);
+   }
+   FreeObj(ObjPtr);
 }
 
 void DelAllObj ()
@@ -180,9 +198,9 @@ void AdjObjOBBox(ObjPtr)
          break;
       }
       break;
-   case OBJ_SYM:
    case OBJ_GROUP:
    case OBJ_ICON:
+   case OBJ_SYM:
       obj_ptr = ObjPtr->detail.r->last;
       oltx = obj_ptr->obbox.ltx; olty = obj_ptr->obbox.lty;
       orbx = obj_ptr->obbox.rbx; orby = obj_ptr->obbox.rby;
@@ -222,9 +240,9 @@ void AdjObjBBox(ObjPtr)
    case OBJ_XBM: break;
    case OBJ_XPM: break;
 
-   case OBJ_SYM:
    case OBJ_GROUP:
    case OBJ_ICON:
+   case OBJ_SYM:
       obj_ptr = ObjPtr->detail.r->last;
       ltx = obj_ptr->bbox.ltx; lty = obj_ptr->bbox.lty;
       rbx = obj_ptr->bbox.rbx; rby = obj_ptr->bbox.rby;
@@ -433,9 +451,9 @@ void InvalidateObjCache(ObjPtr)
       }
       break;
 
-   case OBJ_SYM:
-   case OBJ_ICON:
    case OBJ_GROUP:
+   case OBJ_ICON:
+   case OBJ_SYM:
       for (obj_ptr=ObjPtr->detail.r->first; obj_ptr != NULL;
             obj_ptr=obj_ptr->next) {
          InvalidateObjCache(obj_ptr);
@@ -452,9 +470,9 @@ void AdjObjCache (ObjPtr)
 
    GetTransformedOBBoxOffsetVs(ObjPtr, ObjPtr->rotated_obbox);
    switch (ObjPtr->type) {
-   case OBJ_SYM:
-   case OBJ_ICON:
    case OBJ_GROUP:
+   case OBJ_ICON:
+   case OBJ_SYM:
       for (obj_ptr=ObjPtr->detail.r->first; obj_ptr != NULL;
             obj_ptr=obj_ptr->next) {
          AdjObjCache(obj_ptr);
@@ -485,9 +503,9 @@ void AdjCaches ()
       case OBJ_XPM:
          AdjObjCache(obj_ptr);
          break;
-      case OBJ_SYM:
-      case OBJ_ICON:
       case OBJ_GROUP:
+      case OBJ_ICON:
+      case OBJ_SYM:
          for (ptr=obj_ptr->detail.r->first; ptr != NULL; ptr=ptr->next) {
             AdjObjCache(ptr);
          }
@@ -705,8 +723,8 @@ void AdjPolygonCache(ObjPtr)
    }
 }
 
-void AdjObjSplineVs (ObjPtr)
-   struct ObjRec	* ObjPtr;
+void AdjObjSplineVs(ObjPtr)
+   struct ObjRec *ObjPtr;
 {
    struct ObjRec *obj_ptr;
 
@@ -721,9 +739,9 @@ void AdjObjSplineVs (ObjPtr)
    case OBJ_POLY: AdjPolyCache(ObjPtr); break;
    case OBJ_POLYGON: AdjPolygonCache(ObjPtr); break;
 
-   case OBJ_SYM:
-   case OBJ_ICON:
    case OBJ_GROUP:
+   case OBJ_ICON:
+   case OBJ_SYM:
       for (obj_ptr=ObjPtr->detail.r->first; obj_ptr != NULL;
             obj_ptr=obj_ptr->next) {
          AdjObjSplineVs(obj_ptr);
@@ -753,13 +771,13 @@ void AdjSplineVs()
       case OBJ_XPM:
          AdjObjSplineVs (obj_ptr);
          break;
-      case OBJ_SYM:
-      case OBJ_ICON:
       case OBJ_GROUP:
-         for (ptr = obj_ptr->detail.r->first; ptr != NULL; ptr = ptr->next) {
-            AdjObjSplineVs (ptr);
+      case OBJ_ICON:
+      case OBJ_SYM:
+         for (ptr=obj_ptr->detail.r->first; ptr != NULL; ptr=ptr->next) {
+            AdjObjSplineVs(ptr);
          }
-         GetTransformedOBBoxOffsetVs (obj_ptr, obj_ptr->rotated_obbox);
+         GetTransformedOBBoxOffsetVs(obj_ptr, obj_ptr->rotated_obbox);
          break;
       }
    }
@@ -839,8 +857,8 @@ void MoveRotatedObjCache (ObjPtr, AbsDx, AbsDy)
          break;
       case OBJ_BOX:
       case OBJ_GROUP:
-      case OBJ_SYM:
       case OBJ_ICON:
+      case OBJ_SYM:
       case OBJ_XBM:
       case OBJ_XPM:
          break;
