@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1997, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -27,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/oval.c,v 3.8 1997/09/14 20:37:56 william Exp $
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/oval.c,v 3.36 1998/11/05 22:56:20 william Exp $
  */
 
 #include <stdio.h>
@@ -116,8 +117,11 @@ void DumpOvalPath (FP, ObjPtr, Xc, Yc, A, B, Width, Pen, Dash)
    struct ObjRec	* ObjPtr;
    int			Xc, Yc, A, B, Width, Pen, Dash;
 {
-   register int	i;
-   char		s[MAXSTRING];
+   register int i;
+   int w_is_int=TRUE;
+   char *width_spec=ObjPtr->detail.o->width_spec;
+   double dw=GetWidthInDouble(Width, width_spec, &w_is_int);
+   char s[MAXSTRING];
 
    fprintf(FP, "   gsave\n");
    if (!colorDump && useGray && Pen > BACKPAT) {
@@ -130,7 +134,11 @@ void DumpOvalPath (FP, ObjPtr, Xc, Yc, A, B, Width, Pen, Dash)
    if (ObjPtr->ctm != NULL) {
       fprintf(FP, "      tgiforigctm setmatrix\n");
    }
-   if (Width != 1) fprintf(FP, "      %1d setlinewidth\n", Width);
+   if (w_is_int) {
+      if (Width != 1) fprintf(FP, "      %1d setlinewidth\n", Width);
+   } else {
+      fprintf(FP, "      %.3f setlinewidth\n", dw);
+   }
    if (Dash != 0) {
       fprintf(FP, "      [");
       for (i = 0; i < dashListLength[Dash]-1; i++) {
