@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/page.c,v 3.34 1998/11/05 22:56:20 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/page.c,v 3.3 1996/09/14 20:16:28 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -177,7 +176,6 @@ int DrawAHorizontalTab(page_num, page_ptr, x, y, on_top, skip)
 void RedrawPageWindow()
 {
    int i, x, y=1;
-   char s[20];
    struct PageRec *page_ptr;
 
    XClearArea(mainDisplay, pageWindow, 0, 0, pageWindowW,
@@ -227,11 +225,55 @@ void RedrawPageWindow()
    XSetTSOrigin(mainDisplay, rasterGC, 0, 0);
 }
 
+void GotoPageNum (new_page_num)
+   int	new_page_num;
+{
+   int			i=1;
+   struct PageRec	* page_ptr;
+
+   curPage->draw_orig_x = drawOrigX;
+   curPage->draw_orig_y = drawOrigY;
+   curPage->zoom_scale = zoomScale;
+   curPage->zoomed_in = zoomedIn;
+
+   for (page_ptr = firstPage; page_ptr != NULL; page_ptr = page_ptr->next, i++)
+      if (i == new_page_num)
+         break;
+   curPageNum = new_page_num;
+   curPage = page_ptr;
+   topObj = curPage->top;
+   botObj = curPage->bot;
+   if (curPage->draw_orig_x != drawOrigX || curPage->draw_orig_y != drawOrigY ||
+         curPage->zoom_scale != zoomScale || curPage->zoomed_in != zoomedIn)
+   {
+      if (!PRTGIF) AdjSplineVs();
+      if (!PRTGIF) AdjCaches();
+      curPage->draw_orig_x = drawOrigX;
+      curPage->draw_orig_y = drawOrigY;
+      curPage->zoom_scale = zoomScale;
+      curPage->zoomed_in = zoomedIn;
+   }
+}
+
+void SetCurPage (page_number)
+   int	page_number;
+{
+   if (pageLayoutMode == PAGE_TILE) return;
+
+   MakeQuiescent ();
+   PrepareToRecord (CMD_GOTO_PAGE, NULL, NULL, curPageNum);
+   GotoPageNum (page_number);
+   RecordCmd (CMD_GOTO_PAGE, NULL, NULL, NULL, curPageNum);
+   ClearAndRedrawDrawWindow ();
+   RedrawTitleWindow ();
+   ShowPage ();
+}
+
 static
 void HandleClickInPageWindow(button_ev)
    XButtonEvent *button_ev;
 {
-   int i, index=(int)(button_ev->x / scrollBarW), total, x, offset;
+   int i, index=(int)(button_ev->x / scrollBarW), total, offset;
    struct PageRec *page_ptr;
 
    if (button_ev->x <= 0) {
@@ -292,7 +334,7 @@ void HandleClickInPageWindow(button_ev)
             int w=DrawAHorizontalTab(i, page_ptr, 0, 0, FALSE, TRUE);
 
             if (w >= offset) {
-               int start=(((rulerFontWidth<<1)-7)>>1)+rulerFontWidth;
+               /* int start=(((rulerFontWidth<<1)-7)>>1)+rulerFontWidth; */
 
                if (page_ptr != curPage) {
                   SetCurPage(i);
@@ -326,7 +368,7 @@ static
 void HandleMotionInPageWindow(motion_ev)
    XMotionEvent *motion_ev;
 {
-   int i, index, total, x, offset;
+   int i, index, offset;
    struct PageRec *page_ptr;
 
    if (motion_ev->x <= 0) {
@@ -357,7 +399,7 @@ void HandleMotionInPageWindow(motion_ev)
             int w=DrawAHorizontalTab(i, page_ptr, 0, 0, FALSE, TRUE);
 
             if (w >= offset) {
-               int start=(((rulerFontWidth<<1)-7)>>1)+rulerFontWidth;
+               /* int start=(((rulerFontWidth<<1)-7)>>1)+rulerFontWidth; */
 
                if (page_ptr->name == NULL) {
                   sprintf(gszMsgBox, "Goto page %1d", i);
@@ -375,40 +417,6 @@ void HandleMotionInPageWindow(motion_ev)
    }
 }
 
-void PageEventHandler(input)
-   XEvent *input;
-{
-   XEvent ev;
-
-   if (input->type == Expose) {
-      while (XCheckWindowEvent(mainDisplay, pageWindow, ExposureMask, &ev)) ;
-      RedrawPageWindow();
-   } else if (input->type == EnterNotify) {
-      SetMouseStatus("", "", "");
-   } else if (input->type == MotionNotify) {
-      while (XCheckWindowEvent(mainDisplay,pageWindow,PointerMotionMask,&ev)) ;
-      if (pageLayoutMode == PAGE_TILE) {
-         SetMouseStatus("(none)", "Page Menu", "(none)");
-      } else {
-         HandleMotionInPageWindow(&input->xmotion);
-      }
-   } else if (input->type == ButtonPress) {
-      XButtonEvent *button_ev=(&(input->xbutton));
-
-      if (pageLayoutMode == PAGE_TILE) {
-         if (button_ev->button == Button2) {
-            PageMenu(button_ev->x_root, button_ev->y_root, FALSE);
-         }
-      } else {
-         if (button_ev->button == Button1) {
-            HandleClickInPageWindow(button_ev);
-         } else if (button_ev->button == Button2) {
-            PageMenu(button_ev->x_root, button_ev->y_root, FALSE);
-         }
-      }
-   }
-}
-
 void RedrawPageDummyWindow()
 {
 }
@@ -443,7 +451,6 @@ static
 void InitPageOnlyOnce()
 {
    static int initialized=FALSE;
-   char *c_ptr;
 
    if (initialized) return;
    initialized = TRUE;
@@ -486,50 +493,6 @@ void InitPage ()
    curPage = (lastPageNum > 0 ? firstPage : NULL);
 }
 
-void GotoPageNum (new_page_num)
-   int	new_page_num;
-{
-   int			i=1;
-   struct PageRec	* page_ptr;
-
-   curPage->draw_orig_x = drawOrigX;
-   curPage->draw_orig_y = drawOrigY;
-   curPage->zoom_scale = zoomScale;
-   curPage->zoomed_in = zoomedIn;
-
-   for (page_ptr = firstPage; page_ptr != NULL; page_ptr = page_ptr->next, i++)
-      if (i == new_page_num)
-         break;
-   curPageNum = new_page_num;
-   curPage = page_ptr;
-   topObj = curPage->top;
-   botObj = curPage->bot;
-   if (curPage->draw_orig_x != drawOrigX || curPage->draw_orig_y != drawOrigY ||
-         curPage->zoom_scale != zoomScale || curPage->zoomed_in != zoomedIn)
-   {
-      if (!PRTGIF) AdjSplineVs();
-      if (!PRTGIF) AdjCaches();
-      curPage->draw_orig_x = drawOrigX;
-      curPage->draw_orig_y = drawOrigY;
-      curPage->zoom_scale = zoomScale;
-      curPage->zoomed_in = zoomedIn;
-   }
-}
-
-void SetCurPage (page_number)
-   int	page_number;
-{
-   if (pageLayoutMode == PAGE_TILE) return;
-
-   MakeQuiescent ();
-   PrepareToRecord (CMD_GOTO_PAGE, NULL, NULL, curPageNum);
-   GotoPageNum (page_number);
-   RecordCmd (CMD_GOTO_PAGE, NULL, NULL, NULL, curPageNum);
-   ClearAndRedrawDrawWindow ();
-   RedrawTitleWindow ();
-   ShowPage ();
-}
-
 void NextPage ()
 {
    if (pageLayoutMode == PAGE_TILE)
@@ -560,7 +523,6 @@ void PrevPage ()
    SetCurPage (curPageNum-1);
 }
 
-static XComposeStatus	c_stat;
 static int		leadingChars=(-1);
 static char		formatStr[20];
 static DspList		* pageNameDspPtr=NULL;
@@ -1019,7 +981,7 @@ void PrintOnePage ()
    }
 }
 
-#ifdef __hpux
+#if defined (__hpux) || defined (linux) || defined(sco)
 extern double   atof ARGS_DECL((const char *));
 #else /* !__hpux */
 extern double   atof ARGS_DECL((char *));
@@ -1117,19 +1079,56 @@ int SetPaperSize(Spec)
    return ok;
 }
 
-void SpecifyPaperSize ()
+static
+void GetCurPaperSizeSpec(buf)
+   char *buf;
 {
-   char	spec[MAXSTRING+1];
+   char w_str[MAXSTRING], h_str[MAXSTRING];
+   float w=((float)onePageWidth)*printMag/((float)100.0);
+   float h=((float)onePageHeight)*printMag/((float)100.0);
+   float unit=(float)0.0, w_val=(float)0.0, h_val=(float)0.0;
 
-   MakeQuiescent ();
-   if (Dialog ("Please enter physical paper size: [W x H] (e.g., 8.5in x 11in)",
-         "( <CR>: accept, <ESC>: cancel )", spec) == INVALID) {
+   switch (gridSystem) {
+   case ENGLISH_GRID:
+      unit = (float)PIX_PER_INCH;
+
+      switch (pageStyle) {
+      case PORTRAIT: w_val = w/unit; h_val = h/unit; break;
+      case LANDSCAPE: w_val = h/unit; h_val = w/unit; break;
+      }
+      FormatFloat(&w_val, w_str);
+      FormatFloat(&h_val, h_str);
+      sprintf(buf, "%s in x %s in", w_str, h_str);
+      break;
+   case METRIC_GRID:
+      unit = (float)ONE_CM;
+
+      switch (pageStyle) {
+      case PORTRAIT: w_val = w/unit; h_val = h/unit; break;
+      case LANDSCAPE: w_val = h/unit; h_val = w/unit; break;
+      }
+      FormatFloat(&w_val, w_str);
+      FormatFloat(&h_val, h_str);
+      sprintf(buf, "%s cm x %s cm", w_str, h_str);
+      break;
+   }
+}
+
+void SpecifyPaperSize()
+{
+   char	buf[MAXSTRING+1], spec[MAXSTRING+1];
+
+   MakeQuiescent();
+   GetCurPaperSizeSpec(gszMsgBox);
+   sprintf(buf, "( current paper size: '%s' )", gszMsgBox);
+   if (Dialog("Please enter physical paper size: [W x H] (e.g., 8.5in x 11in)",
+         buf, spec) == INVALID) {
       return;
    }
    if (SetPaperSize(spec)) {
-      UpdPageStyle (pageStyle);
-      SetFileModified (TRUE);
-      ClearAndRedrawDrawWindow ();
+      UpdPageStyle(pageStyle);
+      SetFileModified(TRUE);
+      ClearAndRedrawDrawWindow();
    }
 }
 
@@ -1593,6 +1592,40 @@ int PageLayoutMenu (X, Y, TrackMenubar)
    return (index);
 }
 
+void PageEventHandler(input)
+   XEvent *input;
+{
+   XEvent ev;
+
+   if (input->type == Expose) {
+      while (XCheckWindowEvent(mainDisplay, pageWindow, ExposureMask, &ev)) ;
+      RedrawPageWindow();
+   } else if (input->type == EnterNotify) {
+      SetMouseStatus("", "", "");
+   } else if (input->type == MotionNotify) {
+      while (XCheckWindowEvent(mainDisplay,pageWindow,PointerMotionMask,&ev)) ;
+      if (pageLayoutMode == PAGE_TILE) {
+         SetMouseStatus("(none)", "Page Menu", "(none)");
+      } else {
+         HandleMotionInPageWindow(&input->xmotion);
+      }
+   } else if (input->type == ButtonPress) {
+      XButtonEvent *button_ev=(&(input->xbutton));
+
+      if (pageLayoutMode == PAGE_TILE) {
+         if (button_ev->button == Button2) {
+            PageMenu(button_ev->x_root, button_ev->y_root, FALSE);
+         }
+      } else {
+         if (button_ev->button == Button1) {
+            HandleClickInPageWindow(button_ev);
+         } else if (button_ev->button == Button2) {
+            PageMenu(button_ev->x_root, button_ev->y_root, FALSE);
+         }
+      }
+   }
+}
+
 void CleanUpPage ()
 {
    DelAllPages ();
