@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/polygon.c,v 3.31 1998/11/05 22:56:22 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/polygon.c,v 3.6 1997/01/30 22:45:54 william Exp $";
-#endif
 
 #include <math.h>
 #include <stdio.h>
@@ -135,6 +134,9 @@ void DumpPolygonPath (FP, ObjPtr, Vs, NumPts, Width, Pen, Fill, Dash)
    int NumPts, Width, Pen, Fill, Dash;
 {
    register int	i;
+   int w_is_int=TRUE;
+   char *width_spec=ObjPtr->detail.g->width_spec;
+   double dw=GetWidthInDouble(Width, width_spec, &w_is_int);
 
    if (Fill != (-1) && Pen == (-1)) {
       /* dumping the fill */
@@ -160,8 +162,10 @@ void DumpPolygonPath (FP, ObjPtr, Vs, NumPts, Width, Pen, Fill, Dash)
       if (ObjPtr->ctm != NULL) {
          fprintf(FP, "   tgiforigctm setmatrix\n");
       }
-      if (Width != 1) {
-         fprintf(FP, "   %1d setlinewidth\n", Width);
+      if (w_is_int) {
+         if (Width != 1) fprintf(FP, "   %1d setlinewidth\n", Width);
+      } else {
+         fprintf(FP, "   %.3f setlinewidth\n", dw);
       }
       if (Dash != 0) {
          fprintf(FP, "   [");
