@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/rcbox.c,v 3.31 1998/11/05 22:56:23 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/rcbox.c,v 3.5 1996/10/30 22:49:44 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -204,6 +203,9 @@ void DumpRCBoxPath (FP, ObjPtr, ltx, lty, rbx, rby, r, width, pen, dash)
    int			ltx, lty, rbx, rby, r, width, pen, dash;
 {
    register int	i;
+   int w_is_int=TRUE;
+   char *width_spec=ObjPtr->detail.rcb->width_spec;
+   double dw=GetWidthInDouble(width, width_spec, &w_is_int);
 
    fprintf(FP, "   gsave\n");
    if (!colorDump && useGray && pen > BACKPAT)
@@ -226,7 +228,11 @@ void DumpRCBoxPath (FP, ObjPtr, ltx, lty, rbx, rby, r, width, pen, dash)
       fprintf(FP, "%1d] 0 setdash\n",
             (int)(dashList[dash][dashListLength[dash]-1]));
    }
-   if (width != 1) fprintf(FP, "      %1d setlinewidth\n", width);
+   if (w_is_int) {
+      if (width != 1) fprintf(FP, "      %1d setlinewidth\n", width);
+   } else {
+      fprintf(FP, "      %.3f setlinewidth\n", dw);
+   }
    switch (pen) {
    case SOLIDPAT: fprintf(FP, "      stroke\n"); break;
    case BACKPAT: fprintf(FP, "      1 setgray stroke 0 setgray\n"); break;
@@ -603,7 +609,7 @@ void ContinueRCBox (OrigX, OrigY)
    PixelToMeasurementUnit(h_buf, 0);
    PixelToMeasurementUnit(x_buf, ABS_X(grid_x));
    PixelToMeasurementUnit(y_buf, ABS_Y(grid_y));
-   sprintf(buf, "x=%s\ny=%s\nw=%s\nh=%s", w_buf, h_buf, x_buf, y_buf);
+   sprintf(buf, "w=%s\nh=%s\nx=%s\ny=%s", w_buf, h_buf, x_buf, y_buf);
    StartShowMeasureCursor(grid_x, grid_y, buf, TRUE);
    BeginIntervalRulers(grid_x, grid_y, grid_x, grid_y);
    XGrabPointer(mainDisplay, drawWindow, FALSE,
@@ -626,7 +632,7 @@ void ContinueRCBox (OrigX, OrigY)
          PixelToMeasurementUnit(h_buf, ABS_SIZE(abs(saved_y-OrigY)));
          PixelToMeasurementUnit(x_buf, ABS_X(saved_x));
          PixelToMeasurementUnit(y_buf, ABS_Y(saved_y));
-         sprintf(buf, "x=%s\ny=%s\nw=%s\nh=%s", w_buf, h_buf, x_buf, y_buf);
+         sprintf(buf, "w=%s\nh=%s\nx=%s\ny=%s", w_buf, h_buf, x_buf, y_buf);
          EndShowMeasureCursor (saved_x, saved_y, buf, TRUE);
          done = TRUE;
       }
@@ -663,7 +669,7 @@ void ContinueRCBox (OrigX, OrigY)
             PixelToMeasurementUnit(h_buf, ABS_SIZE(abs(saved_y-OrigY)));
             PixelToMeasurementUnit(x_buf, ABS_X(saved_x));
             PixelToMeasurementUnit(y_buf, ABS_Y(saved_y));
-            sprintf(buf, "x=%s\ny=%s\nw=%s\nh=%s", w_buf, h_buf, x_buf, y_buf);
+            sprintf(buf, "w=%s\nh=%s\nx=%s\ny=%s", w_buf, h_buf, x_buf, y_buf);
             ShowMeasureCursor (saved_x, saved_y, buf, TRUE);
             MyRCBox (drawWindow,drawGC,OrigX,OrigY,saved_x,saved_y,radius);
             saved_x = grid_x;
@@ -674,7 +680,7 @@ void ContinueRCBox (OrigX, OrigY)
             PixelToMeasurementUnit(h_buf, ABS_SIZE(abs(saved_y-OrigY)));
             PixelToMeasurementUnit(x_buf, ABS_X(saved_x));
             PixelToMeasurementUnit(y_buf, ABS_Y(saved_y));
-            sprintf(buf, "x=%s\ny=%s\nw=%s\nh=%s", w_buf, h_buf, x_buf, y_buf);
+            sprintf(buf, "w=%s\nh=%s\nx=%s\ny=%s", w_buf, h_buf, x_buf, y_buf);
             ShowMeasureCursor (saved_x, saved_y, buf, TRUE);
          }
          DrawIntervalRulers (OrigX, OrigY, grid_x, grid_y);
@@ -697,7 +703,7 @@ void ContinueRCBox (OrigX, OrigY)
             PixelToMeasurementUnit(h_buf, ABS_SIZE(abs(saved_y-OrigY)));
             PixelToMeasurementUnit(x_buf, ABS_X(saved_x));
             PixelToMeasurementUnit(y_buf, ABS_Y(saved_y));
-            sprintf(buf, "x=%s\ny=%s\nw=%s\nh=%s", w_buf, h_buf, x_buf, y_buf);
+            sprintf(buf, "w=%s\nh=%s\nx=%s\ny=%s", w_buf, h_buf, x_buf, y_buf);
             EndShowMeasureCursor (saved_x, saved_y, buf, TRUE);
             abort = TRUE;
             done = TRUE;
@@ -946,6 +952,9 @@ void ReadRCBoxObj (FP, Inbuf, ObjPtr)
  
       s = FindChar ((int)'[', aux);
       s++;
+      if (!bufferAsFileForWhiteBoard) {
+         fgets(inbuf, MAXSTRING, FP);
+      }
  
 #else /* ~_TGIF_WB */
  
