@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/remote.c,v 3.31 1998/11/05 22:56:24 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/remote.c,v 3.0 1996/05/06 17:25:09 william Exp $";
-#endif
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -88,8 +87,13 @@ int GetClientID(psz_buf, buf_sz)
 {
    char agent_name[128];
 
-   sprintf(agent_name, "%s/%s patchlevel/%1d", TOOL_NAME, versionString,
-         TGIF_PATCHLEVEL);
+   if (*specialBuild == '\0') {
+      sprintf(agent_name, "%s/%s patchlevel/%1d", TOOL_NAME, versionString,
+            TGIF_PATCHLEVEL);
+   } else {
+      sprintf(agent_name, "%s/%s patchlevel/%1d-%s", TOOL_NAME, versionString,
+            TGIF_PATCHLEVEL, specialBuild);
+   }
    return UtilStrCpy(psz_buf, buf_sz, agent_name);
 }
 
@@ -364,6 +368,7 @@ int FormNewFileName(psz_dir, psz_file, psz_def_ext, psz_return, ppsz_page_spec)
 void ShowRemoteStatus(psz_msg)
    char *psz_msg;
 {
+   if (PRTGIF) return;
    SetStringStatus(psz_msg);
    XSync(mainDisplay, False);
 }
@@ -403,9 +408,10 @@ char *WriteRemoteFileIntoTemp(psz_buf, buf_sz, psz_ext)
          unlink(tmp_fname);
          return NULL;
       }
-      if (chmod(tmp_fname, 0777)) {
-         sprintf(gszMsgBox, "Can not chmod '%s' to 0777.", tmp_fname);
-         Msg(gszMsgBox);
+      if (tmpFileMode != 0 && chmod(tmp_fname, tmpFileMode)) {
+         sprintf(gszMsgBox, "Can not chmod '%s' to 0%03o.", tmp_fname,
+               tmpFileMode);
+         MsgBox(gszMsgBox, TOOL_NAME, INFO_MB);
       }
       return tmp_fname;
    }
@@ -607,6 +613,16 @@ int LoadHttpIntoMem(url, host, port, path, ppsz_buf, ppsz_content_type,
                TG_REMOTE_STATUS_OK && buf != NULL && *buf != '\0') {
             *ppsz_buf = HttpExtractText(buf, pn_buf_sz, pn_html,
                   ppsz_content_type);
+            if (*ppsz_buf != NULL && debugHttp == 99) {
+               /*
+                * Because of the way HttpExtractText() is coded,
+                * if *ppsz_buf != NULL, (*ppsz_buf)[*pn_buf_sz-1] is '\0'
+                * no matter what kind of file it is!
+                */
+               if (cmdLineDumpURL) {
+                  fwrite(*ppsz_buf, sizeof(char), (*pn_buf_sz)-1, stdout);
+               }
+            }
             if (pn_http_extracted_text != NULL) *pn_http_extracted_text = TRUE;
             FreeRemoteBuf(buf);
          } else if (status == TG_REMOTE_STATUS_INTR) {
@@ -702,6 +718,16 @@ int LoadFtpIntoMem(url, host, port, path, ppsz_buf, ppsz_content_type,
             buf != NULL && *buf != '\0') {
          *ppsz_buf = buf;
          if (pn_buf_sz != NULL) *pn_buf_sz = buf_sz;
+         if (*ppsz_buf != NULL && pn_buf_sz != NULL && debugFtp == -99) {
+            /*
+             * Because of the way FtpDoTalk() is coded,
+             * if *ppsz_buf != NULL, (*ppsz_buf)[*pn_buf_sz-1] is '\0'
+             * no matter what kind of file it is!
+             */
+            if (cmdLineDumpURL) {
+               fwrite(*ppsz_buf, sizeof(char), (*pn_buf_sz)-1, stdout);
+            }
+         }
          sprintf(gszMsgBox, "FTP: data received.");
          ShowRemoteStatus(gszMsgBox);
       } else if ((status & (~FTP_LOGGED_IN)) == TG_REMOTE_STATUS_INTR) {
@@ -762,13 +788,14 @@ static int gnForwardCount=0;
 static int gnAuthCount=0;
 
 int LoadRemoteFileInMem ARGS_DECL((char *url, char **ppsz_buf,
-      char **ppsz_content_type, int *pn_buf_sz, int *pn_html, int force_load));
+      char **ppsz_content_type, int *pn_buf_sz, int *pn_html, int force_load,
+      char *psz_final_url, int cb_final_url));
 
 static
 int LoadForwardedFileInMem(url, ppsz_buf, ppsz_content_type, pn_buf_sz,
-      pn_html, force_load)
-   char *url, **ppsz_buf, **ppsz_content_type;
-   int *pn_buf_sz, *pn_html, force_load;
+      pn_html, force_load, psz_final_url, cb_final_url)
+   char *url, **ppsz_buf, **ppsz_content_type, *psz_final_url;
+   int *pn_buf_sz, *pn_html, force_load, cb_final_url;
 {
    char *location=HttpHeaderGetLocation(), *dup_location;
    int rc=TRUE;
@@ -791,6 +818,9 @@ int LoadForwardedFileInMem(url, ppsz_buf, ppsz_content_type, pn_buf_sz,
       FailAllocMessage();
       return TRUE;
    }
+   if (psz_final_url != NULL && cb_final_url > 0) {
+      UtilStrCpy(psz_final_url, cb_final_url, dup_location);
+   }
    sprintf(gszMsgBox, "Forwarding '%s'", url);
    Msg(gszMsgBox);
    sprintf(gszMsgBox, "    to: '%s'.", location);
@@ -802,7 +832,7 @@ int LoadForwardedFileInMem(url, ppsz_buf, ppsz_content_type, pn_buf_sz,
    ResetRemoteBuf(ppsz_buf, ppsz_content_type, pn_buf_sz, pn_html);
    gnForwardCount++;
    rc = LoadRemoteFileInMem(dup_location, ppsz_buf, ppsz_content_type,
-         pn_buf_sz, pn_html, force_load);
+         pn_buf_sz, pn_html, force_load, psz_final_url, cb_final_url);
    gnForwardCount--;
    free(dup_location);
    return rc;
@@ -866,7 +896,7 @@ int LoadAuthenticatedFileInMem(url, host, port, ppsz_buf, ppsz_content_type,
       SetAuthorization(host, port, scheme, realm, encoded_auth);
       gnAuthCount++;
       rc = LoadRemoteFileInMem(url, ppsz_buf, ppsz_content_type, pn_buf_sz,
-            pn_html, force_load);
+            pn_html, force_load, NULL, 0);
       gnAuthCount--;
       ResetAuthorization();
    } else {
@@ -904,7 +934,7 @@ int LoadAuthenticatedFileInMem(url, host, port, ppsz_buf, ppsz_content_type,
             SetAuthorization(host, port, scheme, realm, encoded_auth);
             gnAuthCount++;
             rc = LoadRemoteFileInMem(url, ppsz_buf, ppsz_content_type,
-                  pn_buf_sz, pn_html, force_load);
+                  pn_buf_sz, pn_html, force_load, NULL, 0);
             gnAuthCount--;
             ResetAuthorization();
          }
@@ -916,16 +946,16 @@ int LoadAuthenticatedFileInMem(url, host, port, ppsz_buf, ppsz_content_type,
 }
 
 int LoadRemoteFileInMem(url, ppsz_buf, ppsz_content_type, pn_buf_sz, pn_html,
-      force_load)
-   char *url, **ppsz_buf, **ppsz_content_type;
-   int *pn_buf_sz, *pn_html, force_load;
+      force_load, psz_final_url, cb_final_url)
+   char *url, **ppsz_buf, **ppsz_content_type, *psz_final_url;
+   int *pn_buf_sz, *pn_html, force_load, cb_final_url;
    /* if the remote type is http, the url has an extension and it */
    /*       is not html but the retrieved file is html, then it's */
    /*       probably an error */
 {
-   int status=0, n_socket=0, buf_sz=0, rc;
-   int port=0, proxy_port=0, protocol_is_http=FALSE, http_extracted_text=FALSE;
-   char *protocol=NULL, *host=NULL, *path=NULL, *buf=NULL, *proxy_host=NULL;
+   int status=0, rc;
+   int port=0, protocol_is_http=FALSE, http_extracted_text=FALSE;
+   char *protocol=NULL, *host=NULL, *path=NULL, *proxy_host=NULL;
    char port_str[20];
    struct URLCacheRec *url_cache=NULL;
 
@@ -991,7 +1021,7 @@ int LoadRemoteFileInMem(url, ppsz_buf, ppsz_content_type, pn_buf_sz, pn_html,
       case 301:
       case 302:
          rc = LoadForwardedFileInMem(url, ppsz_buf, ppsz_content_type,
-               pn_buf_sz, pn_html, force_load);
+               pn_buf_sz, pn_html, force_load, psz_final_url, cb_final_url);
          break;
       case 401:
          rc = LoadAuthenticatedFileInMem(url, host, port,
@@ -1815,7 +1845,10 @@ int LoadRemoteFileFromMem(psz_url, psz_buf, psz_content_type, buf_sz, is_html)
       free(tmp_fname);
       return FALSE;
    }
-   if (!navigating) navigatingBackAndForth = TRUE;
+   if (!navigating) {
+      BeforeNavigate();
+      navigatingBackAndForth = TRUE;
+   }
    rc_loadfile = LoadFile(tmp_fname, (-1));
    if (!navigating) navigatingBackAndForth = FALSE;
 
