@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/scroll.c,v 3.19 1998/11/05 22:56:25 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/scroll.c,v 3.0 1996/05/06 22:06:26 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <X11/Xlib.h>
@@ -817,8 +816,10 @@ void ScrollToSpecifiedOrigin(cur_page_num, orig_x, orig_y, zoom_scale,
    int adj_caches=(zoomScale != zoom_scale || zoomedIn != zoomed_in);
 
    if (cur_page_num <= 0 || cur_page_num > lastPageNum) return;
-   if (drawOrigX == orig_x && drawOrigY == orig_y && !adj_caches) return;
-
+   if (drawOrigX == orig_x && drawOrigY == orig_y &&
+         cur_page_num == curPageNum && !adj_caches) {
+      return;
+   }
    drawOrigX = orig_x;
    drawOrigY = orig_y;
    zoomScale = zoom_scale;
