@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/shortcut.c,v 3.54 1998/11/05 22:56:26 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /n/opus/u/guest/william/src/tgif/v3/RCS/shortcut.c,v 3.3 1996/05/30 14:29:46 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -283,6 +282,19 @@ static struct ShortCutRec	shortCutXlateTbl[] =
    { '\0', 0, "BrowseOtherType()", 1, },
    { '\0', 0, "ToggleShowCrossHair()", 0, },
    { '\0', 0, "SetShapeShadow()", 0, },
+   { '\0', 0, "NoTransform()", 0, },
+   { '\0', 0, "About()", 0, },
+   { '\0', 0, "Copyright()", 0, },
+   { '\0', 0, "SetSelFontSize()", 0, },
+   { '\0', 0, "ZoomInAtCursor()", 0, },
+   { '\0', 0, "CenterAtCursor()", 0, },
+   { '\0', 0, "SetEditTextSize()", 0, },
+   { '\0', 0, "FindCaseSensitive()", 0, },
+   { '\0', 0, "FindNoCase()", 0, },
+   { '\0', 0, "FindAgain()", 0, },
+   { '\0', 0, "CurrentVersionInfo()", 0, },
+   { '\0', 0, "LatestReleaseInfo()", 0, },
+   { '\0', 0, "VectorWarp()", 0, },
    { '\0', 0, "", 0 }
 };
 
