@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/spline.c,v 3.20 1998/11/05 22:56:28 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/spline.c,v 3.1 1996/10/30 22:59:52 william Exp $";
-#endif
 
 #include <math.h>
 #include <stdio.h>
@@ -103,7 +102,8 @@ void Spline (Win, Pixel, Func, X1, Y1, X2, Y2, X3, Y3, X4, Y4)
             ((X3+X4)/2.0), ((Y3+Y4)/2.0), X4, Y4);
 }
 
-static XPoint	* splineVs;
+static XPoint *splineVs=NULL;
+static DoublePoint *splineDoubleVs=NULL;
 
 static
 int AddSplinePt(N, MaxN, X, Y)
@@ -125,6 +125,26 @@ int AddSplinePt(N, MaxN, X, Y)
    return (TRUE);
 }
 
+static
+int AddDoubleSplinePt(N, MaxN, X, Y)
+   int *N, *MaxN;
+   double X, Y;
+{
+   if (*N == *MaxN) {
+      splineDoubleVs = (DoublePoint*)realloc(splineDoubleVs,
+            (*MaxN)*2*sizeof(DoublePoint)+1);
+      if (splineDoubleVs == NULL) {
+         fprintf(stderr, "Can not realloc() in AddDoubleSplinePt ().\n");
+         return FALSE;
+      }
+      *MaxN = (*MaxN) << 1;
+   }
+   splineDoubleVs[*N].x = X;
+   splineDoubleVs[*N].y = Y;
+   (*N)++;
+   return TRUE;
+}
+
 static
 void SetSplineVs (N, MaxN, X1, Y1, X2, Y2, X3, Y3, X4, Y4)
    int		* N, * MaxN;
@@ -148,6 +168,30 @@ void SetSplineVs (N, MaxN, X1, Y1, X2, Y2, X3, Y3, X4, Y4)
             ((X3+X4)/2.0), ((Y3+Y4)/2.0), X4, Y4);
 }
 
+static
+void SetDoubleSplineVs(N, MaxN, X1, Y1, X2, Y2, X3, Y3, X4, Y4)
+   int *N, *MaxN;
+   double X1, Y1, X2, Y2, X3, Y3, X4, Y4;
+   /* X1, Y1, X2, Y2, X3, Y3, X4, Y4 are screen offsets */
+{
+   double x, y;
+
+   x = (X2 + X3) / 2.0;
+   y = (Y2 + Y3) / 2.0;
+   if (fabs(X1 - x) < splineTol && fabs(Y1 - y) < splineTol) {
+      AddDoubleSplinePt(N, MaxN, x, y);
+   } else {
+      SetDoubleSplineVs(N, MaxN, X1, Y1, ((X1+X2)/2.0), ((Y1+Y2)/2.0),
+            ((3.0*X2+X3)/4.0), ((3.0*Y2+Y3)/4.0), x, y);
+   }
+   if (fabs(x - X4) < splineTol && fabs(y - Y4) < splineTol) {
+      AddDoubleSplinePt(N, MaxN, X4, Y4);
+   } else {
+      SetDoubleSplineVs(N, MaxN, x, y, ((X2+3.0*X3)/4.0), ((Y2+3.0*Y3)/4.0),
+            ((X3+X4)/2.0), ((Y3+Y4)/2.0), X4, Y4);
+   }
+}
+
 XPoint * MakeSplinePolyVertex (N, XOff, YOff, NumVs, Vs)
    int		* N, XOff, YOff, NumVs;
    IntPoint	* Vs;
@@ -255,18 +299,20 @@ XPoint * MakeMultiSplinePolyVertex (N, Smooth, XOff, YOff, NumVs, Vs)
    if (Smooth == NULL) return MakeSplinePolyVertex (N, XOff, YOff, NumVs, Vs);
    if (Smooth[0] || Smooth[NumVs-1])
    {
-      fprintf (stderr, "Bad poly in MakeMultiSplinePolyVertex().\n");
+      fprintf (stderr, "Corrupted poly in MakeMultiSplinePolyVertex().\n");
+      fprintf (stderr, "Fix attempted.\n");
       fprintf (stderr, "Safest thing to do is to save file and exit.\n");
       fprintf (stderr, "Please try to reproduce this error and\n");
       fprintf (stderr, "\tsend bug report to william@cs.ucla.edu.\n");
       fflush (stderr);
-      sprintf (gszMsgBox, "%s.\n\n%s.\n\n%s %s.",
-            "Bad poly in MakeMultiSplinePolyVertex()",
+      sprintf (gszMsgBox, "%s.\n\n%s.\n\n%s.\n\n%s %s.",
+            "Corrupted poly in MakeMultiSplinePolyVertex()",
+            "Fix attempted",
             "Safest thing to do is to save file and exit",
             "Please try to reproduce this error and",
             "send bug report to william@cs.ucla.edu");
       MsgBox (gszMsgBox, TOOL_NAME, STOP_MB);
-      return (NULL);
+      Smooth[0] = Smooth[NumVs-1] = FALSE;
    }
    for (i=1; i < NumVs-1; i++)
       if (Smooth[i])
@@ -377,6 +423,86 @@ XPoint * MakeSplinePolygonVertex (N, XOff, YOff, NumVs, Vs)
    return (splineVs);
 }
 
+XPoint *MakeDoubleSplinePolygonVertex (N, XOff, YOff, NumVs, Vs)
+   int *N, XOff, YOff, NumVs;
+   DoublePoint *Vs;
+{
+   double mx1, my1, mx2, my2, mx3, my3, mx4, my4, x1, y1, x2, y2, x, y;
+   double dx_off, dy_off;
+   int i, max_n, x_off, y_off;
+
+   x_off = (zoomedIn ? XOff : (XOff>>zoomScale)<<zoomScale);
+   y_off = (zoomedIn ? YOff : (YOff>>zoomScale)<<zoomScale);
+
+   dx_off = (double)x_off;
+   dy_off = (double)y_off;
+
+   splineVs = NULL;
+
+   if (NumVs <= 3) {
+      splineVs = (XPoint *)malloc(5*sizeof(XPoint));
+      if (splineVs == NULL) {
+         FailAllocMessage();
+         *N = 0;
+         return (splineVs);
+      }
+      x = ZOOMED_DOUBLE_SIZE(Vs[0].x-dx_off);
+      y = ZOOMED_DOUBLE_SIZE(Vs[0].y-dy_off);
+      splineVs[0].x = round(x);
+      splineVs[0].y = round(y);
+      x = ZOOMED_DOUBLE_SIZE(Vs[1].x-dx_off);
+      y = ZOOMED_DOUBLE_SIZE(Vs[1].y-dy_off);
+      splineVs[1].x = round(x);
+      splineVs[1].y = round(y);
+      *N = 2;
+      return splineVs;
+   }
+
+   Vs[NumVs].x = Vs[1].x; Vs[NumVs].y = Vs[1].y;
+   x1 = ZOOMED_DOUBLE_SIZE(Vs->x-dx_off);
+   y1 = ZOOMED_DOUBLE_SIZE((Vs++)->y-dy_off);
+   x2 = ZOOMED_DOUBLE_SIZE(Vs->x-dx_off);
+   y2 = ZOOMED_DOUBLE_SIZE((Vs++)->y-dy_off);
+   mx4 = (x1 + x2) / 2.0;
+   my4 = (y1 + y2) / 2.0;
+
+   max_n = 100;
+   splineDoubleVs = (DoublePoint*)malloc((max_n+1)*sizeof(DoublePoint));
+   if (splineDoubleVs == NULL) {
+      FailAllocMessage();
+      *N = 0;
+      return NULL;
+   }
+   splineDoubleVs[0].x = mx4;
+   splineDoubleVs[0].y = my4;
+   *N = 1;
+
+   for (i=1; i < NumVs; i++, Vs++) {
+      mx1 = mx4;                             my1 = my4;
+      mx2 = (x1+3.0*x2)/4.0;                 my2 = (y1+3.0*y2)/4.0;
+      x1 = x2;                               y1 = y2;
+      x2 = ZOOMED_DOUBLE_SIZE(Vs->x-dx_off); y2 = ZOOMED_DOUBLE_SIZE(Vs->y-dy_off);
+      mx3 = (3.0*x1+x2)/4.0;                 my3 = (3.0*y1+y2)/4.0;
+      mx4 = (x1+x2)/2.0;                     my4 = (y1+y2)/2.0;
+      SetDoubleSplineVs(N, &max_n, mx1, my1, mx2, my2, mx3, my3, mx4, my4);
+   }
+   splineVs = (XPoint*)malloc(((*N)+2)*sizeof(XPoint));
+   if (splineVs == NULL) {
+      FailAllocMessage();
+      free(splineDoubleVs);
+      splineDoubleVs = NULL;
+      *N = 0;
+      return NULL;
+   }
+   for (i=0; i < *N; i++) {
+      splineVs[i].x = round(splineDoubleVs[i].x);
+      splineVs[i].y = round(splineDoubleVs[i].y);
+   }
+   free(splineDoubleVs);
+   splineDoubleVs = NULL;
+   return splineVs;
+}
+
 XPoint * MakeMultiSplinePolygonVertex (N, Smooth, XOff, YOff, NumVs, Vs)
    int		* N, XOff, YOff, NumVs;
    char		* Smooth;
@@ -685,6 +811,60 @@ void ClosedSetupMatrix (NumPts, Vs)
    mtxInfo.y[NumPts-1] = (mtxInfo.y[NumPts-1]*val+mtxInfo.y[0])/theSum;
 }
 
+static
+void DoubleClosedSetupMatrix (NumPts, Vs)
+   int NumPts;
+   DoublePoint *Vs;
+{
+   register int i;
+   register double val;
+
+   mtxInfo.x = (double*)malloc(NumPts*sizeof(double));
+   mtxInfo.y = (double*)malloc(NumPts*sizeof(double));
+   mtxInfo.dx = (double*)malloc(NumPts*sizeof(double));
+   mtxInfo.dy = (double*)malloc(NumPts*sizeof(double));
+   if (mtxInfo.x == NULL || mtxInfo.y == NULL || mtxInfo.dx == NULL ||
+         mtxInfo.dy == NULL) {
+      FailAllocMessage();
+   }
+   for (i=0; i < NumPts; i++) {
+      mtxInfo.x[i] = mtxInfo.dx[i] = ((double)(Vs[i].x))*((double)theSum);
+      mtxInfo.y[i] = mtxInfo.dy[i] = ((double)(Vs[i].y))*((double)theSum);
+   }
+   /* the first NumPts-2 rows have an extra column */
+   mtxInfo.mtx = (double**)malloc(NumPts*sizeof(double*));
+   if (mtxInfo.mtx == NULL) FailAllocMessage();
+   for (i=0; i < NumPts; i++) {
+      mtxInfo.mtx[i] = (double*)malloc(4*sizeof(double));
+      if (mtxInfo.mtx[i] == NULL) FailAllocMessage();
+   }
+   mtxInfo.mtx[0][0] = mtxInfo.mtx[NumPts-1][2] = (double)1.0;
+   mtxInfo.mtx[0][1] = mtxInfo.mtx[NumPts-1][1] = (double)SUM_MINUS_2;
+   mtxInfo.mtx[0][2] = mtxInfo.mtx[NumPts-1][0] = (double)1.0;
+   mtxInfo.mtx[0][3] = (double)1.0;
+   /* use mtx[NumPts-1][3] as mtx[NumPts-1][i] where i is moving to right */
+   mtxInfo.mtx[NumPts-1][3] = (double)0.0;
+   for (i=1; i < NumPts-1; i++)
+   {
+      mtxInfo.mtx[i][0] = (double)1.0;
+      mtxInfo.mtx[i][1] = (double)SUM_MINUS_2;
+      mtxInfo.mtx[i][2] = (double)1.0;
+      mtxInfo.mtx[i][3] = (double)0.0;
+   }
+   val = (-mtxInfo.mtx[0][1]);
+   if (NumPts == 3)
+      mtxInfo.mtx[NumPts-1][0] =
+            (mtxInfo.mtx[NumPts-1][0]*val+mtxInfo.mtx[0][2])/theSum;
+   else
+      mtxInfo.mtx[NumPts-1][0] = mtxInfo.mtx[NumPts-1][0]*val/theSum;
+   mtxInfo.mtx[NumPts-1][1] =
+         (mtxInfo.mtx[NumPts-1][1]*val+mtxInfo.mtx[0][3])/theSum;
+   /* use mtx[NumPts-1][3] as mtx[NumPts-1][i] where i moves to right */
+   mtxInfo.mtx[NumPts-1][3] = mtxInfo.mtx[0][2]/theSum;
+   mtxInfo.x[NumPts-1] = (mtxInfo.x[NumPts-1]*val+mtxInfo.x[0])/theSum;
+   mtxInfo.y[NumPts-1] = (mtxInfo.y[NumPts-1]*val+mtxInfo.y[0])/theSum;
+}
+
 static int gaussIteration=0;
 
 static
@@ -827,6 +1007,36 @@ IntPoint * ClosedControlPts (NumPts, N)
    return (v);
 }
 
+static
+DoublePoint *DoubleClosedControlPts(NumPts, N)
+   int NumPts, *N;
+{
+   register int i;
+   int index=0;
+   double half=theSum/((double)2.0);
+   double weight=half-((double)1.0);
+   DoublePoint *v;
+
+   v = (DoublePoint*)malloc(((NumPts<<1)+2)*sizeof(DoublePoint));
+   if (v == NULL) FailAllocMessage();
+   for (i=0; i<NumPts; i++) {
+      v[index].x = ((weight*mtxInfo.x[i]+mtxInfo.x[(i+1) % NumPts])/half);
+      v[index].y = ((weight*mtxInfo.y[i]+mtxInfo.y[(i+1) % NumPts])/half);
+      index++;
+      v[index].x = ((mtxInfo.x[i]+weight*mtxInfo.x[(i+1) % NumPts])/half);
+      v[index].y = ((mtxInfo.y[i]+weight*mtxInfo.y[(i+1) % NumPts])/half);
+      index++;
+   }
+   v[index].x = ((weight*mtxInfo.x[0]+mtxInfo.x[1])/half);
+   v[index].y = ((weight*mtxInfo.y[0]+mtxInfo.y[1])/half);
+   index++;
+
+   FreeMtxInfo (NumPts);
+
+   *N = index;
+   return (v);
+}
+
 XPoint * MakeIntSplinePolygonVertex (N, CntrlN, CntrlVs, XOff, YOff, NumVs, Vs)
    int		* N, * CntrlN, XOff, YOff, NumVs;
    IntPoint	* * CntrlVs, * Vs;
@@ -861,6 +1071,46 @@ XPoint * MakeIntSplinePolygonVertex (N, CntrlN, CntrlVs, XOff, YOff, NumVs, Vs)
    return (MakeSplinePolygonVertex (N, XOff, YOff, *CntrlN, *CntrlVs));
 }
 
+XPoint *MakeDoubleIntSplinePolygonVertex(N, CntrlN, CntrlVs, XOff, YOff,
+      NumVs, Vs)
+   int *N, *CntrlN, XOff, YOff, NumVs;
+   DoublePoint **CntrlVs, *Vs;
+{
+   int x_off, y_off;
+
+   x_off = (zoomedIn ? XOff : (XOff>>zoomScale)<<zoomScale);
+   y_off = (zoomedIn ? YOff : (YOff>>zoomScale)<<zoomScale);
+
+   splineVs = NULL;
+
+   if (NumVs <= 3) {
+      double x, y;
+
+      splineVs = (XPoint *)malloc(5*sizeof(XPoint));
+      if (splineVs == NULL) {
+         FailAllocMessage();
+         *N = 0;
+         return splineVs;
+      }
+      x = ZOOMED_DOUBLE_SIZE(Vs[0].x-((double)x_off));
+      y = ZOOMED_DOUBLE_SIZE(Vs[0].y-((double)y_off));
+      splineVs[0].x = round(x);
+      splineVs[0].y = round(y);
+      x = ZOOMED_DOUBLE_SIZE(Vs[1].x-((double)x_off));
+      y = ZOOMED_DOUBLE_SIZE(Vs[1].y-((double)y_off));
+      splineVs[1].x = round(x);
+      splineVs[1].y = round(y);
+      *N = *CntrlN = 2;
+      return splineVs;
+   }
+   gaussIteration = 0;
+   NumVs--; /* drop the duplicated end point */
+   DoubleClosedSetupMatrix(NumVs, Vs);
+   Gaussian(NumVs);
+   *CntrlVs = DoubleClosedControlPts(NumVs, CntrlN);
+   return MakeDoubleSplinePolygonVertex(N, XOff, YOff, *CntrlN, *CntrlVs);
+}
+
 void DumpCurvedPolyPoints (FP, NumPts, V, Indent)
    FILE			* FP;
    int			NumPts, Indent;
@@ -977,18 +1227,20 @@ void DumpMultiCurvedPolyPoints (FP, Smooth, Style, Curved, NumPts, V, Indent)
    }
    if (Smooth[0] || Smooth[NumPts-1])
    {
-      fprintf (stderr, "Bad poly in DumpMultiCurvedPolyPoints().\n");
+      fprintf (stderr, "Corrupted poly in DumpMultiCurvedPolyPoints().\n");
+      fprintf (stderr, "Fix attempted.\n");
       fprintf (stderr, "Safest thing to do is to save file and exit.\n");
       fprintf (stderr, "Please try to reproduce this error and\n");
       fprintf (stderr, "\tsend bug report to william@cs.ucla.edu.\n");
       fflush (stderr);
-      sprintf (gszMsgBox, "%s.\n\n%s.\n\n%s %s.",
-            "Bad poly in DumpMultiCurvedPolyPoints()",
+      sprintf (gszMsgBox, "%s.\n\n%s.\n\n%s.\n\n%s %s.",
+            "Corrupted poly in DumpMultiCurvedPolyPoints()",
+            "Fix attempted",
             "Safest thing to do is to save file and exit",
             "Please try to reproduce this error and",
             "send bug report to william@cs.ucla.edu");
       MsgBox (gszMsgBox, TOOL_NAME, STOP_MB);
-      return;
+      Smooth[0] = Smooth[NumPts-1] = FALSE;
    }
    for (i=1; i < NumPts-1; i++)
       if (Smooth[i])
