@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,11 +27,9 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/stk.c,v 3.22 1998/11/05 22:56:28 william Exp $
  */
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/stk.c,v 3.4 1996/10/30 18:27:01 william Exp $";
-#endif
 
 #include <stdio.h>
 #include <string.h>
@@ -71,6 +70,7 @@ static char RCSid[] =
 #include "stk.e"
 #endif
 #include "text.e"
+#include "util.e"
 
 struct ObjRec	*tgifObj=NULL;
 struct StkRec	*topStk=NULL;
@@ -247,15 +247,25 @@ int PushIcon()
    }
 
    strcpy(sym_name, topSel->obj->detail.r->s);
-   if (!GetSymbolPath(sym_name, path_name)) {
-      sprintf(gszMsgBox, "Can not find '%s.%s' in %s", sym_name, SYM_FILE_EXT,
-            curDomainPath);
-      MsgBox(gszMsgBox, TOOL_NAME, INFO_MB);
-      return FALSE;
-   }
+   if (*sym_name == '/') {
+      char *psz=UtilStrRChr(sym_name, '/'), *psz1=sym_name;
 
+      *psz = '\0';
+      strcpy(path_name, sym_name);
+      *psz++ = '/';
+      while (*psz != '\0') *psz1++ = *psz++;
+      *psz1 = '\0';
+   } else {
+      if (!GetSymbolPath(sym_name, path_name)) {
+         sprintf(gszMsgBox, "Can not find '%s.%s' in %s", sym_name,
+               SYM_FILE_EXT, curDomainPath);
+         MsgBox(gszMsgBox, TOOL_NAME, INFO_MB);
+         return FALSE;
+      }
+   }
    strcat(sym_name, ".");
    strcat(sym_name, SYM_FILE_EXT);
+
    sprintf(file_name, "%s/%s", path_name, sym_name);
 
    if ((short_name=IsPrefix(bootDir, file_name, &rest))) ++rest;
