@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -26,14 +27,11 @@
  * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/tgif_dbg.c,v 3.10 1998/11/05 22:56:31 william Exp $
  */
 #ifdef _TGIF_DBG
 
-#ifndef lint
-static char RCSid[] =
-      "@(#)$Header: /n/opus/u/guest/william/src/tgif/v3/RCS/tgif_dbg.c,v 3.0 1996/05/06 16:12:28 william Exp $";
-#endif
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <stdio.h>
@@ -177,8 +175,8 @@ GC Tgif_XCreateGC(display, d, valuemask, values)
       if (++gnCreateGCCount == gnCreateGCTrigger) {
          got_trigger(1);
       }
-      fprintf(gpTraceFile, "g: %6d 0x%08x	%d\n",
-            gnCreateGCCount, (unsigned int)gc, valuemask);
+      fprintf(gpTraceFile, "g: %6d 0x%08x	%ld\n",
+            gnCreateGCCount, (unsigned int)gc, (long)valuemask);
    }
    return gc;
 }
