@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1996, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -27,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/types.h,v 3.4 1996/10/28 00:37:39 william Exp $
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/types.h,v 3.103 1998/11/05 22:57:11 william Exp $
  */
 
 #ifndef _TGIF_TYPES_H_
@@ -48,6 +49,10 @@ typedef struct {
    int	x, y;
 } IntPoint;
 
+typedef struct {
+   double	x, y;
+} DoublePoint;
+
 typedef struct XfrmMtrxRec {
    int	m[6];
 } * XfrmMtrxPtr;
