@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (william@cs.ucla.edu)
  *
- * Copyright (C) 1990-1997, William Chia-Wei Cheng.
+ * Copyright (C) 1990-1998, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -15,9 +15,10 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.  All other rights (including, but not limited to, the
- * right to sell "tgif", the right to sell derivative works of
- * "tgif", and the right to distribute "tgif" for a fee) are
- * reserved by the Author.
+ * right to sell "tgif", the right to sell or distribute derivative
+ * works of "tgif", the right to distribute "tgif" for a fee, and
+ * the right to include "tgif" or derivative works of "tgif" in a
+ * for-sale product) are reserved by the Author.
  *
  * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
  * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
@@ -27,9 +28,12 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/version.c,v 3.6 1997/10/24 02:54:40 william Exp $
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/version.c,v 3.27 1998/11/05 23:46:08 william Exp $
  */
 
+#include <stdio.h>
+#include <string.h>
+#include <X11/Xlib.h>
 #include "const.h"
 #include "patchlvl.h"
 
@@ -38,8 +42,11 @@
 #endif
 
 char *versionString="3.0";
-char *copyrightString="Copyright (C) 1990-1997, William Chia-Wei Cheng";
+char *authorEmailString="bill.cheng@acm.org";
+char *copyrightString="Copyright (C) 1990-1998, William Chia-Wei Cheng";
 char *homePageURL="http://bourbon.cs.umd.edu:8001/tgif/";
+char *mailingList="kragen-tgif@gentle.dyn.ml.org";
+char *joinMailingList="kragen-tgif-subscribe@gentle.dyn.ml.org";
 char *currentReleaseURL="http://bourbon.cs.umd.edu:8001/tgif/current.html";
 char *hyperGraphicsURL="http://bourbon.cs.umd.edu:8001/tgif/index.obj";
 
@@ -57,9 +64,9 @@ void SetFullVersionString()
       }
    } else {
       if (*specialBuild == '\0') {
-         sprintf(fullVersionString, "%s-p%1d", versionString, TGIF_PATCHLEVEL);
+         sprintf(fullVersionString, "%s.%1d", versionString, TGIF_PATCHLEVEL);
       } else {
-         sprintf(fullVersionString, "%s-p%1d-%s", versionString,
+         sprintf(fullVersionString, "%s.%1d-%s", versionString,
                TGIF_PATCHLEVEL, specialBuild);
       }
    }
