@@ -1,7 +1,7 @@
 /*
  * Author:      Renato Santana, <renato@nce.ufrj.br> in January, 1996.
  *
- * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/wb1.c,v 3.2 1996/10/31 03:42:12 william Exp $
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/wb1.c,v 3.10 1998/11/05 22:51:31 william Exp $
  */
 
 #ifdef _TGIF_WB
@@ -459,6 +459,12 @@ void CmdReceived(buff)
    register struct SelRec       * topSelRec;
    register struct SelRec       * botSelRec;
 
+/*
+ * Added by Bill.  This indicates the FILE* passed to the read/write
+ * functions of OBJ files should be actually (not implemented yet) as char*.
+ */
+bufferAsFileForWhiteBoard = TRUE;
+
    buff = ParseStr (buff,(int) '#', aux, strlen(buff));
    CmdTypeRec = atoi (aux); 
    Cmd_Flag_Arrived = CmdTypeRec;
@@ -498,6 +504,11 @@ void CmdReceived(buff)
       case 30:                CmdUndoRec(); break;     /* UNDO Client->Server*/
       /*case 31:              RedoCmd(); break;        REDO Client->Server*/
    }
+/*
+ * Added by Bill.  This indicates the FILE* passed to the read/write
+ * functions of OBJ files should be actually (not implemented yet) as char*.
+ */
+bufferAsFileForWhiteBoard = FALSE;
 }
 
 
