@@ -1,7 +1,7 @@
 /*
  * Author:      Renato Santana, <renato@nce.ufrj.br> in January, 1996.
  *
- * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/wb3.c,v 3.2 1996/10/31 03:31:53 william Exp $
+ * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/wb3.c,v 3.14 1998/11/05 22:51:31 william Exp $
  */
 
 #ifdef _TGIF_WB
@@ -1221,12 +1221,8 @@ void SaveToBuffer(buff, BotObjPtr, Level, PageNumber)
       ResetXPmErrorMessage ();
       GetPSFontStr (curFont, curStyle, font_str);
 
-      if (TGIF_PATCHLEVEL == 0) {
-         sprintf (buff, "%s%%TGIF %s\n", buff, versionString);
-      } else {
-         sprintf (buff, "%s%%TGIF %s-p%1d\n", buff, versionString,
-               TGIF_PATCHLEVEL);
-      }
+      SetFullVersionString();
+      sprintf (buff, "%s%%TGIF %s\n", buff, fullVersionString);
 
       sprintf (buff, "%sstate(%1d,%1d,%.3f,", buff, pageStyle, CUR_VERSION,
                                              printMag);
